(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    282103,       8617]
NotebookOptionsPosition[    121191,       4668]
NotebookOutlinePosition[    248703,       7617]
CellTagsIndexPosition[    246273,       7527]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Introduction to Programming with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "TitleBar",
 CellTags->{
  "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
   "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
   "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
   "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Chapter"],
 " The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language"
}], "Chapter",
 CounterAssignments->{{"Chapter", 1}}],

Cell[TextData[{
 "Expressions are the basic building blocks from which everything is built. \
Their structure, internal representation, and how they are evaluated are \
essential to understanding ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". In this chapter we focus on the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " language with particular emphasis on the structure and syntax of \
expressions. We will also look at how to define and name new expressions, how \
to combine them using logical operators, and how to control properties of \
your expressions through the use of attributes."
}], "ChapterAbstract",
 CellTags->"IPM3.2.0"],

Cell[CellGroupData[{

Cell["Expressions", "Section",
 CellTags->"2. expressions"],

Cell["\<\
update information on atoms to reflect sparse arrays and new graph objects\
\>", "Editorial",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellTags->"2. expressions"],

Cell[TextData[{
 "Although it may appear different at first, everything that you will work \
with in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a similar underlying structure. This means things like a simple \
computation, a data object, a graphic, the cells in your ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook, even your notebook itself, all have a similar structure",
 " \[Dash] ",
 "they are all ",
 StyleBox["expressions", "TermDefinition"],
 ", and an understanding of expressions is essential to mastering ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "TextFirst",
 CellTags->"2. expressions"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Internal forms of expressions", "Subsection",
 CellTags->"2. expressions"],

Cell[TextData[{
 "When doing a simple arithmetic operation such as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "+", 
    RowBox[{"4", "*", "5"}]}], TraditionalForm]]],
 ", you are usually not concerned with exactly how a system such as ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " actually performs the additions or multiplications. Yet you will find it \
extremely useful to be able to see the internal representation of such \
expressions as this will allow you to manipulate them in a consistent and \
powerful manner."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[TextData[{
 "Internally, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " groups the objects that it operates on into different types: integers are \
distinct from real numbers; lists are distinct from numbers. One of the \
reasons that it is useful to identify these different ",
 StyleBox["data types", "TermDefinition"],
 " is that specialized algorithms can be used on certain classes of objects \
that will help to speed up the computations involved."
}], "Text",
 CellTags->"2. expressions"],

Cell[TextData[{
 "The ",
 StyleBox["Head", "MR"],
 " function can be used to identify types of objects. For numbers, it will \
report whether the number is an integer, a rational number, a real number, or \
a complex number."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Head", "[", "7", "]"}], ",", 
   RowBox[{"Head", "[", 
    FractionBox["1", "7"], "]"}], ",", 
   RowBox[{"Head", "[", "7.0", "]"}], ",", 
   RowBox[{"Head", "[", 
    RowBox[{"7", "+", 
     RowBox[{"2", " ", "\[ImaginaryI]"}]}], "]"}]}], "}"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[1]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Integer", ",", "Rational", ",", "Real", ",", "Complex"}], 
  "}"}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[{
 "In fact, every ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expression has a ",
 StyleBox["Head", "MR"],
 " that gives some information about that type of expression."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"a", "+", "b"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[2]:="],

Cell[BoxData["Plus"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[2]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], 
  "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[3]:="],

Cell[BoxData["List"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[3]="]
}, Open  ]],

Cell["", "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Atoms", "Subsection",
 CellTags->"2. expressions"],

Cell[TextData[{
 "The basic building blocks of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \[Dash] the ",
 StyleBox["atoms", "TermDefinition"],
 " \[Dash] from which every expression is ultimately constructed are symbols, \
numbers, strings, and sparse arrays. Although you can determine the type of \
any atomic expression (using ",
 StyleBox["Head", "MR"],
 "), you cannot extract any parts."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"7", "+", 
    RowBox[{"2", "I"}]}], ",", "1"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[8]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Part", "::", "\<\"partd\"\>"}], ":", 
  " ", "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Part specification \\\\\\\"\\\", \\\
\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\!\\(\\(\\((7 + \\(\\(2\\\\ \
\[ImaginaryI]\\)\\))\\)\\) \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\), \
\\\"MT\\\"]\\)\[NoBreak]\\!\\(\\*StyleBox[\\\"\\\\\\\" is longer than depth \
of object.\\\\\\\"\\\", \\\"MT\\\"]\\) \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/partd\\\", \
ButtonNote -> \\\"Part::partd\\\"]\\)\"\>"}]], "Message", "MSG",
 CellTags->"2. expressions",
 CellLabel->"During evaluation of In[8]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"7", "+", 
    RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], "\[LeftDoubleBracket]", "1",
   "\[RightDoubleBracket]"}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
 "A symbol consists of a sequence of letters and digits, not startingt with a \
digit. For example, both ",
 StyleBox["f", "MR"],
 " and the built-in ",
 StyleBox["Integrate", "MR"],
 " are symbols."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "f", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[4]:="],

Cell[BoxData["Symbol"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[4]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "Integrate", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[5]:="],

Cell[BoxData["Symbol"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", built-in constants all are symbols."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Head", "[", "\[Pi]", "]"}], ",", 
   RowBox[{"Head", "[", "\[ExponentialE]", "]"}], ",", 
   RowBox[{"Head", "[", "EulerGamma", "]"}]}], "}"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[6]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Symbol", ",", "Symbol", ",", "Symbol"}], "}"}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
Symbols can consist of one or more concatenated characters so long as they do \
not begin with a number.\
\>", "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "myfunc", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[7]:="],

Cell[BoxData["Symbol"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[7]="]
}, Open  ]],

Cell["As we saw above, numbers are all atomic.", "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "3628800", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[4]:="],

Cell[BoxData["Integer"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
A string is composed of characters and is enclosed in quotes. They will be \
discussed in detail in Section 3.5. \
\>", "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "\"\<Mathematica\>\"", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[9]:="],

Cell[BoxData["String"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
 "Sparse arrays are a special kind of atomic expression. They give a compact \
and highly efficient means of representing large arrays of numbers, typically \
with many zero elements. Sparse arrays in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are represented by SparseArray whose output form displays the number of \
non-default elements and the dimension of the array."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mat", "=", 
  RowBox[{"SparseArray", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i_", ",", "i_"}], "}"}], "\[Rule]", "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[12]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"SparseArray", "[", 
   RowBox[{
    InterpretationBox[
     RowBox[{"\<\"<\"\>", "\[InvisibleSpace]", "4", 
      "\[InvisibleSpace]", "\<\">\"\>"}],
     SequenceForm["<", 4, ">"],
     Editable->False], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}]}], "]"}],
  False,
  Editable->False]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "mat", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[13]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0", "0"},
     {"0", "1", "0", "0"},
     {"0", "0", "1", "0"},
     {"0", "0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 4}, {{1}, {2}, {3}, {4}}}, {1, 1, 1, 1}}]]]]], "Output",\

 CellTags->"2. expressions",
 CellLabel->"Out[13]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AtomQ", "[", "mat", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[15]:="],

Cell[BoxData["True"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
We will have more to say about sparse arrays in Chapter 8, Numerics.\
\>", "Text",
 CellTags->"2. expressions"],

Cell["", "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The structure of expressions", "Subsection",
 CellTags->"2. expressions"],

Cell[TextData[{
 "As mentioned earlier, everything in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is an expression. Expressions are either atomic, as described in the \
previous section, or they are ",
 StyleBox["normal expressions", "TermDefinition"],
 ", which have a head and contain zero or more elements. Normal expressions \
are of the following form, where ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 " is the head of the expression and the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "i"], TraditionalForm]]],
 " are the elements which may themselves be atomic or normal expressions."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"h", "[", 
   RowBox[{
    SubscriptBox["e", "1"], ",", 
    SubscriptBox["e", "2"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["e", "n"]}], "]"}], TraditionalForm]]]], "DisplayFormula",
 CellTags->"2. expressions"],

Cell[TextData[{
 "Although we indicated that you can use ",
 StyleBox["Head", "MR"],
 " to determine the type of atomic expressions, this is entirely general. For \
normal expressions, ",
 StyleBox["Head", "MR"],
 " simply gives the head of that expression."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"a", "+", "b", "+", "c"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[10]:="],

Cell[BoxData["Plus"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
 "To see the full internal representation of an expression, use ",
 StyleBox["FullForm", "MR"],
 "."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"a", "+", "b", "+", "c"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[11]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Plus", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[11]//FullForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[12]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"List", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[12]//FullForm="]
}, Open  ]],

Cell[TextData[{
 "The important thing to notice is that both of these objects (the sum and \
the list) have very similar internal representations. Each is made up of a \
function (",
 StyleBox["Plus", "MR"],
 " and ",
 StyleBox["List", "MR"],
 ", respectively), each encloses its arguments in square brackets, and each \
separates its arguments with commas."
}], "Text",
 CellTags->"2. expressions"],

Cell[TextData[{
 "Regardless of how an atomic or normal expression may appear in your \
notebook, its structure is uniquely determined by its head and parts as seen \
using ",
 StyleBox["FullForm", "MR"],
 ". This is important for understanding the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " evaluation mechanism which depends on the matching of patterns based on \
their ",
 StyleBox["FullForm", "MR"],
 " representation, a subject we will turn to in detail in Chapter 6."
}], "Text",
 CellTags->"2. expressions"],

Cell["\<\
The number of elements in any expression is given by its length.\
\>", "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"a", "+", "b", "+", "c"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[13]:="],

Cell[BoxData["3"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[13]="]
}, Open  ]],

Cell["Here is a more complicated expression.", "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr", "=", 
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"b", " ", "x"}], "+", "c"}], ")"}]}]}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[14]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"c", "+", 
    RowBox[{"b", " ", "x"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["x", "2"]}]}], ")"}], " ", 
  RowBox[{"Sin", "[", "x", "]"}]}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[14]="]
}, Open  ]],

Cell[TextData[{
 "Its head is ",
 StyleBox["Times", "MR"],
 " because it is composed of the product of ",
 StyleBox["Sin[x]", "MR"],
 " and the quadratic polynomial."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "expr", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[15]:="],

Cell[BoxData["Times"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[15]="]
}, Open  ]],

Cell["Its length is 2 since it only contains two factors.", "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "expr", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[16]:="],

Cell[BoxData["2"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
 "Although the ",
 StyleBox["FullForm", "MR"],
 " of this expression is a little harder to decipher, if you look carefully \
you should see that it is composed of the product of ",
 StyleBox["Plus[c,Times[b,x],Times[a,Power[x,2]]]", "MR"],
 " and ",
 StyleBox["Sin[x]", "MR"],
 "."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", "expr", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[17]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Times", "[", 
    RowBox[{
     RowBox[{"Plus", "[", 
      RowBox[{"c", ",", 
       RowBox[{"Times", "[", 
        RowBox[{"b", ",", "x"}], "]"}], ",", 
       RowBox[{"Times", "[", 
        RowBox[{"a", ",", 
         RowBox[{"Power", "[", 
          RowBox[{"x", ",", "2"}], "]"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"Sin", "[", "x", "]"}]}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[17]//FullForm="]
}, Open  ]],

Cell[TextData[{
 "There are several important differences between atomic expressions and \
nonatomic expressions. While the heads of all expressions are extracted in \
the same way \[Dash] using the ",
 StyleBox["Head", "MR"],
 " function",
 " \[Dash] ",
 "the head of an atom provides different information than the head of other \
expressions. For example, the head of a symbol or string is the ",
 StyleBox["kind",
  FontSlant->"Italic"],
 " of atom that it is."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "Integrate", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[18]:="],

Cell[BoxData["Symbol"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "\"\<hello\>\"", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[19]:="],

Cell[BoxData["String"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[19]="]
}, Open  ]],

Cell["\<\
The head of a number is the specific kind of number that it is, its data type.\
\>", "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "2", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[20]:="],

Cell[BoxData["Integer"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", "5.21", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[21]:="],

Cell[BoxData["Real"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["FullForm", "MR"],
 " of an atom (except a complex or rational number) is the atom itself."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", "f", "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[22]:="],

Cell[BoxData[
 TagBox[
  StyleBox["f",
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[22]//FullForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  FractionBox["5", "7"], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[23]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Rational", "[", 
    RowBox[{"5", ",", "7"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[23]//FullForm="]
}, Open  ]],

Cell[TextData[{
 "Atoms have no parts (which of course is why they are called atoms). In \
contrast, nonatomic expressions do have parts. To extract different parts of \
an expression, use the ",
 StyleBox["Part", "MR"],
 " function. For example, the first part of the expression ",
 StyleBox["a+b", "MR"],
 " is ",
 StyleBox["a", "MR"],
 "."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"a", "+", "b"}], ",", "1"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[24]:="],

Cell[BoxData["a"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
 "The second part is ",
 StyleBox["b", "MR"],
 "."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"a", "+", "b"}], ",", "2"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[25]:="],

Cell[BoxData["b"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
This should be clearer from looking at the internal representation of this \
expression.\
\>", "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"a", "+", "b"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[26]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Plus", "[", 
    RowBox[{"a", ",", "b"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[26]//FullForm="]
}, Open  ]],

Cell[TextData[{
 "So ",
 StyleBox["Part[a+b,1]", "MR"],
 " is another way of asking for the first element of ",
 StyleBox["Plus[a,b]", "MR"],
 ", which is just ",
 StyleBox["a", "MR"],
 ". In general ",
 StyleBox["Part[", "MR"],
 StyleBox["expr", "IT"],
 StyleBox[",", "MR"],
 StyleBox["n", "IT"],
 StyleBox["]", "MR"],
 " gives the ",
 StyleBox["n",
  FontSlant->"Italic"],
 "th element of ",
 StyleBox["expr",
  FontSlant->"Italic"],
 "."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[TextData[{
 "It is worth noting that the 0th part is the ",
 StyleBox["Head", "MR"],
 " of the expression."
}], "Text",
 PageBreakAbove->True,
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"a", "+", "b"}], ",", "0"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[27]:="],

Cell[BoxData["Plus"], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[27]="]
}, Open  ]],

Cell["As we stated above, atomic expressions have no parts.", "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{"\"\<read my lips\>\"", ",", "1"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[28]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Part", "::", "\<\"partd\"\>"}], ":", 
  " ", "\<\"Part specification \\!\\(\\\"read my lips\\\" \
\[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is longer than depth of \
object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message",
 CellTags->"2. expressions",
 CellLabel->"From In[28]:="],

Cell[BoxData[
 RowBox[{"\<\"read my lips\"\>", "\[LeftDoubleBracket]", "1", 
  "\[RightDoubleBracket]"}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
 "This error message indicates that the string ",
 StyleBox["\"read my lips\"", "MR"],
 " has no first part, since it is atomic. The expression ",
 StyleBox["expr[[1]]", "MR"],
 " is shorthand for ",
 StyleBox["Part[expr,1]", "MR"],
 "."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell["\<\
Similarly, complex numbers are atomic and hence have no parts.\
\>", "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"3", "+", 
    RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[29]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Part", "::", "\<\"partd\"\>"}], ":", 
  " ", "\<\"Part specification \\!\\(\\(\\((3 + \\(\\(4\\\\ \
\[ImaginaryI]\\)\\))\\)\\) \[LeftDoubleBracket] 1 \[RightDoubleBracket]\\) is \
longer than depth of object. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::partd\\\"]\\)\"\>"}]], "Message",
 CellTags->"2. expressions",
 CellLabel->"From In[29]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"3", "+", 
    RowBox[{"4", " ", "\[ImaginaryI]"}]}], ")"}], "\[LeftDoubleBracket]", "1",
   "\[RightDoubleBracket]"}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
 "Because everything in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has the common structure of an expression, most of the built-in functions \
that are used for list manipulation, such as ",
 StyleBox["Part", "MR"],
 ", can also be used to manipulate the arguments of any other kind of \
expression (except atoms)."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Append", "[", 
  RowBox[{
   RowBox[{"w", "+", 
    RowBox[{"x", " ", "y"}]}], ",", "z"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[30]:="],

Cell[BoxData[
 RowBox[{"w", "+", 
  RowBox[{"x", " ", "y"}], "+", "z"}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[{
 "This result can best be understood by looking at the ",
 StyleBox["FullForm", "MR"],
 " of the following two expressions."
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"w", "+", 
   RowBox[{"x", " ", "y"}]}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[31]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Plus", "[", 
    RowBox[{"w", ",", 
     RowBox[{"Times", "[", 
      RowBox[{"x", ",", "y"}], "]"}]}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[31]//FullForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"w", "+", 
   RowBox[{"x", " ", "y"}], "+", "z"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[32]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Plus", "[", 
    RowBox[{"w", ",", 
     RowBox[{"Times", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "z"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[32]//FullForm="]
}, Open  ]],

Cell[TextData[{
 "Appending ",
 StyleBox["z", "MR"],
 " to ",
 StyleBox["w\[ThinSpace]+\[ThinSpace]x\[ThinSpace]y", "MR"],
 " is equivalent to adding ",
 StyleBox["z", "MR"],
 " as an argument to the ",
 StyleBox["Plus", "MR"],
 " function. More generally:"
}], "TextFirst",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Append", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ",", "c"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[33]="]
}, Open  ]],

Cell[TextData[{
 "Finally, for more complicated expressions, you might find it useful to \
display the internal representation with the ",
 StyleBox["TreeForm", "MR"],
 " function, which shows the \[OpenCurlyDoubleQuote]tree structure\
\[CloseCurlyDoubleQuote] of an expression. In the following example, the root \
node of the tree is ",
 StyleBox["Plus", "MR"],
 ", which then branches three times at ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "\[VeryThinSpace]", "x"}], TraditionalForm]]],
 ", and at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "\[VeryThinSpace]", 
    SuperscriptBox["x", "2"]}], TraditionalForm]]],
 ", the latter two branching further."
}], "Text",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TreeForm", "[", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"b", " ", "x"}], "+", "c"}], "]"}]], "Input",
 CellTags->"2. expressions",
 CellLabel->"In[34]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Plus\"\>", "[", 
   RowBox[{"c", ",", 
    InterpretationBox[GridBox[{
       {"\<\"|\"\>"},
       {
        RowBox[{"\<\"Times\"\>", "[", 
         RowBox[{"b", ",", "x"}], "]"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}}],
     ColumnForm[{"|", 
       "Times"[b, x]}],
     Editable->False], ",", 
    InterpretationBox[GridBox[{
       {"\<\"|\"\>"},
       {
        RowBox[{"\<\"Times\"\>", "[", 
         RowBox[{"a", ",", GridBox[{
            {"\<\"|\"\>"},
            {
             RowBox[{"\<\"Power\"\>", "[", 
              RowBox[{"x", ",", "2"}], "]"}]}
           },
           BaselinePosition->{Baseline, {1, 1}},
           
           GridBoxAlignment->{
            "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]}], "]"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}}],
     ColumnForm[{"|", 
       "Times"[a, 
        ColumnForm[{"|", 
          "Power"[x, 2]}]]}],
     Editable->False]}], "]"}],
  TreeForm[c + b x + a x^2],
  Editable->False]], "Output",
 CellTags->"2. expressions",
 CellLabel->"Out[34]//TreeForm="]
}, Open  ]],

Cell["", "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSubsection",
 CellTags->"2. expressions"],

Cell[TextData[{
 "Give the full (internal) form of the expression ",
 StyleBox["a(b+c)", "MR"],
 "."
}], "ExerciseItem",
 CellTags->"2. expressions"],

Cell[TextData[{
 "What is the traditional representation of",
 " ",
 StyleBox["Times[a,Power[Plus[b,c],-1]]", "MR"],
 "."
}], "ExerciseItem",
 CellTags->"2. expressions"],

Cell[TextData[{
 "What do you expect to be the result of the following operations? Use the ",
 StyleBox["FullForm", "MR"],
 " of the expressions to understand what is going on."
}], "ExerciseItem",
 CellTags->"2. expressions"],

Cell[TextData[StyleBox["((x^2 + y) z/w) [[2, 1, 2]]", "MR"]], \
"ExerciseSubItem",
 CellTags->"2. expressions"],

Cell[TextData[StyleBox["(a/b)[[2, 2]]", "MR"]], "ExerciseSubItem",
 CellTags->"2. expressions"],

Cell[CellGroupData[{

Cell[TextData[{
 "What is the part specification of the ",
 StyleBox["b", "MR"],
 " in the expression ",
 StyleBox["a x^2 + b x + c", "MR"],
 "?"
}], "ExerciseItem",
 CellTags->"2. expressions"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "NonPrintInput",
 CellTags->"2. expressions",
 CellLabel->"In[35]:="],

Cell["", "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellTags->{
  "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
   "IPM3.2.2.6", "c:8"}],

Cell[CellGroupData[{

Cell["Defining variables and functions", "Subsection",
 CellTags->{"b:3.0", "IPM3.2.2.1", "c:9"}],

Cell[TextData[{
 "One of the most common tasks in any programming environment is to define \
functions, constants, and procedures to perform various tasks. Sometimes a \
particular function that you need is not part of the built-in set of \
functions. Other times, you may need to use an expression over and over again \
and so it would be useful to define it once and have it available for future \
reference. Because you want your newly defined expressions to work with all \
the built-in functions seamlessly, by defining your own functions and \
constants you essentially expand the range of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s capabilities."
}], "TextFirst",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],

Cell[TextData[{
 "For example, you might define a constant ",
 StyleBox["a", "MR"],
 " to have a certain numeric value."
}], "Text",
 PageBreakAbove->True,
 CellTags->{"i:13", "b:3.0", "IPM3.2.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a", "=", 
  RowBox[{"N", "[", 
   RowBox[{"2", "\[Pi]"}], "]"}]}]], "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[1]:="],

Cell[BoxData["6.283185307179586`"], "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"Out[1]="]
}, Closed]],

Cell[TextData[{
 "Then, whenever ",
 StyleBox["a", "MR"],
 " is used in a subsequent computation, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will find a rule associated with ",
 StyleBox["a", "MR"],
 " and will substitute that value wherever ",
 StyleBox["a", "MR"],
 " occurs."
}], "TextFirst",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cos", "[", "a", "]"}]], "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[2]:="],

Cell[BoxData["1.`"], "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"Out[2]="]
}, Closed]],

Cell[TextData[{
 "To check what definitions are associated with ",
 StyleBox["a", "MR"],
 ", use ",
 StyleBox["?a", "MR"],
 "."
}], "TextFirst",
 CellTags->{"i:14", "b:3.0", "IPM3.2.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "a"}]], "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[3]:="],

Cell["Global`a", "Print",
 CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{"a", "=", "6.283185307179586`"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["a"],
  Editable->False]], "Print",
 CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}]
}, Closed]],

Cell[TextData[{
 "To define a rule for a function ",
 StyleBox["f", "MR"],
 ", enclose its arguments in square brackets and use ",
 StyleBox["x_", "MR"],
 " to indicate the variable that will be substituted for ",
 StyleBox["x", "MR"],
 " on the right-hand side."
}], "Text",
 CellTags->{"i:15", "b:3.0", "IPM3.2.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], "=", 
  FractionBox["1", 
   RowBox[{"1", "+", "x"}]]}]], "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[4]:="],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "+", "x"}]]], "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"Out[4]="]
}, Closed]],

Cell[TextData[{
 "The expression ",
 StyleBox["f[x_]", "MR"],
 " on the left side of this assignment is a ",
 StyleBox["pattern",
  FontSlant->"Italic"],
 ". It indicates the class of expressions for which this definition should be \
used. We will have much more to say about patterns and pattern",
 " ",
 "matching in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " in Chapter 6, but, for now, it is enough to say that the pattern ",
 StyleBox["f[x_]", "MR"],
 " matches ",
 StyleBox["f[", "MR"],
 StyleBox["any expression", "IT"],
 StyleBox["]", "MR"],
 "."
}], "TextFirst",
 CellTags->{"i:16", "b:3.0", "IPM3.2.2.1"}],

Cell[TextData[{
 "You can evaluate ",
 StyleBox["f", "MR"],
 " at different values by replacing ",
 StyleBox["x", "MR"],
 " with the value you wish to use. These values can be numeric, exact, or \
symbolic."
}], "Text",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", ".1", "]"}]], "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[5]:="],

Cell[BoxData["0.9090909090909091`"], "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"Out[5]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "1", "]"}]], "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[6]:="],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"Out[6]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  SuperscriptBox["\[Alpha]", "2"], "]"}]], "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[7]:="],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"1", "+", 
   SuperscriptBox["\[Alpha]", "2"]}]]], "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"Out[7]="]
}, Closed]],

Cell["We clear the symbols that are no longer needed.", "TextFirst",
 PageBreakAbove->True,
 CellTags->{"b:3.0", "IPM3.2.2.1"}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "f"}], "]"}]], "Input",
 CellMargins->{{Inherited, Inherited}, {12, Inherited}},
 CellTags->{"b:3.0", "IPM3.2.2.1"},
 CellLabel->"In[8]:="],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Immediate vs. delayed assignments", "Subsection",
 CellTags->{"b:3.1", "IPM3.2.2.2", "c:10"}],

Cell["\<\
When you make an assignment to a variable, you are only interested in giving \
that variable a specific value and then using the variable name to represent \
that value in subsequent computations. But oftentimes, when you set up \
definitions for functions, those functions may depend upon the values of \
previously defined functions or constants. In such instances it us useful to \
delay the assignment until the function is actually used in a computation. \
This is the basic difference between immediate and delayed assignments.\
\>", "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 "An immediate assignment is written ",
 StyleBox["Set[", "MR"],
 Cell[BoxData[
  FormBox[
   StyleBox["lhs",
    FontSlant->"Italic"], TraditionalForm]]],
 StyleBox[",", "MR"],
 Cell[BoxData[
  FormBox[
   StyleBox["rhs",
    FontSlant->"Italic"], TraditionalForm]]],
 StyleBox["]", "MR"],
 " or, more commonly:"
}], "Text",
 CellTags->{"i:17", "b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 StyleBox["lhs", "TI"],
 " = ",
 StyleBox["rhs", "TI"]
}], "Program",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 "where ",
 StyleBox["lhs",
  FontSlant->"Italic"],
 " is an abbreviation for \[OpenCurlyDoubleQuote]left-hand side\
\[CloseCurlyDoubleQuote] and ",
 StyleBox["rhs",
  FontSlant->"Italic"],
 " abbreviates \[OpenCurlyDoubleQuote]right-hand side\[CloseCurlyDoubleQuote]."
}], "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 "As an example, consider defining ",
 StyleBox["rand1", "MR"],
 " to be an immediate assignment that generates a uniformly",
 " ",
 "distributed random number between 0 and 1."
}], "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "1", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Line", "=", 
   RowBox[{"$Line", "-", "2"}]}], ";"}]}], "NonPrintInput",
 CellLabel->"In[9]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rand1", "=", 
  RowBox[{"RandomReal", "[", "]"}]}]], "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"In[9]:="],

Cell[BoxData["0.6686926778600345`"], "Output",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"Out[9]="]
}, Closed]],

Cell[TextData[{
 "Notice that the output of this assignment is the value of the right-hand \
side and that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " evaluates the right-hand side immediately; that is, ",
 StyleBox["when the assignment is made",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 "A delayed assignment is set up with the ",
 StyleBox["SetDelayed", "MR"],
 " function and is written ",
 StyleBox["SetDelayed[", "MR"],
 Cell[BoxData[
  FormBox[
   StyleBox["lhs",
    FontSlant->"Italic"], TraditionalForm]]],
 StyleBox[",", "MR"],
 Cell[BoxData[
  FormBox[
   StyleBox["rhs",
    FontSlant->"Italic"], TraditionalForm]]],
 StyleBox["]", "MR"],
 " or, in its standard input form:"
}], "Text",
 CellTags->{"i:18", "b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 StyleBox["lhs", "TI"],
 " := ",
 StyleBox["rhs", "TI"]
}], "Program",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 "As an example, consider ",
 StyleBox["rand2", "MR"],
 " to be defined similarly to ",
 StyleBox["rand1", "MR"],
 ", but with a delayed assignment."
}], "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[BoxData[
 RowBox[{"rand2", ":=", 
  RowBox[{"RandomReal", "[", "]"}]}]], "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"In[10]:="],

Cell[TextData[{
 "Notice that the delayed assignment does not return a value when the \
assignment is made. In fact, the right-hand side will not be evaluated until \
the function ",
 StyleBox["rand2", "MR"],
 " is called. "
}], "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[TextData[{
 "Let us call the function ",
 StyleBox["rand1", "MR"],
 " five times."
}], "Text",
 PageBreakAbove->True,
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{"rand1", ",", 
   RowBox[{"{", "5", "}"}]}], "]"}]], "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"In[11]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.6686926778600345`", ",", "0.6686926778600345`", ",", 
   "0.6686926778600345`", ",", "0.6686926778600345`", ",", 
   "0.6686926778600345`"}], "}"}]], "Output",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"Out[11]="]
}, Closed]],

Cell[TextData[{
 "Because the right-hand side of ",
 StyleBox["rand1", "MR"],
 " was evaluated when the definition was made, ",
 StyleBox["rand1", "MR"],
 " was assigned the value 0.668693. Each subsequent call to ",
 StyleBox["rand1", "MR"],
 " returns that value."
}], "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "rand1"}]], "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"In[12]:="],

Cell["Global`rand1", "Print",
 CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{"rand1", "=", "0.6686926778600345`"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["rand1"],
  Editable->False]], "Print",
 CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}]
}, Closed]],

Cell[TextData[{
 "On the other hand, creating a table of values using ",
 StyleBox["rand2", "MR"],
 " produces a very different result."
}], "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{"rand2", ",", 
   RowBox[{"{", "5", "}"}]}], "]"}]], "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"In[13]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.8311998722869463`", ",", "0.7818074748209513`", ",", 
   "0.12463419022903224`", ",", "0.9345372830959425`", ",", 
   "0.6002520340808316`"}], "}"}]], "Output",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"Out[13]="]
}, Closed]],

Cell[TextData[{
 "Each of the five times that ",
 StyleBox["rand2", "MR"],
 " is called in the ",
 StyleBox["Table", "MR"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " looks up the definition of ",
 StyleBox["rand2", "MR"],
 " (which does not have a numeric value), and sees that it should evaluate ",
 StyleBox["Random[]", "MR"],
 ". It does this each time it is called, generating a new random number each \
time."
}], "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "rand2"}]], "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"},
 CellLabel->"In[14]:="],

Cell["Global`rand2", "Print",
 CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{"rand2", ":=", 
         RowBox[{"Random", "[", "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["rand2"],
  Editable->False]], "Print",
 CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}]
}, Closed]],

Cell[TextData[{
 "When a ",
 StyleBox["SetDelayed", "MR"],
 " function is entered, nothing is returned. When a ",
 StyleBox["Set", "MR"],
 " function is entered, the value resulting from evaluating the right-hand \
side is returned. This difference in output is indicative of a more \
fundamental difference in what happens when the two kinds of functions are \
entered and rewrite rules are thereby created. To see this, we need to look \
at the ",
 StyleBox["global rule base", "TermDefinition"],
 ", wherein reside rewrite rules."
}], "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["The global rule base", "Subsection",
 CellTags->{"b:3.2", "IPM3.2.2.3", "c:11"}],

Cell[TextData[{
 "The global rule base is composed of two kinds of rewrite rules: the \
built-in functions, which are part of every ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session, and the user-defined rewrite rules, which are entered during a \
particular session."
}], "TextFirst",
 CellTags->{"i:19", "b:3.2", "IPM3.2.2.3"}],

Cell[TextData[{
 "We can get information about both kinds of rules in the global rule base by \
entering ",
 StyleBox["?", "MR"],
 StyleBox["name", "IT"],
 ". In the case of a built-in function, the resulting usage message gives \
information about the syntax for using the function and a brief statement \
explaining what the function does."
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Apply"}]], "Input",
 CellTags->{"b:3.2", "IPM3.2.2.3"},
 CellLabel->"In[15]:="],

Cell[BoxData[
 RowBox[{"\<\"Apply[f, expr] or f @@ expr replaces the head of expr by f. \
Apply[f, expr, levelspec] replaces heads in parts of expr specified by \
levelspec.\"\>", " ", 
  ButtonBox[
   StyleBox["More\[Ellipsis]", "SR"],
   Active->True,
   BaseStyle->"RefGuideLink",
   ButtonData:>"Apply"]}]], "Print",
 CellTags->{"b:3.2", "Info3302591258-3722316", "IPM3.2.2.3"}]
}, Closed]],

Cell[TextData[{
 "In the case of a user-defined rewrite rule, the rule itself is printed. For \
the simple examples above, the crucial difference between rewrite rules \
created with the ",
 StyleBox["SetDelayed", "MR"],
 " and ",
 StyleBox["Set", "MR"],
 " functions becomes apparent by querying the rule base for the rewrite rules \
associated with the symbols ",
 StyleBox["rand1", "MR"],
 " and ",
 StyleBox["rand2", "MR"],
 "."
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "rand1"}]], "Input",
 CellTags->{"b:3.2", "IPM3.2.2.3"},
 CellLabel->"In[16]:="],

Cell["Global`rand1", "Print",
 CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{"rand1", "=", "0.6686926778600345`"}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["rand1"],
  Editable->False]], "Print",
 CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}]
}, Closed]],

Cell[TextData[{
 "A rewrite rule created using the ",
 StyleBox["Set", "MR"],
 " function has the same left-hand side as the function that created it but \
the right-hand side of the rule may differ from the right-hand side of the \
function. This is because the right-hand side of the rule was evaluated at \
the moment the definition was made."
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "rand2"}]], "Input",
 CellTags->{"b:3.2", "IPM3.2.2.3"},
 CellLabel->"In[17]:="],

Cell["Global`rand2", "Print",
 CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{"rand2", ":=", 
         RowBox[{"Random", "[", "]"}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["rand2"],
  Editable->False]], "Print",
 CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}]
}, Closed]],

Cell[TextData[{
 "Comparing this with the original ",
 StyleBox["SetDelayed", "MR"],
 " function, we see that a rewrite rule created using the ",
 StyleBox["SetDelayed", "MR"],
 " function looks exactly like the function that created it. This is because \
both the left-hand side and right-hand side of a ",
 StyleBox["SetDelayed", "MR"],
 " function are placed in the rule base ",
 StyleBox["without",
  FontSlant->"Italic"],
 StyleBox[" being evaluated",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell[TextData[{
 "In view of this difference between the ",
 StyleBox["SetDelayed", "MR"],
 " and ",
 StyleBox["Set", "MR"],
 " functions, the question is when should you use one or the other function \
to create a rewrite rule?"
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell[TextData[{
 "When you define a function, you usually do not want either the left-hand \
side or the right-hand side to be evaluated; you just want to make it \
available for use when the appropriate function call is made. This is \
precisely what occurs when a ",
 StyleBox["SetDelayed", "MR"],
 " function is entered, so the ",
 StyleBox["SetDelayed", "MR"],
 " function is commonly used in writing function definitions."
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell[TextData[{
 "When you make a value declaration, you do not want the left-hand side to be \
evaluated; you just want to make it a nickname to serve as a shorthand for a \
value. This is what happens when a ",
 StyleBox["Set", "MR"],
 " function is entered and so the ",
 StyleBox["Set", "MR"],
 " function is commonly used to make value declarations, such as assigning a \
numeric value to a constant or variable."
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell[TextData[{
 "A new rewrite rule overwrites, or replaces, an older rule with the same \
left-hand side. However, keep in mind that if two left-hand sides are the \
same except for the names of their pattern variables, they are considered \
different by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". ",
 StyleBox["Clear[", "MR"],
 Cell[BoxData[
  FormBox[
   StyleBox["name",
    FontSlant->"Italic"], TraditionalForm]]],
 StyleBox["]", "MR"],
 " can be used to remove a rewrite rule from the global rule base."
}], "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Piecewise-defined functions", "Subsection",
 CellTags->{"b:3.3", "IPM3.2.2.4", "c:12"}],

Cell[TextData[{
 "You can set up several definitions for a function and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will apply the definition that applies. In the following example we give a \
piecewise-defined function ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 ", whose values depend upon whether ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " is less than 0, between 0 and 1, or greater than 1. We specify the \
conditions on ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " by means of the ",
 StyleBox["/;", "MR"],
 " symbol."
}], "TextFirst",
 CellTags->{"i:20", "b:3.3", "IPM3.2.2.4"}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "x_", "]"}], ":=", 
  RowBox[{
   SuperscriptBox["x", "3"], "/;", 
   RowBox[{"x", "\[LessEqual]", "0"}]}]}]], "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"},
 CellLabel->"In[18]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "x_", "]"}], ":=", 
  RowBox[{"x", "/;", 
   RowBox[{"0", "<", "x", "\[LessEqual]", "1"}]}]}]], "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"},
 CellLabel->"In[19]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Sin", "[", "x", "]"}], "/;", 
   RowBox[{"x", ">", "1"}]}]}]], "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"},
 CellLabel->"In[20]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"g", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "3"}], "}"}]}], "]"}]], "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"},
 CellLabel->"In[21]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.370891 0.232428 [
[.02381 .35839 -7.59375 -11.875 ]
[.02381 .35839 7.59375 0 ]
[.21429 .35839 -7.59375 -11.875 ]
[.21429 .35839 7.59375 0 ]
[.59524 .35839 -4.5 -11.875 ]
[.59524 .35839 4.5 0 ]
[.78571 .35839 -4.5 -11.875 ]
[.78571 .35839 4.5 0 ]
[.97619 .35839 -4.5 -11.875 ]
[.97619 .35839 4.5 0 ]
[.39226 .02225 -22.6875 -5.9375 ]
[.39226 .02225 0 5.9375 ]
[.39226 .13846 -15.1875 -5.9375 ]
[.39226 .13846 0 5.9375 ]
[.39226 .25468 -22.6875 -5.9375 ]
[.39226 .25468 0 5.9375 ]
[.39226 .48711 -16.5 -5.9375 ]
[.39226 .48711 0 5.9375 ]
[.39226 .60332 -9 -5.9375 ]
[.39226 .60332 0 5.9375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .37089 m
.02381 .37714 L
s
gsave
.02381 .35839 -68.5938 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.21429 .37089 m
.21429 .37714 L
s
gsave
.21429 .35839 -68.5938 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.59524 .37089 m
.59524 .37714 L
s
gsave
.59524 .35839 -65.5 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.78571 .37089 m
.78571 .37714 L
s
gsave
.78571 .35839 -65.5 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .37089 m
.97619 .37714 L
s
gsave
.97619 .35839 -65.5 -15.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.0619 .37089 m
.0619 .37464 L
s
.1 .37089 m
.1 .37464 L
s
.1381 .37089 m
.1381 .37464 L
s
.17619 .37089 m
.17619 .37464 L
s
.25238 .37089 m
.25238 .37464 L
s
.29048 .37089 m
.29048 .37464 L
s
.32857 .37089 m
.32857 .37464 L
s
.36667 .37089 m
.36667 .37464 L
s
.44286 .37089 m
.44286 .37464 L
s
.48095 .37089 m
.48095 .37464 L
s
.51905 .37089 m
.51905 .37464 L
s
.55714 .37089 m
.55714 .37464 L
s
.63333 .37089 m
.63333 .37464 L
s
.67143 .37089 m
.67143 .37464 L
s
.70952 .37089 m
.70952 .37464 L
s
.74762 .37089 m
.74762 .37464 L
s
.82381 .37089 m
.82381 .37464 L
s
.8619 .37089 m
.8619 .37464 L
s
.9 .37089 m
.9 .37464 L
s
.9381 .37089 m
.9381 .37464 L
s
.25 Mabswid
0 .37089 m
1 .37089 L
s
.40476 .02225 m
.41101 .02225 L
s
gsave
.39226 .02225 -83.6875 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.40476 .13846 m
.41101 .13846 L
s
gsave
.39226 .13846 -76.1875 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 .25468 m
.41101 .25468 L
s
gsave
.39226 .25468 -83.6875 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.188 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40476 .48711 m
.41101 .48711 L
s
gsave
.39226 .48711 -77.5 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40476 .60332 m
.41101 .60332 L
s
gsave
.39226 .60332 -70 -9.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.40476 .04549 m
.40851 .04549 L
s
.40476 .06874 m
.40851 .06874 L
s
.40476 .09198 m
.40851 .09198 L
s
.40476 .11522 m
.40851 .11522 L
s
.40476 .16171 m
.40851 .16171 L
s
.40476 .18495 m
.40851 .18495 L
s
.40476 .20819 m
.40851 .20819 L
s
.40476 .23143 m
.40851 .23143 L
s
.40476 .27792 m
.40851 .27792 L
s
.40476 .30116 m
.40851 .30116 L
s
.40476 .32441 m
.40851 .32441 L
s
.40476 .34765 m
.40851 .34765 L
s
.40476 .39413 m
.40851 .39413 L
s
.40476 .41738 m
.40851 .41738 L
s
.40476 .44062 m
.40851 .44062 L
s
.40476 .46386 m
.40851 .46386 L
s
.40476 .51035 m
.40851 .51035 L
s
.40476 .53359 m
.40851 .53359 L
s
.40476 .55683 m
.40851 .55683 L
s
.40476 .58008 m
.40851 .58008 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.18218 0 m
.18221 .00015 L
.20178 .08961 L
.22272 .16798 L
.24259 .22744 L
.26416 .27741 L
.28492 .31301 L
.29482 .3262 L
.30409 .33658 L
.32282 .35238 L
.33275 .35833 L
.34344 .36314 L
.35355 .36637 L
.35927 .36772 L
.36458 .36871 L
.36968 .36944 L
.3743 .36994 L
.37687 .37016 L
.37964 .37036 L
.38207 .3705 L
.38467 .37062 L
.38724 .37071 L
.38958 .37077 L
.39071 .3708 L
.39194 .37082 L
.39417 .37085 L
.39542 .37086 L
.3968 .37087 L
.39749 .37088 L
.39824 .37088 L
.39889 .37088 L
.39959 .37089 L
.40087 .37089 L
.40156 .37089 L
.40221 .37089 L
.40337 .37089 L
.40461 .37089 L
.40529 .37154 L
.40602 .37243 L
.40733 .37403 L
.41028 .37763 L
.41564 .38417 L
.42567 .3964 L
.46356 .44264 L
.5039 .49186 L
.54272 .53924 L
.56247 .56333 L
.5729 .57606 L
.584 .5896 L
.58958 .59641 L
Mistroke
.59231 .59975 L
.59351 .60121 L
.59483 .60282 L
.59601 .56698 L
.59712 .5677 L
.59954 .56926 L
.60463 .57242 L
.62376 .58302 L
.64415 .59195 L
.66272 .59789 L
.67266 .60019 L
.68184 .60175 L
.68664 .60236 L
.69192 .60285 L
.69458 .60304 L
.69598 .60311 L
.69744 .60318 L
.69873 .60323 L
.69942 .60325 L
.70014 .60327 L
.70143 .6033 L
.70262 .60331 L
.70386 .60332 L
.70456 .60332 L
.70522 .60331 L
.70591 .60331 L
.70654 .6033 L
.70727 .60328 L
.70796 .60327 L
.71032 .60319 L
.71165 .60313 L
.71289 .60306 L
.71827 .60266 L
.721 .60239 L
.724 .60203 L
.7344 .60036 L
.74417 .59816 L
.76433 .59174 L
.78282 .58368 L
.82241 .55981 L
.86049 .52916 L
.90102 .48964 L
.94003 .44652 L
.97619 .40369 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->{"b:3.3", "IPM3.2.2.4"},
 CellLabel->"From In[21]:=",
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzVmv1PFEcYxxfukBdfeJFDiyDHmwJaUakVadWqRaTFt1ZNmjZGJLSofTFI
08YYjWmaGpum0Wj8vZoY/K1/Id7MrrNze59nb+fYC3jJzc19n+9859mZ2ZnZ
Z/bs7NLC/E+zSzfmZvNTi7O3F27M3cmf/mWxAGVqPK8m73ne/3lP5VcK2SA5
5K2srHgZT/8p5NT3U8CWdepVl/4xmD5xo+/RaV0RpsmFT63K1apcfSWixVhG
p9kirPDZ4KY8oFItkgEriWVVqqFA9jCQRlJx2Ek5U6ZdSWzYdAh5kYJnYWPF
iI2D6UgFdH0hb9LVZDqZSGI90ifAdDjafCLJUTMVOs1AdC+vLd1uPppiaSpe
Xof0o2D6qAK63R5paTL9GJjGqkqn9ahOljgOJpotHSX6VSquXVrMXqeq5IWj
xGdgGjLjJWb9ooLDq6/7QAV0e2ifANJ+WbO69JNgGl13dLv5TgFpn6xZXfrn
YPpwreiTYNobbT6R5KiZCv00mGimTJlut8cUkGiCWq6IfgZMNAVVRp8GU4dK
NURTfLkpU1QsfQrJMhyza/8CTC0q9UXq3knYcuhsyQMVKefScvtLMLXHiGfK
tLGDHq1MMZ7OSMrhA1umzMWSxKBMPwumgegtJpJY8xyY+lOjnwdTX2r0C2Dq
rYBuN99FIOVlTUf6V2Dqkelfg2lnavRLYOqW6ZfB1BVtvkb1o+8seiBoA2wH
YLTdP2CUx0yljX6lTUCn6rcC1pmw+oMiVjKPNPiZrHGY1oa9sdZ2wD5I6Clh
1Br+vORtTCiRA2z7KlwizJ/HvU0J27/DDISkjlA7EG+DNZpLOzgcgDR6csY6
VpwrFYofQE2mOIUDaDjQsBEHs1YOQwHBvXTVACQWTAXXDInu6IB0Xf1oS7NM
mjdKm2XSD+qnXhli1lIdvNbN162SWh9tgAJpY7T7qEodVj+9h96vQR3BfLIU
ManPMpvUVzfza9vOxyWv4yRKsVcWXVdBE/8rWZPoL2V6FrD/ZDptfl8kb1L1
pZvzudh7iSWeAdYoS9A4eApYU7Q76MZ6UqYgulWM/QvYRlmC9jL/ALZJlqAV
/W/ANrtJPAZsiyxBi/gjwJqj/bAFSH+VKYhuFWN/AtYiS9Ca9QdgrbJEC2AP
AWuTJVoBewDYVjeJ+4C1yxK0yN8DLBftStpC3AWsQ66bJH4HbJssQTvX39wk
OgD7FbDtssQ2wO4A5u/rrN2TU2SJalkErNOqZVVhG9p53wZsR2yF8XEn2ur+
DFhXWhdF2/ofAesuX2FGujx67r0J2M7YOpLGrLoAWwCsxxeeUz8J4lgULvge
sLx8X5DEPGC9loT2rAdIc4D1yXWTxHU3iTxg1wDrlyUoZHUVsAFZgoJk3wE2
6CbxLWC7ZAkKBH4D2O5oV1LM84qxjsg1UkEKa8VI7AKMwnR73CQuGPf3yQV3
A0YR1hiJIcAorDwabXM6R5k21oNyjXREQkcpMRJU96Sp+5BckM6faF6iN1gq
kdX+hC8vjcsSdO4WnZzVJ3wXZUIWo2NHep6zYkt0/VZv0zkwbyyKSujcUdlR
OqylZ9/wZYcRI3tclh0NCtnYuwYMo2KDRvSELLU/aDwb84IQo2b2mJx/AIwL
PS2z0TcT1KfZiHUaN6fcZMPYXJvJ5YzstJsYjQ0t26gQPaQaVG6mjKyG9JSm
O+WSmxdBrOWWuZ6Y8zpHTerywKT/BLsGr+YtL0CthA==\
\>"],
 ImageRangeCache->{{{153.125, 330.625}, {432.938, 323.625}} -> {-6.76097, \
6.35694, 0.0185914, 0.0152357}}]
}, Closed]],

Cell[TextData[{
 "Defining the function above is more easily accomplished using the new (in \
Version 5.1) ",
 StyleBox["Piecewise", "MR"],
 " function as follows."
}], "Text",
 CellTags->{"i:56", "IPM3.2.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Piecewise", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["x", "3"], ",", 
      RowBox[{"x", "\[LessEqual]", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"0", "<", "x", "\[LessEqual]", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sin", "[", "x", "]"}], ",", 
      RowBox[{"x", ">", "1"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellTags->"IPM3.2.2.4",
 CellLabel->"In[22]:="],

Cell[BoxData[
 RowBox[{"\[Piecewise]", GridBox[{
    {
     SuperscriptBox["x", "3"], 
     RowBox[{"x", "\[LessEqual]", "0"}]},
    {"x", 
     RowBox[{"0", "<", "x", "\[LessEqual]", "1"}]},
    {
     RowBox[{"Sin", "[", "x", "]"}], 
     RowBox[{"x", ">", "1"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}]}]], "Output",
 CellTags->"IPM3.2.2.4",
 CellLabel->"Out[22]="]
}, Closed]],

Cell[TextData[{
 "You could plot this expression directly or define a function with this ",
 StyleBox["Piecewise", "MR"],
 " object on the right-hand side of your definition and then use that \
function like any other. We will look at further uses of piecewise-defined \
objects in later chapters, in particular in the chapter on procedural \
programming."
}], "Text",
 CellTags->"IPM3.2.2.4"],

Cell["", "SubsectionSpacer",
 CellTags->"IPM3.2.2.4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions with multiple definitions", "Subsection",
 CellTags->{"b:3.4", "IPM3.2.2.5", "c:13"}],

Cell[TextData[{
 "When you make an assignment, the symbol associated with the evaluation rule \
is called an ",
 StyleBox["assignment tag",
  FontSlant->"Italic"],
 ". Assignment tags are used to specify the structure of expressions. So, for \
example, the expression ",
 StyleBox["{a,b,c}", "MR"],
 " is represented internally by ",
 StyleBox["List[a,b,c]", "MR"],
 ". Its assignment tag is ",
 StyleBox["List", "MR"],
 ". ",
 StyleBox["List", "MR"],
 " does not really do anything except serve as a wrapper to specify the \
structure of this expression. Similarly, the expression ",
 StyleBox["1+2", "MR"],
 " is represented internally by ",
 StyleBox["Plus[1,2]", "MR"],
 "; its assignment tag is ",
 StyleBox["Plus", "MR"],
 "."
}], "TextFirst",
 CellTags->{"i:21", "b:3.4", "IPM3.2.2.5"}],

Cell[TextData[{
 "Occasionally you will encounter the ",
 StyleBox["Tag", "MR"],
 " expression when you try to evaluate some incorrect input."
}], "Text",
 CellTags->{"i:22", "b:3.4", "IPM3.2.2.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "+", "2"}], "=", "4"}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"In[23]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Set", "::", "\<\"write\"\>"}], ":", 
  " ", "\<\"Tag \\!\\(Plus\\) in \\!\\(1 + 2\\) is Protected. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::write\\\"]\\)\"\>"}]], \
"Message",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"From In[23]:="],

Cell[BoxData["4"], "Output",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"Out[23]="]
}, Closed]],

Cell[TextData[{
 "For user-defined functions, the tag basically refers to the name of the \
function. So, for example, the following assignment associates the rule ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", "x", "+", 
    SuperscriptBox["x", "2"]}], TraditionalForm]]],
 " with the tag ",
 StyleBox["f", "MR"],
 "."
}], "Text",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{"1", "+", "x", "+", 
   SuperscriptBox["x", "2"]}]}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"In[24]:="],

Cell[TextData[{
 "There can be many evaluation rules associated with one tag. The following \
assignments all associate rules with the symbol ",
 Cell[BoxData["f"]],
 "."
}], "Text",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{"x", "+", "y"}]}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"In[25]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  FractionBox["1", 
   RowBox[{"x", "+", "y", "-", "z"}]]}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"In[26]:="],

Cell[TextData[{
 "To view all of the rules associated with ",
 StyleBox["f", "MR"],
 ", use ",
 StyleBox["?f", "MR"],
 "."
}], "TextFirst",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "f"}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"In[27]:="],

Cell["Global`f", "Print",
 CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"f", "[", "x_", "]"}], ":=", 
         RowBox[{"1", "+", "x", "+", 
          SuperscriptBox["x", "2"]}]}]},
       {" "},
       {
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
         RowBox[{"x", "+", "y"}]}]},
       {" "},
       {
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
         FractionBox["1", 
          RowBox[{"x", "+", "y", "-", "z"}]]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["f"],
  Editable->False]], "Print",
 CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}]
}, Closed]],

Cell["\<\
The advantages of this structure is that you can use one name for a function \
that will behave differently depending upon the number or form of arguments \
you give to that function. Using a different symbol for each of these tasks \
would require you and those who use your programs to have to remember \
multiple function names when one might be sufficient.\
\>", "TextFirst",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],

Cell["Let us clear symbols that are no longer needed.", "Text",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"f", ",", "g"}], "]"}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"},
 CellLabel->"In[28]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "NonPrintInput",
 CellTags->"b:3.4",
 CellLabel->"In[29]:="],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSubsection",
 CellTags->{"b:3.4", "IPM3.2.2.6", "c:14"}],

Cell["\<\
What rewrite rules do each of the following functions create? Check your \
predictions by entering them and then querying the rule base.\
\>", "ExerciseItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[TextData[StyleBox["randLis1[n_]:= Table[Random[], {n}]", "MR"]], \
"ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[TextData[StyleBox["randLis2[n_]:= (x=Random[]; Table[x, {n}])", "MR"]], \
"ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[TextData[StyleBox["randLis3[n_]:= (x:=Random[]; Table[x, {n}])", "MR"]], \
"ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[TextData[StyleBox["randLis4[n_] = Table[Random[], {n}]", "MR"]], \
"ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[CellGroupData[{

Cell[TextData[{
 "Consider the two functions ",
 StyleBox["f", "MR"],
 " and ",
 StyleBox["g", "MR"],
 ", which are identical except that one is written using an immediate \
assignment and the other using a delayed assignment."
}], "ExerciseItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "n_", "]"}], "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"},
 CellLabel->"In[1]:="],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "x"}], ")"}], "n"]}], ")"}]}], "x"]], "Output",
 CellTags->{"b:3.4", "IPM3.2.2.6"},
 CellLabel->"Out[1]="]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "n_", "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], "j"], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"},
 CellLabel->"In[2]:="],

Cell[TextData[{
 "Explain why the output of these two functions ",
 StyleBox["look",
  FontSlant->"Italic"],
 " so different. Are they in fact different?"
}], "ExercisesNoLabel",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "2", "]"}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"},
 CellLabel->"In[3]:="],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", "x"}], ")"}], "2"]}], ")"}]}], "x"]], "Output",
 CellTags->{"b:3.4", "IPM3.2.2.6"},
 CellLabel->"Out[3]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g", "[", "2", "]"}]], "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"},
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{"1", "+", "x", "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], "2"]}]], "Output",
 CellTags->{"b:3.4", "IPM3.2.2.6"},
 CellLabel->"Out[4]="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Create a piecewise-defined function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "x", ")"}], TraditionalForm]]],
 " based on the following and then plot the function from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "2"}], TraditionalForm]]],
 " to 0."
}], "ExerciseItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"g", "(", "x", ")"}], "=", 
   RowBox[{"\[Piecewise]", GridBox[{
      {
       RowBox[{"-", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "2"}], ")"}], "2"]}]]}], 
       RowBox[{
        RowBox[{"-", "2"}], "\[LessEqual]", "x", "\[LessEqual]", 
        RowBox[{"-", "1"}]}]},
      {
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["x", "2"]}]], 
       RowBox[{"x", "<", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}}]}]}], TraditionalForm]], "Input",
 FontWeight->"Plain",
 CellTags->"IPM3.2.2.6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f", ",", "g", ",", "x", ",", "n"}], "]"}], ";"}]], "NonPrintInput",\

 CellTags->"IPM3.2.2.6",
 CellLabel->"In[5]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "NonPrintInput",
 CellTags->"IPM3.2.2.6",
 CellLabel->"In[6]:="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Predicates and Boolean operations", "Section",
 CellTags->{"IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", "c:15"}],

Cell[CellGroupData[{

Cell["Predicates", "Subsection",
 CellTags->{"b:4.0", "IPM3.2.3.1", "c:16"}],

Cell[TextData[{
 "When working with data sets, you are often presented with the problem of \
extracting those data points that meet certain criteria. Similarly, when you \
write programs, oftentimes what to do next at any particular point in your \
program will depend upon some test or condition being met. Every programming \
language has constructs for testing data or conditions. Some of the most \
useful such constructs are called predicates. A ",
 StyleBox["predicate", "TermDefinition"],
 " is a function that returns a value of true or false depending upon whether \
its argument passes a test. For example, the predicate ",
 StyleBox["PrimeQ", "MR"],
 " tests for the primality of its argument."
}], "TextFirst",
 CellTags->{"i:23", "b:4.0", "IPM3.2.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PrimeQ", "[", "144", "]"}]], "Input",
 CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[1]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[1]="]
}, Closed]],

Cell["\<\
Other predicates are available for testing numbers to see whether they are \
even, odd, integral, and so on.\
\>", "Text",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],

Cell[CellGroupData[{

Cell["OddQ[21]", "Input",
 CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[2]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[2]="]
}, Closed]],

Cell[CellGroupData[{

Cell["EvenQ[21]", "Input",
 CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[3]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[3]="]
}, Closed]],

Cell[CellGroupData[{

Cell["IntegerQ[5/9]", "Input",
 CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[4]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[4]="]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["NumericQ", "MR"],
 " predicate tests whether its argument is a numeric quantity. Essentially, \
",
 StyleBox["NumericQ[", "MR"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox["]", "MR"],
 " gives ",
 StyleBox["True", "MR"],
 " whenever ",
 StyleBox["N[", "MR"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox["]", "MR"],
 " evaluates to an explicit number."
}], "Text",
 CellTags->{"i:28", "b:4.0", "IPM3.2.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumericQ", "[", "\[Pi]", "]"}]], "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[5]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[5]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumericQ", "[", "\[Infinity]", "]"}]], "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[6]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[6]="]
}, Closed]],

Cell[TextData[{
 "This is distinct from a related function, ",
 StyleBox["NumberQ", "MR"],
 ", which evaluates to ",
 StyleBox["True", "MR"],
 " whenever its argument is an explicit number (that is, has head one of ",
 StyleBox["Integer", "MR"],
 ", ",
 StyleBox["Rational", "MR"],
 ", ",
 StyleBox["Real", "MR"],
 ", ",
 StyleBox["Complex", "MR"],
 ")."
}], "TextFirst",
 CellTags->{"i:29", "b:4.0", "IPM3.2.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberQ", "[", "3.2", "]"}]], "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[7]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[7]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumberQ", "[", "\[Pi]", "]"}]], "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[8]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[8]="]
}, Closed]],

Cell["\<\
Many other predicates are available for testing if an expression is an atom, \
a list, a matrix, a polynomial, and much more.\
\>", "Text",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AtomQ", "[", "\"\<string\>\"", "]"}]], "Input",
 CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[9]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[9]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListQ", "[", 
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}]], "Input",
 CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[10]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[10]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixQ", "[", 
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", "0"},
     {"0", "0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], "]"}]], "Input",
 CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[11]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[11]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolynomialQ", "[", 
  RowBox[{
   RowBox[{
    FractionBox["1", "x"], "+", 
    FractionBox["1", 
     SuperscriptBox["x", "2"]], "+", 
    FractionBox["1", 
     SuperscriptBox["x", "3"]]}], ",", "x"}], "]"}]], "Input",
 CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[12]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[12]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntervalMemberQ", "[", 
  RowBox[{
   RowBox[{"Interval", "[", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "]"}], ",", "\[Pi]"}], "]"}]], "Input",
 CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"In[13]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"},
 CellLabel->"Out[13]="]
}, Closed]],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Relational and logical operators", "Subsection",
 CellTags->{"b:4.1", "IPM3.2.3.2", "c:17"}],

Cell[TextData[{
 "Another type of predicate that is commonly used in programming are \
relational operators. These are used to compare two or more expressions and \
return a value of ",
 StyleBox["True", "MR"],
 " or ",
 StyleBox["False", "MR"],
 ". The relational operators in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are ",
 StyleBox["Equal", "MR"],
 " (",
 StyleBox["\[Equal]", "MR"],
 "), ",
 StyleBox["Unequal", "MR"],
 " (",
 StyleBox["\[NotEqual]", "MR"],
 "), ",
 StyleBox["Greater", "MR"],
 " (",
 StyleBox[">", "MR"],
 "), ",
 StyleBox["Less", "MR"],
 " (",
 StyleBox["<", "MR"],
 "), ",
 StyleBox["GreaterEqual", "MR"],
 "(",
 StyleBox["\[GreaterEqual]", "MR"],
 "), and ",
 StyleBox["LessEqual", "MR"],
 " (",
 StyleBox["\[LessEqual]", "MR"],
 "). They can be used to compare numbers or arbitrary expressions."
}], "TextFirst",
 CellTags->{"i:35", "b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"7", "<", "5"}]], "Input",
 CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[14]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[14]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Equal", "[", 
  RowBox[{"3", ",", 
   RowBox[{"7", "-", "4"}], ",", 
   FractionBox["6", "2"]}], "]"}]], "Input",
 CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[15]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[15]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "2"], "-", "1"}], "==", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "4"], "-", "1"}], 
    RowBox[{
     SuperscriptBox["x", "2"], "+", "1"}]]}], "//", "Simplify"}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[16]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[16]="]
}, Closed]],

Cell[TextData[{
 "Note that the relational operators have lower precedence than arithmetic \
operators. The second example above is interpreted as ",
 StyleBox["3\[Equal](7-4)", "MR"],
 " and not as ",
 StyleBox["(3\[Equal]7)-4", "MR"],
 ". Table 2.1 lists the relational operators and their various input forms."
}], "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell[BoxData[
 FormBox[GridBox[{
    {
     StyleBox["StandardForm", "TB"], 
     StyleBox[
      RowBox[{"Functional", " ", "form"}], "TB"], 
     StyleBox["Meaning", "TB"]},
    {
     RowBox[{"x", 
      StyleBox["==", "MR"], "y"}], 
     StyleBox[
      RowBox[{"Equal", "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}], "MR"], 
     StyleBox["equal", "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox["!=", "MR"], "y"}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"Unequal", "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}], "MR"], 
     StyleBox["unequal", "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox[">", "MR"], "y"}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"Greater", "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}], "MR"], 
     StyleBox[
      RowBox[{"greater", " ", "than"}], "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox["<", "MR"], "y"}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"Less", "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}], "MR"], 
     StyleBox[
      RowBox[{"less", " ", "than"}], "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox["\[GreaterEqual]", "MR"], "y"}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"GreaterEqual", "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}], "MR"], 
     StyleBox[
      RowBox[{"greater", " ", "than", " ", "or", " ", "equal"}], "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox["\[LessEqual]", "MR"], "y"}],
      FontWeight->"Plain"], 
     StyleBox[
      RowBox[{"LessEqual", "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}], "MR"], 
     StyleBox[
      RowBox[{"less", " ", "than", " ", "or", " ", "equal"}], "TR"]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, True, {False}, True}, "RowsIndexed" -> {}}], 
  DefaultTraditionalFormatType]], "DisplayTable",
 CellTags->{"i:38", "b:4.1", "IPM3.2.3.2"}],

Cell["Relational operators", "NumberedTable",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell["\<\
The logical operators (sometimes known as Boolean operators) determine the \
truth of an expression based on Boolean arithmetic. For example, the \
conjunction of two true statements is always true.\
\>", "Text",
 CellTags->{"i:39", "b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"4", "<", "5"}], "&&", 
  RowBox[{"8", ">", "1"}]}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[17]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[17]="]
}, Closed]],

Cell[TextData[{
 "The Boolean operation \[OpenCurlyDoubleQuote]and\[CloseCurlyDoubleQuote] is \
represented in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " by ",
 StyleBox["And", "MR"],
 ", with shorthand notation ",
 StyleBox["&&", "MR"],
 " or \[And]. Here is a table that gives all the possible values for the ",
 StyleBox["And", "MR"],
 " operator. (The function ",
 StyleBox["TruthTable", "MR"],
 " is developed in Chapter 10.)"
}], "Text",
 CellTags->{"i:40", "b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TruthTable", "[", 
  RowBox[{
   RowBox[{"A", "\[And]", "B"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"A", ",", "B"}], "}"}]}], "]"}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[18]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"A", "B", 
     TagBox[
      FormBox[
       RowBox[{"A", "\[And]", "B"}],
       TraditionalForm],
      TraditionalForm,
      Editable->True]},
    {"T", "T", "T"},
    {"T", "F", "F"},
    {"F", "T", "F"},
    {"F", "F", "F"}
   },
   GridBoxDividers->{"Columns" -> {True, False, {
        AbsoluteThickness[2]}, True}, "ColumnsIndexed" -> {}, "Rows" -> {True, 
       AbsoluteThickness[2], {False}, True}, "RowsIndexed" -> {}}],
  DisplayForm]], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[18]//DisplayForm="]
}, Closed]],

Cell[TextData[{
 "The logical \[OpenCurlyDoubleQuote]or\[CloseCurlyDoubleQuote] operator, \
represented by ",
 StyleBox["Or", "MR"],
 " and with shorthand notation ",
 StyleBox["||", "MR"],
 " (or ",
 StyleBox["\[Or]", "MR"],
 "), is true when either of its arguments is true."
}], "Text",
 PageBreakAbove->True,
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"4", "==", "3"}], "||", 
  RowBox[{"3", "==", 
   FractionBox["6", "2"]}]}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[19]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[19]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"0", "==", "0.0001"}], "\[Or]", 
  RowBox[{"\[Pi]", "==", 
   FractionBox["22", "7"]}]}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[20]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[20]="]
}, Closed]],

Cell[TextData[{
 "Note the difference between this Boolean \[OpenCurlyDoubleQuote]or\
\[CloseCurlyDoubleQuote] and the common notion of \[OpenCurlyDoubleQuote]or.\
\[CloseCurlyDoubleQuote] A phrase such as, \[OpenCurlyDoubleQuote]It is cold \
or it is hot,\[CloseCurlyDoubleQuote] uses the word \[OpenCurlyDoubleQuote]or\
\[CloseCurlyDoubleQuote] in an ",
 StyleBox["exclusive",
  FontSlant->"Italic"],
 " sense; that is, it excludes the possibility that it is ",
 StyleBox["both",
  FontSlant->"Italic"],
 " cold and hot. The logical ",
 StyleBox["Or", "MR"],
 " is inclusive in the sense that if ",
 StyleBox["A", "MR"],
 " and ",
 StyleBox["B", "MR"],
 " are both true, then ",
 StyleBox["A||B", "MR"],
 " is also true."
}], "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"True", "||", "True"}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[21]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[21]="]
}, Closed]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " also contains an operator for the exclusive or, ",
 StyleBox["Xor", "MR"],
 "."
}], "Text",
 CellTags->{"i:41", "b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Xor", "[", 
  RowBox[{"True", ",", "True"}], "]"}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[22]:="],

Cell[BoxData["False"], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[22]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Xor", "[", 
  RowBox[{"True", ",", "False"}], "]"}]], "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[23]:="],

Cell[BoxData["True"], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[23]="]
}, Closed]],

Cell["Table 2.2 shows the logical operators and their input forms.", "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell[BoxData[
 FormBox[GridBox[{
    {
     StyleBox["StandardForm", "TB"], 
     StyleBox[
      RowBox[{"Functional", " ", "form"}], "TB"], 
     StyleBox["Meaning", "TB"]},
    {
     StyleBox[
      RowBox[{
       StyleBox["!", "MR"], "x"}],
      FontWeight->"Plain"], 
     RowBox[{
      StyleBox["Not", "MR"], 
      StyleBox["[", "MR"], 
      StyleBox["x", "TI"], 
      StyleBox["]", "MR"]}], 
     StyleBox["not", "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox["!=", "MR"], "y"}],
      FontWeight->"Plain"], 
     RowBox[{
      StyleBox["Unequal", "MR"], 
      StyleBox["[", "MR"], 
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox[",", "MR"], 
       StyleBox["y", "TI"]}], 
      StyleBox["]", "MR"]}], 
     StyleBox["unequal", "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox["&&", "MR"], "y"}],
      FontWeight->"Plain"], 
     RowBox[{
      StyleBox["And", "MR"], 
      StyleBox["[", "MR"], 
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox[",", "MR"], 
       StyleBox["y", "TI"]}], 
      StyleBox["]", "MR"]}], 
     StyleBox["and", "TR"]},
    {
     StyleBox[
      RowBox[{"x", 
       StyleBox["||", "MR"], "y"}],
      FontWeight->"Plain"], 
     RowBox[{
      StyleBox["Or", "MR"], 
      StyleBox["[", "MR"], 
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox[",", "MR"], 
       StyleBox["y", "TI"]}], 
      StyleBox["]", "MR"]}], 
     StyleBox["or", "TR"]},
    {
     RowBox[{
      StyleBox[
       RowBox[{"(", 
        RowBox[{"x", 
         StyleBox["||", "MR"], "y"}], ")"}],
       FontWeight->"Plain"], 
      StyleBox["&&", "MR"], 
      RowBox[{
       StyleBox["!", "MR"], 
       StyleBox[
        RowBox[{"(", 
         RowBox[{"x", 
          StyleBox["&&", "MR"], "y"}], ")"}],
        FontWeight->"Plain"]}]}], 
     RowBox[{
      StyleBox["Xor", "MR"], 
      StyleBox["[", "MR"], 
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox[",", "MR"], 
       StyleBox["y", "TI"]}], 
      StyleBox["]", "MR"]}], 
     StyleBox[
      RowBox[{"exclusive", " ", "or"}], "TR"]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, True, {False}, True}, "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {True, {
        Offset[0.5599999999999999]}, True}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {
        Offset[0.4]}, True}, "RowsIndexed" -> {}}], 
  DefaultTraditionalFormatType]], "DisplayTable",
 CellTags->{"i:42", "b:4.1", "IPM3.2.3.2"}],

Cell["Logical operators", "NumberedTable",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell[TextData[{
 "Introduced in Version 4 of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are the ",
 StyleBox["bitwise logical operators", "TermDefinition"],
 ". These functions operate on integers as binary bits. For example, ",
 StyleBox["BitOr[", "MR"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[",", "MR"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox["]", "MR"],
 " gives the integer whose binary representation has 1s wherever the binary \
representation of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " has 1s. Here is the bitwise OR of 21 and 19, given in binary form."
}], "Text",
 CellTags->{"i:43", "b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BaseForm", "[", 
  RowBox[{
   RowBox[{"BitOr", "[", 
    RowBox[{"2^^10101", ",", "2^^10011"}], "]"}], ",", "2"}], "]"}]], "Input",\

 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[24]:="],

Cell[BoxData[
 TagBox[
  InterpretationBox[
   SubscriptBox["\<\"10111\"\>", "\<\"2\"\>"],
   23,
   Editable->False],
  BaseForm[#, 2]& ]], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[24]//BaseForm="]
}, Closed]],

Cell[TextData[{
 "Similarly, ",
 StyleBox["BitXor[", "MR"],
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 StyleBox[",", "MR"],
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 StyleBox["]", "MR"],
 " gives the integer with 1s at positions where either ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " have 1s, but not both."
}], "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BaseForm", "[", 
  RowBox[{
   RowBox[{"BitXor", "[", 
    RowBox[{"2^^10101", ",", "2^^10011"}], "]"}], ",", "2"}], "]"}]], "Input",\

 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"In[25]:="],

Cell[BoxData[
 TagBox[
  InterpretationBox[
   SubscriptBox["\<\"110\"\>", "\<\"2\"\>"],
   6,
   Editable->False],
  BaseForm[#, 2]& ]], "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"},
 CellLabel->"Out[25]//BaseForm="]
}, Closed]],

Cell[BoxData[
 FormBox[GridBox[{
    {
     StyleBox[
      RowBox[{"Functional", " ", "form"}], "TB"], 
     StyleBox["Meaning", "TB"]},
    {
     RowBox[{
      StyleBox["BitAnd", "MR"], 
      StyleBox["[", "MR"], 
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox[",", "MR"], 
       StyleBox["y", "TI"]}], 
      StyleBox["]", "MR"]}], 
     StyleBox[
      RowBox[{
      "bitwise", " ", "AND", " ", "of", " ", "x", " ", "and", " ", "y"}], 
      "TR"]},
    {
     RowBox[{
      StyleBox["BitOr", "MR"], 
      StyleBox["[", "MR"], 
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox[",", "MR"], 
       StyleBox["y", "TI"]}], 
      StyleBox["]", "MR"]}], 
     StyleBox[
      RowBox[{
      "bitwise", " ", "OR", " ", "of", " ", "x", " ", "and", " ", "y"}], "TR"]},
    {
     RowBox[{
      StyleBox["BitNot", "MR"], 
      StyleBox["[", "MR"], 
      StyleBox["x", "TI"], 
      StyleBox["]", "MR"]}], 
     RowBox[{"bitwise", " ", "NOT", " ", "of", " ", "x"}]},
    {
     RowBox[{
      StyleBox["BitXor", "MR"], 
      StyleBox["[", "MR"], 
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox[",", "MR"], 
       StyleBox["y", "TI"]}], 
      StyleBox["]", "MR"]}], 
     StyleBox[
      RowBox[{
      "bitwise", " ", "XOR", " ", "of", " ", "x", " ", "and", " ", "y"}], 
      "TR"]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{True}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, True, {False}, True}, "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {True, {
        Offset[0.5599999999999999]}, True}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {
        Offset[0.5]}, True}, "RowsIndexed" -> {}}], 
  DefaultTraditionalFormatType]], "DisplayTable",
 CellTags->{"i:44", "b:4.1", "IPM3.2.3.2"}],

Cell["Bitwise operators", "NumberedTable",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell["\<\
In Chapter 4 we will look at an application of bitwise operators to an \
example involving error-correcting codes: the computation of Hamming distance.\
\>", "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSubsection",
 CellTags->{"b:4.1", "IPM3.2.3.3", "c:18"}],

Cell[TextData[{
 "Create a predicate function that returns a value of ",
 StyleBox["True", "MR"],
 " if its argument is between ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]]],
 " and 1."
}], "ExerciseItem",
 CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],

Cell[TextData[{
 "Write a predicate function ",
 StyleBox["NaturalQ[", "MR"],
 StyleBox["n", "IT"],
 StyleBox["]", "MR"],
 " that returns a value of ",
 StyleBox["True", "MR"],
 " if ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " is a natural number and ",
 StyleBox["False", "MR"],
 " otherwise; that is, ",
 StyleBox["NaturalQ[", "MR"],
 StyleBox["n", "IT"],
 StyleBox["]", "MR"],
 " is ",
 StyleBox["True", "MR"],
 " if ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " is among 0, 1, 2, 3, \[Ellipsis]."
}], "ExerciseItem",
 CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],

Cell[CellGroupData[{

Cell[TextData[{
 "Create a predicate function ",
 StyleBox["SubsetQ[", "MR"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["lis", "IT"], "1"], TraditionalForm]]],
 StyleBox[",\[ThinSpace]", "MR"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["lis", "IT"], "2"], TraditionalForm]]],
 StyleBox["]", "MR"],
 " that returns a value of ",
 StyleBox["True", "MR"],
 " if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["lis", "IT"], "1"], TraditionalForm]]],
 " is a subset of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["lis", "IT"], "2"], TraditionalForm]]],
 ". Remember: the empty set ",
 StyleBox["{}", "MR"],
 ", is a subset of every set."
}], "ExerciseItem",
 CellTags->{"i:47", "b:4.1", "IPM3.2.3.3"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "f"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]}], "NonPrintInput",
 CellLabel->"In[27]:="],

Cell["", "SectionSpacer"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Attributes", "Section",
 CellTags->{"b:5", "IPM3.2.4", "c:19"}],

Cell[TextData[{
 "All functions in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " have certain properties, called ",
 StyleBox["attributes", "TermDefinition"],
 ". These attributes can make a function commutative or associative, or they \
may give the function the ability to be threaded over a list. The attributes \
of any function are displayed with the ",
 StyleBox["Attributes", "MR"],
 " function."
}], "TextFirst",
 CellTags->{"i:48", "b:5", "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "Plus", "]"}]], "Input",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"In[1]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Flat", ",", "Listable", ",", "NumericFunction", ",", "OneIdentity", ",", 
   "Orderless", ",", "Protected"}], "}"}]], "Output",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"Out[1]="]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["Flat", "MR"],
 " attribute indicates that this function (",
 StyleBox["Plus", "MR"],
 ") is associative. That is, given three elements to add, it does not matter \
which two are added first. In mathematics, this is known as ",
 StyleBox["associativity", "TermDefinition"],
 " and is written as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", "+", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "+", "b"}], ")"}], "+", "c"}]}], TraditionalForm]]],
 ". In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " this could be indicated by saying that the two expressions ",
 StyleBox["Plus[a, Plus[b, c]]", "MR"],
 " and ",
 StyleBox["Plus[Plus[a, b], c]", "MR"],
 " are equivalent to the flattened form ",
 StyleBox["Plus[a, b, c]", "MR"],
 ". When ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " knows that a function has the attribute ",
 StyleBox["Flat", "MR"],
 ", it writes it in flattened form."
}], "Text",
 CellTags->{"i:49", "b:5", "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plus", "[", 
  RowBox[{
   RowBox[{"Plus", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ",", "c"}], "]"}]], "Input",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{"a", "+", "b", "+", "c"}]], "Output",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"Out[2]="]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["Orderless", "MR"],
 " attribute indicates that the function is commutative; that is, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", "+", "b"}], "=", 
    RowBox[{"b", "+", "a"}]}], TraditionalForm]]],
 ". This allows ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to write such an expression in an order that is useful for computation. It \
does this by sorting the elements into a ",
 StyleBox["canonical order", "TermDefinition"],
 ". For expressions consisting of letters and words, this ordering is \
alphabetic."
}], "Text",
 CellTags->{"i:50", "b:5", "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "+", "h", "+", "i", "+", "n"}]], "Input",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"In[3]:="],

Cell[BoxData[
 RowBox[{"h", "+", "i", "+", "n", "+", "t"}]], "Output",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"Out[3]="]
}, Closed]],

Cell["Sometimes a canonical order is readily apparent.", "Text",
 CellTags->{"b:5", "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "3"], "+", 
  SuperscriptBox["x", "5"], "+", 
  SuperscriptBox["x", "4"], "+", 
  SuperscriptBox["x", "2"], "+", "1", "+", "x"}]], "Input",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{"1", "+", "x", "+", 
  SuperscriptBox["x", "2"], "+", 
  SuperscriptBox["x", "3"], "+", 
  SuperscriptBox["x", "4"], "+", 
  SuperscriptBox["x", "5"]}]], "Output",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"Out[4]="]
}, Closed]],

Cell["Other times, it is not so apparent.", "TextFirst",
 CellTags->{"b:5", "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["y", "7"], " ", 
   SuperscriptBox["x", "5"]}], "+", 
  RowBox[{"y", " ", 
   SuperscriptBox["x", "4"]}], "+", 
  RowBox[{
   SuperscriptBox["y", "9"], " ", 
   SuperscriptBox["x", "2"]}], "+", "1", "+", "x"}]], "Input",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"In[5]:="],

Cell[BoxData[
 RowBox[{"1", "+", "x", "+", 
  RowBox[{
   SuperscriptBox["x", "4"], " ", "y"}], "+", 
  RowBox[{
   SuperscriptBox["x", "3"], " ", 
   SuperscriptBox["y", "2"]}], "+", 
  RowBox[{
   SuperscriptBox["x", "5"], " ", 
   SuperscriptBox["y", "7"]}], "+", 
  RowBox[{
   SuperscriptBox["x", "2"], " ", 
   SuperscriptBox["y", "9"]}]}]], "Output",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"Out[5]="]
}, Closed]],

Cell[TextData[{
 "When a symbol has the attribute ",
 StyleBox["Protected", "MR"],
 ", the user is prevented from modifying the function in any significant way. \
All built-in operations have this attribute."
}], "Text",
 CellTags->{"i:51", "b:5", "IPM3.2.4"}],

Cell[TextData[{
 "Functions with the attribute ",
 StyleBox["OneIdentity", "MR"],
 " have the property that repeated application of the function to the same \
argument will have no effect. For example, the expression ",
 StyleBox["Plus[Plus[a, b]]", "MR"],
 " is equivalent to ",
 StyleBox["Plus[a, b]", "MR"],
 ", hence only one addition is performed."
}], "Text",
 CellTags->{"i:52", "b:5", "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"Plus", "[", 
   RowBox[{"Plus", "[", 
    RowBox[{"a", "+", "b"}], "]"}], "]"}], "]"}]], "Input",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"In[6]:="],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Plus", "[", 
    RowBox[{"a", ",", "b"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"Out[6]//FullForm="]
}, Closed]],

Cell[TextData[{
 "The other attributes for the ",
 StyleBox["Plus", "MR"],
 " function, (",
 StyleBox["Listable", "MR"],
 " and ",
 StyleBox["NumericFunction", "MR"],
 ") will be discussed in later chapters. Consult the manual (Wolfram 2003) \
for a complete list of the ",
 StyleBox["Attributes", "MR"],
 " that symbols can have."
}], "Text",
 CellTags->{"b:5", "IPM3.2.4"}],

Cell[TextData[{
 "Although it is unusual to want to alter the attributes of a built-in \
function, it is fairly common to change the default attributes of a \
user-defined function. For example, suppose you had a function which you \
wanted to inherit the ",
 StyleBox["Orderless", "MR"],
 " attribute. Without explicitly setting that attribute, the function does \
not reorder its arguments."
}], "Text",
 CellTags->{"b:5", "IPM3.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"x", ",", "a", ",", "m"}], "]"}]], "Input",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"In[7]:="],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"x", ",", "a", ",", "m"}], "]"}]], "Output",
 CellTags->{"b:5", "IPM3.2.4"},
 CellLabel->"Out[7]="]
}, Closed]],

Cell[TextData[{
 "The ",
 StyleBox["SetAttributes", "MR"],
 " function is used to change the attributes of a function. Explicitly \
setting ",
 StyleBox["f", "MR"],
 " to have the ",
 StyleBox["Orderless", "MR"],
 " attribute causes its arguments to be automatically sorted."
}], "TextFirst",
 CellTags->{"i:53", "b:5", "IPM3.2.4"}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"f", ",", "Orderless"}], "]"}]], "Input",
 CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"x", ",", "a", ",", "m"}], "]"}]], "Input",
 CellLabel->"In[9]:="],

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"a", ",", "m", ",", "x"}], "]"}]], "Output",
 CellLabel->"Out[9]="]
}, Closed]],

Cell[TextData[{
 "We will see some applications of ",
 StyleBox["SetAttributes", "MR"],
 " in Sections 4.2 and 5.3."
}], "Text",
 CellTags->{"b:5", "IPM3.2.4"}],

Cell[" ", "Text",
 PageBreakAbove->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Meta-Information", "NonPrintSection",
 InitializationGroup->True,
 CellTags->"2. inits"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "NonPrintInput",
 CellTags->"2. inits",
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"TruthTable", "[", 
   RowBox[{"expr_", ",", "vars_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"len", "=", 
       RowBox[{"Length", "[", "vars", "]"}]}], ",", "n"}], "}"}], ",", 
    RowBox[{
     RowBox[{"ins", "=", 
      RowBox[{"Distribute", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"True", ",", " ", "False"}], "}"}], ",", " ", 
          RowBox[{"{", "len", "}"}]}], "]"}], ",", " ", "List", ",", " ", 
        "List", ",", " ", "List"}], "]"}]}], 
     StyleBox[";",
      FormatType->StandardForm], 
     RowBox[{"res", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"expr", "/.", "\[InvisibleSpace]", 
          RowBox[{"Thread", "[", 
           RowBox[{"vars", "\[Rule]", "#1"}], "]"}]}], "&"}], ")"}], "/@", 
       "ins"}]}], ";", 
     RowBox[{"DisplayForm", "[", 
      RowBox[{"GridBox", "[", 
       RowBox[{
        RowBox[{"Prepend", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"Append", "[", 
             RowBox[{
              RowBox[{"Transpose", "[", "ins", "]"}], ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"!", 
                    RowBox[{"MemberQ", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"True", ",", "False"}], "}"}], ",", "#1"}], 
                    "]"}]}], ",", "\"\<*\>\"", ",", "#1"}], "]"}], "&"}], 
                ")"}], "/@", "res"}]}], "]"}], "]"}], "/.", 
           "\[InvisibleSpace]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"True", "\[Rule]", "\"\<T\>\""}], ",", 
             RowBox[{"False", "\[Rule]", "\"\<F\>\""}]}], "}"}]}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{"vars", ",", 
            RowBox[{"TraditionalForm", "[", "expr", "]"}]}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"GridFrame", "\[Rule]", "True"}], ",", 
        RowBox[{"RowLines", "\[Rule]", 
         RowBox[{"Prepend", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "res", "]"}], "-", "1"}], "}"}]}], 
            "]"}], ",", "2"}], "]"}]}], ",", 
        RowBox[{"ColumnLines", "\[Rule]", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Length", "[", "vars", "]"}], "-", "1"}], "}"}]}], 
            "]"}], ",", "2"}], "]"}]}]}], "]"}], "]"}]}]}], 
   "]"}]}]], "NonPrintInput",
 CellTags->"2. inits",
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "NonPrintInput",
 CellTags->"2. inits",
 CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Production",
WindowSize->{880, 716},
WindowMargins->{{Automatic, 178}, {Automatic, 1}},
PrintingCopies->1,
PrintingStartingPageNumber->31,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, 
   Cell[
    TextData[{"An Introduction to Programming with ", 
      StyleBox["Mathematica", "IT"]}], "Header"]}, {
   Cell[
    TextData[{"2 The ", 
      StyleBox["Mathematica ", "IT"], "language"}], "Header"], Inherited, 
   Inherited}},
PrintingOptions->{"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
ShowSelection->True,
TaggingRules:>{
 "PaginationCache" -> {{
    2004, 10, 8, 11, 32, 21.4329984`9.083657863422237}, CompressedData["
1:eJxtxMsNgCAQBcC1EkFF/OAXK7EEGvBo+5qYGHb3zWFsus5UENH9Vv4MZJUK
qKEGc0KLeKXTemZgRiFgkzIDS26VNm6XYub4PGycPfY=
    "], Automatic}},
CellLabelAutoDelete->False,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 12, \
2010)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for\n\n", 
         StyleBox[
         "An Introduction to Programming with Mathematica, 4th", FontSlant -> 
          "Italic"], " edition"}], "Subtitle", Editable -> True], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section", Editable -> True], 
         Cell[
          StyleData[All, "Printout"], Editable -> True, PageWidth -> 
          PaperWidth, 
          CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {"HighlightMisspelledWords" -> False}, 
          ScriptMinSize -> 5, MenuSortingValue -> 1500, 
          PrivateFontOptions -> {"FontType" -> "Outline"}, Magnification -> 
          1.]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section", Editable -> True], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Notebook"], Editable -> True, PageHeaders -> {{
                Cell[
                 TextData[{
                   CounterBox["Page"]}], "PageNumber"], None, 
                Cell[
                 TextData[{
                   ValueBox["FileName"]}], "Header"]}, {
                Cell[
                 TextData[{
                   ValueBox["FileName"]}], "Header"], None, 
                Cell[
                 TextData[{
                   CounterBox["Page"]}], "PageNumber"]}}, ShowCellBracket -> 
             Automatic, StyleMenuListing -> None], 
            Cell[
             StyleData["Notebook", "Printout"], 
             PrintingOptions -> {
              "CellBackgroundHalftoneAngle" -> Automatic, 
               "CellBackgroundHalftoneDensity" -> Automatic, "FacingPages" -> 
               True, "FirstPageFace" -> Right, "FirstPageFooter" -> True, 
               "FirstPageHeader" -> False, "GraphicsPrintingFormat" -> 
               "Automatic", "PageFooterMargins" -> {Automatic, Automatic}, 
               "PageHeaderMargins" -> {Automatic, Automatic}, 
               "PageSize" -> {494, 701}, "PaperOrientation" -> "Portrait", 
               "PaperSize" -> {Automatic, Automatic}, "PostScriptOutputFile" :> 
               "Automatic", "PrintCellBrackets" -> False, 
               "PrintMultipleHorizontalPages" -> False, 
               "PrintRegistrationMarks" -> True, "PrintSelectionHighlighting" -> 
               False, "PrintingMargins" -> {{54, 54}, {72, 72}}, 
               "RestPagesFooter" -> True, "RestPagesHeader" -> True, 
               "UnixShellPrintingCommand" -> Automatic, 
               "UsePostScriptOutputFile" -> False, 
               "UseUnixShellPrintingCommand" -> False}, CellFrameLabelMargins -> 
             6]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], Editable -> True, 
             CellMargins -> {{0, 0}, {24, 0}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, CellFrameMargins -> 
             20, LineSpacing -> {1, 6}, CounterIncrements -> "Chapter", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, 
             MenuSortingValue -> 1100, MenuCommandKey -> "1", FontFamily -> 
             "Times", FontSize -> 24, FontWeight -> "Bold", Background -> 
             RGBColor[0.89, 0.89, 0.89]], 
            Cell[
             StyleData["Chapter", "Printout"], 
             CellMargins -> {{0, Inherited}, {36, 18}}, FontFamily -> 
             "Janson Text LT Std Bold", FontSize -> 26, FontWeight -> "Plain",
              Background -> None]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], Editable -> True, 
             CellFrame -> {{0, 0}, {0, 0}}, 
             CellMargins -> {{12, Inherited}, {0, 15}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameLabels -> {{
                Cell[
                 TextData[{
                   StyleBox[
                    CounterBox["Chapter"], FontFamily -> "Janson Text Lt Std",
                     FontSize -> 14], 
                   StyleBox[
                   ".", FontFamily -> "Janson Text Lt Std", FontSize -> 14], 
                   StyleBox[
                    CounterBox["Section"], FontFamily -> "Janson Text Lt Std",
                     FontSize -> 14], " "}], "SectionLabel", CellBaseline -> 
                 Baseline], None}, {None, None}}, CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
               "Exercise", 0}}, MenuSortingValue -> 1200, MenuCommandKey -> 
             "4", CounterStyleMenuListing -> None, FontFamily -> "Times", 
             FontSize -> 20, FontWeight -> "Bold"], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{0, 0}, {6, 6}}, FontFamily -> 
             "Janson Text LT Std", FontSize -> 14, FontWeight -> "Plain"]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SectionLabel"], Editable -> True, 
             ConversionRules :> {{"TeX" -> {"", 
                  NoOutput[], ""}}, {"HTML" -> {"<!--", "-->"}}}, 
             CellSize -> {24, Inherited}, TextAlignment -> Right, 
             StyleMenuListing -> None, FontWeight -> "Bold"], 
            Cell[
             StyleData[
             "SectionLabel", "Printout", StyleDefinitions -> None]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], Editable -> True, CellDingbat -> None, 
             CellMargins -> {{12, Inherited}, {5, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterAssignments -> {{"Subsubsection", 0}}, 
             MenuSortingValue -> 1250, MenuCommandKey -> "5", 
             CounterStyleMenuListing -> None, FontSize -> 16, FontWeight -> 
             "Bold", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{0, 0}, {6, 6}}, FontFamily -> 
             "Janson Text Lt Std", FontSize -> 11, FontSlant -> "Italic"]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], Editable -> True, CellDingbat -> 
             "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica"}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subsubsection", StyleMenuListing -> None, FontFamily -> "Times",
              FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Printout"], CellDingbat -> None, 
             CellMargins -> {{0, 0}, {0, 6}}, FontFamily -> "Janson Text", 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TitleBar"], Editable -> True, 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellFrameMargins -> {{18, 0}, {6, 6}}, LanguageCategory -> 
             "NaturalLanguage", StyleMenuListing -> None, FontFamily -> 
             "Times", FontSize -> 12, FontWeight -> "Bold", FontSlant -> 
             "Italic", FontColor -> GrayLevel[0.900008], Background -> 
             RGBColor[0.501961, 0.501961, 0.752941]], 
            Cell[
             StyleData["TitleBar", "Printout"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TextFirst"], Editable -> True, 
             CellMargins -> {{12, 10}, {7, 7}}, Hyphenation -> True, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Text", 
             MenuSortingValue -> 1300, MenuCommandKey -> "6", FontFamily -> 
             "Times"], 
            Cell[
             StyleData["TextFirst", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, TextJustification -> 1, 
             LineSpacing -> {1, 2}, FontFamily -> "Janson Text Lt Std", 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], Editable -> True, 
             CellMargins -> {{12, 10}, {7, 7}}, Hyphenation -> True, 
             LineSpacing -> {1, 3}, ParagraphIndent -> 24, CounterIncrements -> 
             "Text", MenuSortingValue -> 1310, MenuCommandKey -> "7", 
             FontFamily -> "Times", FontSize -> 12, FontWeight -> "Plain", 
             FontSlant -> "Plain"], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             TextJustification -> 1, LineSpacing -> {1, 2}, ParagraphIndent -> 
             24, FontFamily -> "Janson Text LT Std", FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], Editable -> True], 
            Cell[
             StyleData["Item", "Printout"], CellMargins -> {{24, 4}, {6, 6}}, 
             LineSpacing -> {1, 2}, FontFamily -> "Janson Text Lt Std", 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], Editable -> True], 
            Cell[
             StyleData["Subitem", "Printout"], 
             CellMargins -> {{48, 4}, {0, 6}}, LineSpacing -> {1, 2}, 
             FontFamily -> "Janson Text Lt Std", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedText"], Editable -> True, 
             CellMargins -> {{26, 4}, {0, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 45}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{
                   CounterBox["ItemNumber"], "."}], "ExerciseItemNumber", 
                 CellBaseline -> Baseline], None}, {None, None}}, Hyphenation -> 
             True, LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "ItemNumber", MenuSortingValue -> 1340, 
             MenuCommandKey -> None], 
            Cell[
             StyleData["ItemizedText", "Printout"], 
             CellMargins -> {{14, 0}, {0, 6}}, LineSpacing -> {1, 2}, 
             FontFamily -> "Janson Text Lt Std", FontSize -> 10]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], Editable -> True, 
             CellMargins -> {{60, 10}, {5, 7}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             DefaultFormatType -> DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Formula", FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> 
             "Input", MenuSortingValue -> 1500, MenuCommandKey -> "9", 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{52, 0}, {3, 6}},
              LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], Editable -> True, 
             CellMargins -> {{60, 10}, {7, 5}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Formula", FormatType -> 
             InputForm, CounterIncrements -> "Output", MenuSortingValue -> 
             1550], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{52, 0}, {6, 3}}, FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], Editable -> True, 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Message", StyleMenuListing -> None, 
             FontSize -> 11, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{52, Inherited}, {6, 3}}, FontSize -> 9, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], Editable -> True, 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Print", StyleMenuListing -> None], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{24, Inherited}, {6, 3}}, FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], Editable -> True, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Helvetica", 
             FontSize -> 7, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterHeading"], Editable -> True, 
             CellFrame -> {{0, 0}, {1, 0}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, 
             ConversionRules :> {
              "TeX" -> {{"", (#; "")& , ""}, {"", (#; "")& , ""}}}, 
             PageBreakAbove -> True, CellFrameMargins -> False, 
             CounterIncrements -> "ChapterHeading", StyleMenuListing -> None, 
             CounterStyleMenuListing -> None, FontSize -> 30, FontWeight -> 
             "Bold", GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.13999999999999999`]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.4]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["ChapterHeading", "Printout"], FontSize -> 24]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterHead"], Editable -> True, CounterIncrements -> 
             "ChapterHeading", StyleMenuListing -> None, 
             CounterStyleMenuListing -> None, FontFamily -> "Times", FontSize -> 
             24, FontWeight -> "Bold"], 
            Cell[
             StyleData["ChapterHead", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PrefaceSection"], Editable -> True, 
             CellMargins -> {{12, Inherited}, {5, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, StyleMenuListing -> 
             None, FontSize -> 20, FontWeight -> "Bold"], 
            Cell[
             StyleData["PrefaceSection", "Printout"], 
             CellMargins -> {{0, 0}, {6, 6}}, FontFamily -> "Janson Text", 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterAbstract"], Editable -> True, 
             CellMargins -> {{40, 100}, {20, 0}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {1, 2}, StyleMenuListing -> 
             None, FontFamily -> "Times", FontSize -> 11], 
            Cell[
             StyleData["ChapterAbstract", "Printout"], 
             CellMargins -> {{24, 30}, {36, 0}}, TextJustification -> 1, 
             LineSpacing -> {1, 1}, FontFamily -> "Janson Text Lt Std", 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Quote"], Editable -> True, 
             CellMargins -> {{36, 36}, {9, 18}}, Hyphenation -> True, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "Text", StyleMenuListing -> None, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["Quote", "Printout"], 
             CellMargins -> {{24, 26}, {7, 7}}, FontFamily -> "Janson Text", 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["References"], Editable -> True, 
             CellMargins -> {{20, 10}, {0, 6}}, DefaultNewInlineCellStyle -> 
             "None", Hyphenation -> True, LineSpacing -> {1, 3}, 
             StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 12], 
            Cell[
             StyleData["References", "Printout"], 
             CellMargins -> {{0, 2}, {0, 6}}, TextJustification -> 0.5, 
             FontFamily -> "Janson Text", FontSize -> 8.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayTable"], Editable -> True, 
             CellMargins -> {{30, Inherited}, {0, 18}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultTraditionalFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayTable", "Printout"], 
             CellMargins -> {{24, Inherited}, {0, 12}}, FontFamily -> 
             "Janson Text", FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], Editable -> True, 
             CellMargins -> {{24, 10}, {6, 6}}, CellGroupingRules -> 
             "GraphicsGrouping", CellHorizontalScrolling -> True, 
             ShowCellLabel -> False, MenuSortingValue -> 1500, MenuCommandKey -> 
             None], 
            Cell[
             StyleData["Picture", "Printout"], 
             CellMargins -> {{36, 2}, {12, 12}}, Magnification -> 0.7]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["NonPrint Styles", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NonPrintSection"], CellMargins -> {{32, 4}, {4, 8}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[1, 0, 0], "Thickness" -> 0.55}, 
             CellGroupingRules -> {"SectionGrouping", 30}, 
             DefaultNewInlineCellStyle -> "None", LineSpacing -> {1, 7}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontSize -> 20, FontWeight -> "Bold"], 
            Cell[
             StyleData["NonPrintSection", "Printout"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NonPrintInput"], Editable -> True, 
             CellMargins -> {{60, 10}, {5, 7}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[1, 0, 0], "Thickness" -> 0.5}, Evaluatable -> 
             True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Formula", FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> 
             "Input", MenuSortingValue -> 1365, MenuCommandKey -> None, 
             FontSize -> 12, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.3, 0.3, 0.3]], 
            Cell[
             StyleData["NonPrintInput", "Printout"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 0, "ClosedCellHeight" -> 0}, CellOpen -> 
             False, PageBreakAbove -> False]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Editorial"], Editable -> True, 
             CellMargins -> {{24, 10}, {6, 6}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[1, 0, 0], "Thickness" -> 0.5}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Edit:"}], FontFamily -> "Helvetica", FontSize -> 
                 10, FontWeight -> "Bold", CellBaseline -> Baseline], None}, {
               None, None}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
             True, LineSpacing -> {1, 3}, LanguageCategory -> 
             "NaturalLanguage", FontFamily -> "Helvetica", FontSize -> 10, 
             FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Editorial", "Printout"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Automatic Numbering", "Section", Editable -> True], 
         
         Cell[
         "The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.", "Text", Editable -> 
          True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], Editable -> True, 
             CellMargins -> {{55, 10}, {0, 10}}, CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["NumberedEquation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, CounterIncrements -> 
             "NumberedEquation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{55, 55}, {0, 10}}, FontSize -> 10], 
            Cell[
             StyleData["NumberedEquation", "Production"], 
             CellMargins -> {{42, 55}, {0, 10}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigure"], Editable -> True, 
             CellMargins -> {{52, 4}, {0, 8}}, PageBreakAbove -> False, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Figure ", 
                   CounterBox["Chapter"], ".", 
                   CounterBox["NumberedFigure"], ":"}], FontWeight -> "Bold", 
                 CellBaseline -> Baseline], None}, {None, None}}, 
             CounterIncrements -> "NumberedFigure", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica", FontSize -> 9], 
            Cell[
             StyleData["NumberedFigure", "Printout"], FontSize -> 8], 
            Cell[
             StyleData["NumberedFigure", "Production"], 
             CellMargins -> {{24, Inherited}, {12, Inherited}}, FontSize -> 
             7.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTable"], Editable -> True, 
             CellMargins -> {{42, 4}, {0, 8}}, PageBreakAbove -> False, 
             CellFrameMargins -> 8, CellFrameLabels -> {{
                Cell[
                 TextData[{"Table ", 
                   CounterBox["Chapter"], ".", 
                   CounterBox["NumberedTable"], ":"}], FontWeight -> "Bold", 
                 CellBaseline -> Baseline], None}, {None, None}}, 
             CounterIncrements -> "NumberedTable", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica", FontSize -> 9], 
            Cell[
             StyleData["NumberedTable", "Presentation"], 
             CellMargins -> {{42, 4}, {0, 8}}, PageBreakAbove -> False, 
             CellFrameMargins -> 8, CellFrameLabels -> {{
                Cell[
                 TextData[{"Table ", 
                   CounterBox["Chapter"], ".", 
                   CounterBox["NumberedTable"], ":"}], FontWeight -> "Bold", 
                 CellBaseline -> Baseline], None}, {None, None}}, 
             CounterIncrements -> "NumberedTable", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica", FontSize -> 11], 
            Cell[
             StyleData["NumberedTable", "Printout"], 
             CellMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 8], 
            Cell[
             StyleData["NumberedTable", "Production"], 
             CellMargins -> {{24, Inherited}, {12, Inherited}}, FontSize -> 
             7.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ProgramListing"], Editable -> True, 
             CellMargins -> {{42, 4}, {12, 6}}, CellFrameMargins -> 8, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Program Listing ", 
                   CounterBox["Chapter"], ".", 
                   CounterBox["NumberedProgram"], ":"}], FontWeight -> "Bold",
                  CellBaseline -> Baseline], None}, {None, None}}, 
             CounterIncrements -> "NumberedProgram", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica", FontSize -> 9], 
            Cell[
             StyleData["ProgramListing", "Printout"], 
             CellMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10], 
            Cell[
             StyleData["ProgramListing", "Production"], 
             CellMargins -> {{24, Inherited}, {12, 0}}, FontSize -> 7.5]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Inline Formatting", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TR"], Editable -> True, StyleMenuListing -> None, 
             FontFamily -> "Times", FontWeight -> "Plain", FontSlant -> 
             "Plain"], 
            Cell[
             StyleData["TR", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Janson Text", FontWeight -> "Plain", FontSlant -> 
             "Plain"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TI"], Editable -> True, StyleMenuListing -> None, 
             FontFamily -> "Times", FontWeight -> "Plain", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["TI", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Janson Text", FontWeight -> "Plain", FontSlant -> 
             "Italic"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TB"], Editable -> True, StyleMenuListing -> None, 
             FontFamily -> "Times", FontWeight -> "Bold", FontSlant -> 
             "Plain"], 
            Cell[
             StyleData["TB", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Janson Text", FontWeight -> "Bold", FontSlant -> 
             "Plain"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SR"], Editable -> True, StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontWeight -> "Plain", FontSlant -> 
             "Plain"], 
            Cell[
             StyleData["SR", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 9.5, FontWeight -> 
             "Plain", FontSlant -> "Plain"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO10"], Editable -> True, StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 10, FontWeight -> "Plain",
              FontSlant -> "Italic"], 
            Cell[
             StyleData["SO10", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 8, FontWeight -> "Plain", 
             FontSlant -> "Italic"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TermDefinition"], Editable -> True, FontFamily -> 
             "Times", FontWeight -> "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["TermDefinition", "Printout"], FontFamily -> 
             "Janson Text", FontWeight -> "Plain", FontSlant -> "Italic"]}, 
           Closed]], 
         Cell[
          StyleData["SmallCaps"], Editable -> True, StyleMenuListing -> None, 
          FontSize -> 9]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], Editable -> True, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 1, SingleLetterItalics -> True], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], Editable -> True, 
             CellMargins -> {{36, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultTraditionalFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{24, Inherited}, {12, 12}}, FontFamily -> 
             "Janson Text", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], Editable -> True, 
             CellFrame -> {{0, 0}, {0.5, 0.5}}, 
             CellMargins -> {{42, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, Hyphenation -> False, LanguageCategory -> "Formula", 
             ScriptLevel -> 1, FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{24, 0}, {12, 12}}, FontSize -> 9]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section", Editable -> True], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Header"], Editable -> True, 
             CellMargins -> {{0, 0}, {4, 1}}, DefaultNewInlineCellStyle -> 
             "None", LanguageCategory -> "NaturalLanguage", StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 8], 
            Cell[
             StyleData["Header", "Printout"], FontFamily -> "Janson Text", 
             FontSize -> 9.5, FontSlant -> "Italic"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageFooter"], Editable -> True, StyleMenuListing -> 
             None, FontFamily -> "Times", FontSize -> 7.5, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["PageFooter", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageNumber"], Editable -> True, 
             CellMargins -> {{0, 0}, {4, 1}}, StyleMenuListing -> None, 
             FontFamily -> "Times", FontSize -> 9.5, FontWeight -> "Bold"], 
            Cell[
             StyleData["PageNumber", "Printout"], 
             CellMargins -> {{0, 0}, {4, 1}}, StyleMenuListing -> None, 
             FontFamily -> "Janson Text", FontSize -> 9.5, FontWeight -> 
             "Bold"]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Title Page, Contents, and Index", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsTitle"], Editable -> True, 
             CellMargins -> {{21, 4}, {12, 24}}, FontFamily -> "Times", 
             FontSize -> 24, FontWeight -> "Bold"], 
            Cell[
             StyleData["ContentsTitle", "Printout"], 
             CellMargins -> {{24, 0}, {72, 18}}, PageBreakBelow -> False, 
             FontFamily -> "Janson Text", FontSize -> 24, FontWeight -> 
             "Plain"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterNum"], Editable -> True, TextAlignment -> Left,
              StyleMenuListing -> None, CounterStyleMenuListing -> None, 
             FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["ChapterNum", "Printout"], CellSize -> {18, Inherited},
              FontFamily -> "Janson Text", FontSize -> 12, FontWeight -> 
             "Bold"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsChapter"], Editable -> True, 
             CellMargins -> {{36, 4}, {0, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{
                   CounterBox["ChapterNum"], " "}], "ChapterNum", 
                 CellBaseline -> Baseline], None}, {None, None}}, 
             CounterIncrements -> "ChapterNum", StyleMenuListing -> None, 
             FontFamily -> "Times", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["ContentsChapter", "Printout"], 
             CellMargins -> {{2, 0}, {0, 6}}, PageBreakBelow -> False, 
             FontFamily -> "Janson Text", FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsChapterNoNum"], Editable -> True, 
             CellMargins -> {{35, 4}, {0, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, StyleMenuListing -> 
             None, FontFamily -> "Times", FontSize -> 14, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["ContentsChapterNoNum", "Printout"], 
             CellMargins -> {{24, 0}, {0, 6}}, PageBreakBelow -> False, 
             FontFamily -> "Janson Text", FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsSection"], Editable -> True, 
             CellMargins -> {{48, 4}, {0, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 80}, StyleMenuListing -> 
             None, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["ContentsSection", "Printout"], 
             CellMargins -> {{26, 0}, {0, 6}}, PageBreakBelow -> False, 
             FontFamily -> "Janson Text", FontSize -> 10, FontWeight -> 
             "Bold"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ContentsSubsection"], Editable -> True, 
             ShowGroupOpener -> False, CellMargins -> {{50, 4}, {6, 0}}, 
             CellGroupingRules -> {"SectionGrouping", 90}, StyleMenuListing -> 
             None, FontSize -> 10], 
            Cell[
             StyleData["ContentsSubsection", "Printout"], 
             CellMargins -> {{26, 5}, {0, 0}}, FontSize -> 10, FontSlant -> 
             "Italic"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndexSection"], Editable -> True, CellDingbat -> 
             "\[FilledSquare]", CellMargins -> {{20, 4}, {5, 20}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             12, FontWeight -> "Bold"], 
            Cell[
             StyleData["IndexSection", "Printout"], 
             CellMargins -> {{12, 0}, {5, 20}}, PageBreakBelow -> False, 
             FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Index"], Editable -> True, 
             CellMargins -> {{21, 4}, {0, 0}}, ParagraphIndent -> -48, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["Index", "Printout"], CellMargins -> {{13, 0}, {0, 0}},
              FontFamily -> "Janson Text", FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndexSubentry"], Editable -> True, 
             CellMargins -> {{36, 4}, {0, 0}}, ParagraphIndent -> -48], 
            Cell[
             StyleData["IndexSubentry", "Printout"], 
             CellMargins -> {{24, 0}, {0, 0}}, FontFamily -> "Janson Text", 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Index2Column"], Editable -> True, 
             CellMargins -> {{21, 4}, {0, 8}}, ParagraphIndent -> -20, 
             TabSpacings -> 1, StyleMenuListing -> None, FontSize -> 10, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["Index2Column", "Printout"], 
             CellMargins -> {{2, 2}, {6, 6}}, FontFamily -> "Janson Text", 
             FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RuledPageBreak"], Editable -> True, 
             CellFrame -> {{0, 0}, {0.25, 0}}, 
             CellMargins -> {{27, 4}, {12, 0}}, 
             CellFrameMargins -> {{0, 0}, {1, 0}}, FontSize -> 8], 
            Cell[
             StyleData["RuledPageBreak", "Printout"], CellFrame -> False, 
             CellMargins -> {{2, 2}, {6, 6}}, PageBreakBelow -> True, 
             FontSize -> 1]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Leader"], Editable -> True, TabFilling -> ".", 
             StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 12, 
             FontWeight -> "Plain"], 
            Cell[
             StyleData["Leader", "Printout"], FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LeaderNoDots"], Editable -> True, TabFilling -> " ", 
             StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 12, 
             FontWeight -> "Plain"], 
            Cell[
             StyleData["LeaderNoDots", "Printout"], FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageLink"], Editable -> True, StyleMenuListing -> 
             None, ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& )}], 
            Cell[
             StyleData["PageLink", "Printout"], FontColor -> GrayLevel[0]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCPage"], Editable -> True, 
             CellSize -> {22, Inherited}, TextAlignment -> Right, 
             StyleMenuListing -> None, FontSize -> 12, FontWeight -> "Plain"], 
            Cell[
             StyleData["TOCPage", "Printout"], FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCTitle"], Editable -> True, 
             CellMargins -> {{20, 0}, {1, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, TabSpacings -> 46, 
             CounterIncrements -> "TOCTitle", 
             CounterAssignments -> {{"TOCSection", 0}}, 
             CounterStyleMenuListing -> None, FontFamily -> "Helvetica", 
             FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["TOCTitle", "Printout"], 
             CellMargins -> {{12, 0}, {1, 8}}, PageBreakBelow -> False, 
             TabSpacings -> 47.4, FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSection"], Editable -> True, 
             CellMargins -> {{48, 0}, {1, 1}}, 
             CellGroupingRules -> {"SectionGrouping", 75}, TabSpacings -> 
             42.9, CounterIncrements -> "TOCSection", 
             CounterAssignments -> {{"TOCSubsection", 0}}, 
             CounterStyleMenuListing -> None, FontFamily -> "Helvetica", 
             FontSize -> 12], 
            Cell[
             StyleData["TOCSection", "Printout"], 
             CellMargins -> {{30, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSubsubsection"], Editable -> True, 
             CellMargins -> {{104, 0}, {1, 1}}, 
             CellGroupingRules -> {"SectionGrouping", 85}, TabSpacings -> 
             36.7, CounterIncrements -> "TOCSubsubsection", 
             CounterStyleMenuListing -> None, FontSize -> 12], 
            Cell[
             StyleData["TOCSubsubsection", "Printout"], 
             CellMargins -> {{96, 0}, {1, 1}}, PageBreakBelow -> False, 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCTitleDingbat"], Editable -> True, 
             CellSize -> {34, Inherited}, TextAlignment -> Right], 
            Cell[
             StyleData["TOCTitleDingbat", "Printout"], FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSectionDingbat"], Editable -> True, 
             CellSize -> {38, Inherited}, TextAlignment -> Right], 
            Cell[
             StyleData["TOCSectionDingbat", "Printout"], FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TOCSubsectionDingbat"], Editable -> True, 
             CellSize -> {54, Inherited}, TextAlignment -> Right], 
            Cell[
             StyleData["TOCSubsectionDingbat", "Printout"], FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TitlePageGraphic"], Editable -> True, 
             CellMargins -> {{0, 0}, {100, 20}}, Evaluatable -> False, 
             PageBreakBelow -> False, TextAlignment -> Center], 
            Cell[
             StyleData["TitlePageGraphic", "Printout"], 
             CellMargins -> {{0, 0}, {230, 88}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TitlePageLogo"], Editable -> True, 
             CellMargins -> {{0, 0}, {0, 0}}], 
            Cell[
             StyleData["TitlePageLogo", "Printout"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Exercises", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseSubsection"], Editable -> True, 
             CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellMargins -> {{12, 0}, {8, 36}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, 
             LineSpacing -> {1, 6}, LanguageCategory -> "NaturalLanguage", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
               "ExerciseItem", 0}, {"ExerciseSubItem", 0}}, FontFamily -> 
             "Times", FontSize -> 16, FontWeight -> "Bold", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["ExerciseSubsection", "Printout"], 
             CellFrame -> {{0, 0}, {0, 0.5}}, CellMargins -> {{4, 0}, {0, 6}},
              PageBreakBelow -> False, FontFamily -> 
             "Janson Text LT Std Bold", FontSize -> 12, FontWeight -> "Plain",
              FontSlant -> "Plain", FontColor -> GrayLevel[0], Background -> 
             None]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseItem"], Editable -> True, 
             CellMargins -> {{22, 4}, {0, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 45}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{
                   CounterBox["ExerciseItem"], "."}], "ExerciseItemNumber", 
                 CellBaseline -> Baseline], None}, {None, None}}, Hyphenation -> 
             True, LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "ExerciseItem"], 
            Cell[
             StyleData["ExerciseItem", "Printout"], 
             CellMargins -> {{-4, 4}, {0, 6}}, LineSpacing -> {1, 2}, 
             FontFamily -> "Janson Text LT Std", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseSubItem"], Editable -> True, 
             CellMargins -> {{40, 4}, {0, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 45}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{
                   CounterBox["ExerciseSubItem", CounterFunction -> (Part[
                    CharacterRange["a", "z"], #]& )], "."}], 
                 "ExerciseSubItemNumber", CellBaseline -> Baseline], None}, {
               None, None}}, Hyphenation -> True, LineSpacing -> {1, 3}, 
             ParagraphSpacing -> {0, 8}, CounterIncrements -> 
             "ExerciseSubItem"], 
            Cell[
             StyleData["ExerciseSubItem", "Printout"], 
             CellMargins -> {{12, 4}, {2, 4}}, LineSpacing -> {1, 2}, 
             FontFamily -> "Janson Text LT Std", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExercisesNoLabel"], Editable -> True, 
             CellMargins -> {{44, 4}, {0, 8}}, Hyphenation -> True, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterStyleMenuListing -> None], 
            Cell[
             StyleData["ExercisesNoLabel", "Printout"], 
             CellMargins -> {{20, 4}, {0, 0}}, FontFamily -> "Janson Text", 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseItemNumber"], Editable -> True, 
             CellSize -> {20, Inherited}, TextAlignment -> Right, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["ExerciseItemNumber", "Printout"], 
             CellSize -> {18, Inherited}, FontFamily -> "Janson Text", 
             FontSize -> 9.5, FontWeight -> "Plain", FontSlant -> "Italic"]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseSubItemNumber"], Editable -> True, 
             CellSize -> {18, Inherited}, TextAlignment -> Right, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["ExerciseSubItemNumber", "Printout"], FontFamily -> 
             "Janson Text", FontSize -> 10, FontWeight -> "Plain", FontSlant -> 
             "Italic"]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Solutions", "Section", Editable -> True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SolutionsSection"], Editable -> True, CellDingbat -> 
             None, CellMargins -> {{12, Inherited}, {5, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, FontFamily -> "Times", FontSize -> 20, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SolutionsSection", "Printout"], 
             CellMargins -> {{0, 0}, {6, 6}}, FontFamily -> "Janson Text", 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SolutionsSubsection"], Editable -> True, 
             CellMargins -> {{24, 0}, {12, 6}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             LineSpacing -> {1, 7}, LanguageCategory -> "NaturalLanguage", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
               "SolutionItem", 0}}, FontFamily -> "Helvetica", FontSize -> 14,
              FontWeight -> "Bold"], 
            Cell[
             StyleData["SolutionsSubsection", "Printout"], 
             CellMargins -> {{0, 0}, {6, 6}}, FontFamily -> "Janson Text", 
             FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SolutionItem"], Editable -> True, 
             CellMargins -> {{18, 4}, {0, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 55}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{
                   CounterBox["SolutionItem"], "."}], "ExerciseItemNumber", 
                 CellBaseline -> Baseline], None}, {None, None}}, Hyphenation -> 
             True, LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "SolutionItem"], 
            Cell[
             StyleData["SolutionItem", "Printout"], 
             CellMargins -> {{4, 4}, {0, 6}}, FontFamily -> "Janson Text", 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SolutionNoLabel"], Editable -> True, 
             CellMargins -> {{30, 4}, {0, 8}}, Hyphenation -> True, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterStyleMenuListing -> None], 
            Cell[
             StyleData["SolutionNoLabel", "Printout"], 
             CellMargins -> {{0, 4}, {0, 8}}, FontFamily -> "Janson Text", 
             FontSize -> 9]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Spacer Cells", "Section", Editable -> True], 
         Cell[
          StyleData["SectionSpacer", "Working"], Editable -> True, 
          CellDingbat -> 
          Cell["Section spacer", "Menu", FontColor -> GrayLevel[1], FontSize -> 
            8, Background -> GrayLevel[0.67]], 
          CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}], 
         Cell[
          StyleData["SectionSpacer", "Printout"], Editable -> True, 
          CellDingbat -> None, 
          CellMargins -> {{Inherited, Inherited}, {24, 0}}, PageBreakAbove -> 
          False], 
         Cell[
          StyleData["SubsectionSpacer", "Working"], Editable -> True, 
          CellDingbat -> 
          Cell["Subsection spacer", "Menu", FontColor -> GrayLevel[1], 
            FontSize -> 8, Background -> GrayLevel[0.67]], 
          CellBracketOptions -> {"Color" -> RGBColor[1, 0, 0]}], 
         Cell[
          StyleData["SubsectionSpacer", "Printout"], Editable -> True, 
          CellDingbat -> None, 
          CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
          CellElementSpacings -> {"CellMinHeight" -> 0}, PageBreakAbove -> 
          False]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          TextData[{"Styles for ", 
            StyleBox["Mathematica", FontSlant -> "Italic"], 
            " System\[Hyphen]specific Elements"}], "Section", Editable -> 
          True], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Manipulate"], Editable -> True, ShowAutoStyles -> 
             False, ShowStringCharacters -> False, NumberMarks -> False, 
             FontWeight -> "Plain"], 
            Cell[
             StyleData["Manipulate", "Printout"], ShowAutoStyles -> False, 
             ShowStringCharacters -> False, NumberMarks -> False, FontWeight -> 
             "Plain", Magnification -> 0.5]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], Editable -> True, 
             CellMargins -> {{4, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", StripStyleOnPaste -> 
             False, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoStyleOptions -> {"HighlightMisspelledWords" -> False}, 
             LanguageCategory -> "NaturalLanguage", FormatType -> 
             StandardForm, ShowStringCharacters -> False, NumberMarks -> 
             False, CounterIncrements -> "Graphics", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, Arrowheads -> 
             0.04, Dashing -> {}, LineColor -> GrayLevel[0], LineOpacity -> 1,
              EdgeColor -> GrayLevel[0], EdgeOpacity -> 1, EdgeThickness -> 
             Absolute[0.5], EdgeDashing -> {}, FrontFaceColor -> GrayLevel[0],
              BackFaceColor -> GrayLevel[0], FrontFaceOpacity -> 1, 
             BackFaceOpacity -> 1, GraphicsColor -> GrayLevel[0], PointSize -> 
             Absolute[3], Thickness -> Absolute[0.5], Opacity -> 1, DrawEdges -> 
             False, StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 
             10, FontWeight -> "Plain", FontColor -> GrayLevel[0], 
             FontOpacity -> 1, 
             GraphicsBoxOptions -> {DefaultAxesStyle -> Directive[
                 AbsoluteThickness[0.2], Arrowheads -> {}], DefaultFrameStyle -> 
               AbsoluteThickness[0.2], 
               DefaultFrameTicksStyle -> (ScriptLevel -> 1), 
               DefaultGridLinesStyle -> Directive[
                 AbsoluteThickness[0.2], 
                 GrayLevel[0.5]], DefaultTicksStyle -> (ScriptLevel -> 1), 
               ImageSize -> {200, Automatic}}], 
            Cell[
             StyleData["Graphics", "Printout"], 
             ImageMargins -> {{30, Inherited}, {Inherited, 0}}, FontFamily -> 
             "Helvetica", FontSize -> 7, 
             GraphicsBoxOptions -> {ImageSize -> {200, Automatic}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "Graphics3D", StyleDefinitions -> StyleData["Graphics"]], 
             Editable -> True, Dashing -> {}, LineColor -> GrayLevel[0], 
             LineOpacity -> 1, EdgeColor -> GrayLevel[0], EdgeOpacity -> 1, 
             EdgeThickness -> Absolute[0.5], EdgeDashing -> {}, 
             FrontFaceColor -> GrayLevel[1], FrontFaceGlowColor -> 
             GrayLevel[0], FrontFaceSpecularColor -> GrayLevel[0], 
             FrontFaceSpecularExponent -> 1.5, BackFaceColor -> GrayLevel[1], 
             BackFaceGlowColor -> GrayLevel[0], BackFaceSpecularColor -> 
             GrayLevel[0], BackFaceSpecularExponent -> 1.5, FrontFaceOpacity -> 
             1, BackFaceOpacity -> 1, GraphicsColor -> GrayLevel[0], 
             PointSize -> Absolute[3], Thickness -> Absolute[0.5], Opacity -> 
             1, DrawEdges -> True, DrawFrontFaces -> True, DrawBackFaces -> 
             True, FontColor -> GrayLevel[0], FontOpacity -> 1, 
             Graphics3DBoxOptions -> {
              DefaultAxesStyle -> AbsoluteThickness[0.2], DefaultBoxStyle -> 
               Directive[
                 AbsoluteThickness[0.2], 
                 GrayLevel[0.4]], DefaultFaceGridsStyle -> Directive[
                 AbsoluteThickness[0.2], 
                 GrayLevel[0.66]], DefaultTicksStyle -> (ScriptLevel -> 1)}], 
            
            Cell[
             StyleData["Graphics3D", "Printout"], 
             ImageMargins -> {{30, Inherited}, {Inherited, 0}}, FontFamily -> 
             "Helvetica", FontSize -> 7, 
             Graphics3DBoxOptions -> {ImageSize -> {240, Automatic}}]}, 
           Closed]], 
         Cell[
          StyleData["InlineCellEditing"], Editable -> True, StyleMenuListing -> 
          None, Background -> RGBColor[0.864706, 0.829412, 0.739216]]}, 
        Closed]]}, Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 12, 2010)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"],
PrivateNotebookOptions -> {"NotebookAuthor" -> ""}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "IPM3.2.0"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[1105, 43, 656, 14, 149, "ChapterAbstract",
   CellTags->"IPM3.2.0"]},
 "IPM3.2.1.1"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}]},
 "IPM3.2.1.2"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}]},
 "IPM3.2.1.3"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}]},
 "IPM3.2.1.4"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}]},
 "IPM3.2.1.5"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}]},
 "IPM3.2.2.1"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[33085, 1293, 141, 3, 35, "Section",
   CellTags->{
    "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
     "IPM3.2.2.6", "c:8"}],
  Cell[33251, 1300, 97, 1, 60, "Subsection",
   CellTags->{"b:3.0", "IPM3.2.2.1", "c:9"}],
  Cell[33351, 1303, 737, 13, 153, "TextFirst",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34091, 1318, 199, 6, 39, "Text",
   PageBreakAbove->True,
   CellTags->{"i:13", "b:3.0", "IPM3.2.2.1"}],
  Cell[34315, 1328, 159, 5, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34477, 1335, 104, 2, 168, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34596, 1340, 343, 12, 55, "TextFirst",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34964, 1356, 115, 3, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[35082, 1361, 89, 2, 168, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[35186, 1366, 188, 7, 32, "TextFirst",
   CellTags->{"i:14", "b:3.0", "IPM3.2.2.1"}],
  Cell[35399, 1377, 103, 3, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[35505, 1382, 87, 1, 140, "Print",
   CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}],
  Cell[35595, 1385, 731, 20, 140, "Print",
   CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}],
  Cell[36341, 1408, 319, 9, 55, "Text",
   CellTags->{"i:15", "b:3.0", "IPM3.2.2.1"}],
  Cell[36685, 1421, 182, 6, 64, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[36870, 1429, 130, 4, 245, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[37015, 1436, 627, 20, 101, "TextFirst",
   CellTags->{"i:16", "b:3.0", "IPM3.2.2.1"}],
  Cell[37645, 1458, 255, 8, 62, "Text",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[37925, 1470, 114, 3, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38042, 1475, 105, 2, 168, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38184, 1482, 113, 3, 29, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38300, 1487, 107, 3, 245, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38444, 1495, 144, 4, 38, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38591, 1501, 162, 5, 245, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38768, 1509, 127, 2, 32, "TextFirst",
   PageBreakAbove->True,
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38898, 1513, 197, 5, 47, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}]},
 "IPM3.2.2.2"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[33085, 1293, 141, 3, 35, "Section",
   CellTags->{
    "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
     "IPM3.2.2.6", "c:8"}],
  Cell[39163, 1525, 99, 1, 36, "Subsection",
   CellTags->{"b:3.1", "IPM3.2.2.2", "c:10"}],
  Cell[39265, 1528, 598, 9, 487, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[39866, 1539, 385, 15, 168, "Text",
   CellTags->{"i:17", "b:3.1", "IPM3.2.2.2"}],
  Cell[40254, 1556, 121, 5, 233, "Program",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[40378, 1563, 338, 10, 168, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[40719, 1575, 241, 7, 272, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41202, 1594, 144, 4, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41349, 1600, 105, 2, 151, "Output",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41469, 1605, 334, 10, 272, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41806, 1617, 471, 17, 272, "Text",
   CellTags->{"i:18", "b:3.1", "IPM3.2.2.2"}],
  Cell[42280, 1636, 122, 5, 233, "Program",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[42405, 1643, 213, 7, 168, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[42621, 1652, 146, 4, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[42770, 1658, 272, 7, 272, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43045, 1667, 158, 6, 168, "Text",
   PageBreakAbove->True,
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43228, 1677, 169, 5, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43400, 1684, 264, 7, 158, "Output",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43679, 1694, 319, 9, 257, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[44023, 1707, 108, 3, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[44134, 1712, 91, 1, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}],
  Cell[44228, 1715, 740, 20, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}],
  Cell[44983, 1738, 189, 5, 150, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[45197, 1747, 169, 5, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[45369, 1754, 265, 7, 168, "Output",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[45649, 1764, 479, 15, 363, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[46153, 1783, 108, 3, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[46264, 1788, 91, 1, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}],
  Cell[46358, 1791, 758, 21, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}],
  Cell[47131, 1815, 581, 13, 472, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}]},
 "IPM3.2.2.3"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[33085, 1293, 141, 3, 35, "Section",
   CellTags->{
    "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
     "IPM3.2.2.6", "c:8"}],
  Cell[47780, 1835, 86, 1, 36, "Subsection",
   CellTags->{"b:3.2", "IPM3.2.2.3", "c:11"}],
  Cell[47869, 1838, 342, 8, 272, "TextFirst",
   CellTags->{"i:19", "b:3.2", "IPM3.2.2.3"}],
  Cell[48214, 1848, 390, 9, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[48629, 1861, 108, 3, 158, "Input",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[48740, 1866, 382, 9, 340, "Print",
   CellTags->{"b:3.2", "Info3302591258-3722316", "IPM3.2.2.3"}],
  Cell[49137, 1878, 480, 14, 363, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[49642, 1896, 108, 3, 158, "Input",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[49753, 1901, 91, 1, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}],
  Cell[49847, 1904, 740, 20, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}],
  Cell[50602, 1927, 394, 8, 363, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[51021, 1939, 108, 3, 158, "Input",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[51132, 1944, 91, 1, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}],
  Cell[51226, 1947, 758, 21, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}],
  Cell[51999, 1971, 533, 15, 363, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[52535, 1988, 277, 8, 272, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[52815, 1998, 475, 10, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[53293, 2010, 466, 10, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[53762, 2022, 572, 16, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}]},
 "IPM3.2.2.4"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[33085, 1293, 141, 3, 35, "Section",
   CellTags->{
    "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
     "IPM3.2.2.6", "c:8"}],
  Cell[54402, 2045, 93, 1, 36, "Subsection",
   CellTags->{"b:3.3", "IPM3.2.2.4", "c:12"}],
  Cell[54498, 2048, 630, 19, 382, "TextFirst",
   CellTags->{"i:20", "b:3.3", "IPM3.2.2.4"}],
  Cell[55131, 2069, 223, 7, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[55357, 2078, 208, 6, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[55568, 2086, 218, 7, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[55811, 2097, 249, 8, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[56063, 2107, 16774, 729, 1102, 14695, 691, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[72852, 2839, 211, 6, 168, "Text",
   CellTags->{"i:56", "IPM3.2.2.4"}],
  Cell[73088, 2849, 496, 16, 171, "Input",
   CellTags->"IPM3.2.2.4"],
  Cell[73587, 2867, 460, 15, 343, "Output",
   CellTags->"IPM3.2.2.4"],
  Cell[74062, 2885, 393, 8, 363, "Text",
   CellTags->"IPM3.2.2.4"],
  Cell[74458, 2895, 53, 1, 0, "SubsectionSpacer",
   CellTags->"IPM3.2.2.4"]},
 "IPM3.2.2.5"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[33085, 1293, 141, 3, 35, "Section",
   CellTags->{
    "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
     "IPM3.2.2.6", "c:8"}],
  Cell[74548, 2901, 101, 1, 36, "Subsection",
   CellTags->{"b:3.4", "IPM3.2.2.5", "c:13"}],
  Cell[74652, 2904, 793, 23, 487, "TextFirst",
   CellTags->{"i:21", "b:3.4", "IPM3.2.2.5"}],
  Cell[75448, 2929, 198, 5, 168, "Text",
   CellTags->{"i:22", "b:3.4", "IPM3.2.2.5"}],
  Cell[75671, 2938, 132, 4, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[75806, 2944, 365, 8, 102, "Message",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76174, 2954, 88, 2, 168, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76277, 2959, 370, 11, 257, "Text",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76650, 2972, 197, 6, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76850, 2980, 218, 6, 168, "Text",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77071, 2988, 187, 6, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77261, 2996, 230, 7, 257, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77494, 3005, 175, 7, 168, "TextFirst",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77694, 3016, 104, 3, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77801, 3021, 87, 1, 112, "Print",
   CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}],
  Cell[77891, 3024, 1185, 36, 425, "Print",
   CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}],
  Cell[79091, 3063, 425, 7, 363, "TextFirst",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[79519, 3072, 99, 1, 168, "Text",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[79621, 3075, 141, 4, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}]},
 "IPM3.2.2.6"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[33085, 1293, 141, 3, 35, "Section",
   CellTags->{
    "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
     "IPM3.2.2.6", "c:8"}],
  Cell[79956, 3092, 83, 1, 54, "ExerciseSubsection",
   CellTags->{"b:3.4", "IPM3.2.2.6", "c:14"}],
  Cell[80042, 3095, 204, 4, 53, "ExerciseItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80249, 3101, 126, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80378, 3105, 133, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80514, 3109, 134, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80651, 3113, 126, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80802, 3119, 283, 8, 45, "ExerciseItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[81110, 3131, 331, 11, 46, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[81444, 3144, 331, 12, 246, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[81790, 3159, 332, 11, 39, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82125, 3172, 214, 6, 30, "ExercisesNoLabel",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82364, 3182, 113, 3, 36, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82480, 3187, 331, 12, 262, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82848, 3204, 113, 3, 29, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82964, 3209, 192, 6, 168, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[83205, 3221, 331, 11, 53, "ExerciseItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[83539, 3234, 746, 25, 92, "Input",
   CellTags->"IPM3.2.2.6"],
  Cell[84288, 3261, 178, 6, 36, "NonPrintInput",
   CellTags->"IPM3.2.2.6"],
  Cell[84469, 3269, 127, 4, 36, "NonPrintInput",
   CellTags->"IPM3.2.2.6"]},
 "IPM3.2.3.1"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[84657, 3280, 115, 1, 35, "Section",
   CellTags->{"IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", "c:15"}],
  Cell[84797, 3285, 76, 1, 245, "Subsection",
   CellTags->{"b:4.0", "IPM3.2.3.1", "c:16"}],
  Cell[84876, 3288, 766, 13, 596, "TextFirst",
   CellTags->{"i:23", "b:4.0", "IPM3.2.3.1"}],
  Cell[85667, 3305, 128, 3, 158, "Input",
   CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}],
  Cell[85798, 3310, 99, 2, 151, "Output",
   CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}],
  Cell[85912, 3315, 168, 4, 168, "Text",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[86105, 3323, 92, 2, 158, "Input",
   CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}],
  Cell[86200, 3327, 98, 2, 151, "Output",
   CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}],
  Cell[86335, 3334, 93, 2, 158, "Input",
   CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}],
  Cell[86431, 3338, 99, 2, 151, "Output",
   CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}],
  Cell[86567, 3345, 97, 2, 158, "Input",
   CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}],
  Cell[86667, 3349, 99, 2, 151, "Output",
   CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}],
  Cell[86781, 3354, 476, 18, 272, "Text",
   CellTags->{"i:28", "b:4.0", "IPM3.2.3.1"}],
  Cell[87282, 3376, 124, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87409, 3381, 90, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87536, 3388, 130, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87669, 3393, 91, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87775, 3398, 415, 15, 272, "TextFirst",
   CellTags->{"i:29", "b:4.0", "IPM3.2.3.1"}],
  Cell[88215, 3417, 121, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88339, 3422, 90, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88466, 3429, 123, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88592, 3434, 91, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88698, 3439, 185, 4, 168, "Text",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88908, 3447, 138, 3, 158, "Input",
   CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}],
  Cell[89049, 3452, 98, 2, 151, "Output",
   CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}],
  Cell[89184, 3459, 183, 5, 158, "Input",
   CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}],
  Cell[89370, 3466, 99, 2, 151, "Output",
   CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}],
  Cell[89506, 3473, 389, 11, 321, "Input",
   CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}],
  Cell[89898, 3486, 99, 2, 151, "Output",
   CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}],
  Cell[90034, 3493, 312, 10, 246, "Input",
   CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}],
  Cell[90349, 3505, 100, 2, 151, "Output",
   CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}],
  Cell[90486, 3512, 250, 7, 158, "Input",
   CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}],
  Cell[90739, 3521, 99, 2, 151, "Output",
   CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}]},
 "IPM3.2.3.2"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[84657, 3280, 115, 1, 35, "Section",
   CellTags->{"IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", "c:15"}],
  Cell[90918, 3531, 98, 1, 245, "Subsection",
   CellTags->{"b:4.1", "IPM3.2.3.2", "c:17"}],
  Cell[91019, 3534, 897, 36, 382, "TextFirst",
   CellTags->{"i:35", "b:4.1", "IPM3.2.3.2"}],
  Cell[91941, 3574, 117, 3, 158, "Input",
   CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}],
  Cell[92061, 3579, 100, 2, 151, "Output",
   CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}],
  Cell[92198, 3586, 205, 6, 245, "Input",
   CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}],
  Cell[92406, 3594, 99, 2, 151, "Output",
   CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}],
  Cell[92542, 3601, 317, 11, 266, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[92862, 3614, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[92968, 3619, 361, 8, 272, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[93332, 3629, 2374, 83, 835, "DisplayTable",
   CellTags->{"i:38", "b:4.1", "IPM3.2.3.2"}],
  Cell[95709, 3714, 81, 1, 112, "NumberedTable",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[95793, 3717, 266, 5, 272, "Text",
   CellTags->{"i:39", "b:4.1", "IPM3.2.3.2"}],
  Cell[96084, 3726, 156, 5, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[96243, 3733, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[96349, 3738, 499, 15, 272, "Text",
   CellTags->{"i:40", "b:4.1", "IPM3.2.3.2"}],
  Cell[96873, 3757, 229, 7, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[97105, 3766, 571, 19, 627, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[97691, 3788, 348, 11, 168, "Text",
   PageBreakAbove->True,
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98064, 3803, 180, 6, 245, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98247, 3811, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98375, 3818, 193, 6, 245, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98571, 3826, 92, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98678, 3831, 771, 21, 382, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[99474, 3856, 116, 3, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[99593, 3861, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[99699, 3866, 203, 7, 168, "Text",
   CellTags->{"i:41", "b:4.1", "IPM3.2.3.2"}],
  Cell[99927, 3877, 145, 4, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100075, 3883, 92, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100204, 3890, 146, 4, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100353, 3896, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100459, 3901, 112, 1, 168, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100574, 3904, 2656, 97, 737, "DisplayTable",
   CellTags->{"i:42", "b:4.1", "IPM3.2.3.2"}],
  Cell[103233, 4003, 78, 1, 112, "NumberedTable",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[103314, 4006, 746, 23, 382, "Text",
   CellTags->{"i:43", "b:4.1", "IPM3.2.3.2"}],
  Cell[104085, 4033, 218, 7, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[104306, 4042, 220, 8, 235, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[104541, 4053, 445, 17, 168, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[105011, 4074, 219, 7, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[105233, 4083, 217, 8, 235, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[105465, 4094, 1883, 63, 652, "DisplayTable",
   CellTags->{"i:44", "b:4.1", "IPM3.2.3.2"}],
  Cell[107351, 4159, 78, 1, 112, "NumberedTable",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[107432, 4162, 211, 4, 272, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}]},
 "IPM3.2.3.3"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[84657, 3280, 115, 1, 35, "Section",
   CellTags->{"IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", "c:15"}],
  Cell[107711, 4173, 83, 1, 415, "ExerciseSubsection",
   CellTags->{"b:4.1", "IPM3.2.3.3", "c:18"}],
  Cell[107797, 4176, 274, 9, 127, "ExerciseItem",
   CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],
  Cell[108074, 4187, 586, 23, 213, "ExerciseItem",
   CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],
  Cell[108685, 4214, 751, 29, 213, "ExerciseItem",
   CellTags->{"i:47", "b:4.1", "IPM3.2.3.3"}]},
 "IPM3.2.4"->{
  Cell[545, 20, 365, 9, 36, "TitleBar",
   CellTags->{
    "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
     "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
     "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
     "IPM3.2.4"}],
  Cell[109757, 4261, 69, 1, 35, "Section",
   CellTags->{"b:5", "IPM3.2.4", "c:19"}],
  Cell[109829, 4264, 469, 12, 382, "TextFirst",
   CellTags->{"i:48", "b:5", "IPM3.2.4"}],
  Cell[110323, 4280, 121, 3, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[110447, 4285, 225, 6, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[110687, 4294, 1074, 34, 487, "Text",
   CellTags->{"i:49", "b:5", "IPM3.2.4"}],
  Cell[111786, 4332, 192, 6, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[111981, 4340, 115, 3, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[112111, 4346, 624, 18, 382, "Text",
   CellTags->{"i:50", "b:5", "IPM3.2.4"}],
  Cell[112760, 4368, 124, 3, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[112887, 4373, 125, 3, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113027, 4379, 96, 1, 168, "Text",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113148, 4384, 240, 7, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113391, 4393, 241, 7, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113647, 4403, 88, 1, 168, "TextFirst",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113760, 4408, 411, 14, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[114174, 4424, 412, 14, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[114601, 4441, 260, 6, 272, "Text",
   CellTags->{"i:51", "b:5", "IPM3.2.4"}],
  Cell[114864, 4449, 405, 10, 272, "Text",
   CellTags->{"i:52", "b:5", "IPM3.2.4"}],
  Cell[115294, 4463, 204, 6, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[115501, 4471, 271, 10, 235, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[115787, 4484, 375, 12, 272, "Text",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116165, 4498, 437, 9, 382, "Text",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116627, 4511, 142, 4, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116772, 4517, 143, 4, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116930, 4524, 332, 10, 272, "TextFirst",
   CellTags->{"i:53", "b:5", "IPM3.2.4"}],
  Cell[117649, 4554, 160, 5, 168, "Text",
   CellTags->{"b:5", "IPM3.2.4"}]},
 "2. expressions"->{
  Cell[1786, 61, 59, 1, 54, "Section",
   CellTags->"2. expressions"],
  Cell[1848, 64, 132, 3, 33, "Editorial",
   CellTags->"2. expressions"],
  Cell[2005, 71, 63, 1, 60, "Subsection",
   CellTags->"2. expressions"],
  Cell[2071, 74, 650, 18, 108, "TextFirst",
   CellTags->"2. expressions"],
  Cell[2758, 97, 80, 1, 60, "Subsection",
   CellTags->"2. expressions"],
  Cell[2841, 100, 579, 14, 108, "TextFirst",
   CellTags->"2. expressions"],
  Cell[3423, 116, 508, 11, 108, "Text",
   CellTags->"2. expressions"],
  Cell[3934, 129, 266, 7, 62, "Text",
   CellTags->"2. expressions"],
  Cell[4225, 140, 360, 11, 64, "Input",
   CellTags->"2. expressions"],
  Cell[4588, 153, 170, 5, 36, "Output",
   CellTags->"2. expressions"],
  Cell[4773, 161, 236, 8, 62, "Text",
   CellTags->"2. expressions"],
  Cell[5034, 173, 132, 4, 36, "Input",
   CellTags->"2. expressions"],
  Cell[5169, 179, 83, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[5289, 186, 189, 6, 36, "Input",
   CellTags->"2. expressions"],
  Cell[5481, 194, 83, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[5579, 199, 57, 1, 30, "SubsectionSpacer",
   CellTags->"2. expressions"],
  Cell[5673, 205, 56, 1, 60, "Subsection",
   CellTags->"2. expressions"],
  Cell[5732, 208, 451, 12, 85, "TextFirst",
   CellTags->"2. expressions"],
  Cell[6208, 224, 176, 6, 36, "Input",
   CellTags->"2. expressions"],
  Cell[6387, 232, 706, 12, 32, "Message",
   CellTags->"2. expressions"],
  Cell[7096, 246, 233, 7, 36, "Output",
   CellTags->"2. expressions"],
  Cell[7344, 256, 256, 8, 62, "Text",
   CellTags->"2. expressions"],
  Cell[7625, 268, 109, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[7737, 273, 85, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[7859, 280, 117, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[7979, 285, 85, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[8079, 290, 159, 6, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[8263, 300, 257, 7, 36, "Input",
   CellTags->"2. expressions"],
  Cell[8523, 309, 150, 4, 36, "Output",
   CellTags->"2. expressions"],
  Cell[8688, 316, 162, 4, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[8875, 324, 114, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[8992, 329, 85, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[9092, 334, 85, 1, 39, "Text",
   CellTags->"2. expressions"],
  Cell[9202, 339, 115, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[9320, 344, 86, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[9421, 349, 166, 4, 62, "Text",
   CellTags->"2. expressions"],
  Cell[9612, 357, 127, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[9742, 362, 85, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[9842, 367, 440, 9, 108, "Text",
   CellTags->"2. expressions"],
  Cell[10307, 380, 303, 10, 38, "Input",
   CellTags->"2. expressions"],
  Cell[10613, 392, 401, 14, 36, "Output",
   CellTags->"2. expressions"],
  Cell[11051, 411, 118, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[11172, 416, 824, 25, 127, "Output",
   CellTags->"2. expressions"],
  Cell[12033, 446, 113, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[12149, 451, 84, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[12248, 456, 121, 3, 39, "Text",
   CellTags->"2. expressions"],
  Cell[12372, 461, 57, 1, 30, "SubsectionSpacer",
   CellTags->"2. expressions"],
  Cell[12466, 467, 79, 1, 60, "Subsection",
   CellTags->"2. expressions"],
  Cell[12548, 470, 665, 17, 108, "TextFirst",
   CellTags->"2. expressions"],
  Cell[13216, 489, 263, 7, 30, "DisplayFormula",
   CellTags->"2. expressions"],
  Cell[13482, 498, 299, 8, 62, "Text",
   CellTags->"2. expressions"],
  Cell[13806, 510, 143, 4, 36, "Input",
   CellTags->"2. expressions"],
  Cell[13952, 516, 84, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[14051, 521, 157, 5, 39, "Text",
   CellTags->"2. expressions"],
  Cell[14233, 530, 147, 4, 36, "Input",
   CellTags->"2. expressions"],
  Cell[14383, 536, 279, 10, 54, "Output",
   CellTags->"2. expressions"],
  Cell[14699, 551, 171, 5, 36, "Input",
   CellTags->"2. expressions"],
  Cell[14873, 558, 279, 10, 54, "Output",
   CellTags->"2. expressions"],
  Cell[15167, 571, 399, 10, 85, "Text",
   CellTags->"2. expressions"],
  Cell[15569, 583, 526, 13, 108, "Text",
   CellTags->"2. expressions"],
  Cell[16098, 598, 117, 3, 39, "Text",
   CellTags->"2. expressions"],
  Cell[16240, 605, 145, 4, 36, "Input",
   CellTags->"2. expressions"],
  Cell[16388, 611, 81, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[16484, 616, 83, 1, 39, "Text",
   CellTags->"2. expressions"],
  Cell[16592, 621, 293, 10, 45, "Input",
   CellTags->"2. expressions"],
  Cell[16888, 633, 267, 9, 45, "Output",
   CellTags->"2. expressions"],
  Cell[17170, 645, 212, 7, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[17407, 656, 113, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[17523, 661, 85, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[17623, 666, 101, 1, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[17749, 671, 115, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[17867, 676, 81, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[17963, 681, 338, 10, 85, "Text",
   CellTags->"2. expressions"],
  Cell[18326, 695, 117, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[18446, 700, 576, 19, 54, "Output",
   CellTags->"2. expressions"],
  Cell[19037, 722, 506, 13, 108, "Text",
   CellTags->"2. expressions"],
  Cell[19568, 739, 118, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[19689, 744, 86, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[19812, 751, 122, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[19937, 756, 86, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[20038, 761, 136, 3, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[20199, 768, 110, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[20312, 773, 87, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[20436, 780, 113, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[20552, 785, 84, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[20651, 790, 172, 5, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[20848, 799, 114, 3, 36, "Input",
   CellTags->"2. expressions"],
  Cell[20965, 804, 212, 8, 54, "Output",
   CellTags->"2. expressions"],
  Cell[21214, 817, 135, 4, 64, "Input",
   CellTags->"2. expressions"],
  Cell[21352, 823, 273, 10, 54, "Output",
   CellTags->"2. expressions"],
  Cell[21640, 836, 383, 11, 85, "Text",
   CellTags->"2. expressions"],
  Cell[22048, 851, 157, 5, 36, "Input",
   CellTags->"2. expressions"],
  Cell[22208, 858, 81, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[22304, 863, 112, 5, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[22441, 872, 157, 5, 36, "Input",
   CellTags->"2. expressions"],
  Cell[22601, 879, 81, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[22697, 884, 146, 4, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[22868, 892, 137, 4, 36, "Input",
   CellTags->"2. expressions"],
  Cell[23008, 898, 269, 10, 54, "Output",
   CellTags->"2. expressions"],
  Cell[23292, 911, 486, 21, 62, "TextFirst",
   CellTags->"2. expressions"],
  Cell[23781, 934, 176, 6, 39, "Text",
   PageBreakAbove->True,
   CellTags->"2. expressions"],
  Cell[23982, 944, 157, 5, 36, "Input",
   CellTags->"2. expressions"],
  Cell[24142, 951, 84, 2, 36, "Output",
   CellTags->"2. expressions"],
  Cell[24241, 956, 98, 1, 39, "Text",
   CellTags->"2. expressions"],
  Cell[24364, 961, 152, 4, 36, "Input",
   CellTags->"2. expressions"],
  Cell[24519, 967, 437, 9, 52, "Message",
   CellTags->"2. expressions"],
  Cell[24959, 978, 169, 4, 36, "Output",
   CellTags->"2. expressions"],
  Cell[25143, 985, 299, 9, 62, "TextFirst",
   CellTags->"2. expressions"],
  Cell[25445, 996, 115, 3, 39, "Text",
   CellTags->"2. expressions"],
  Cell[25585, 1003, 214, 7, 36, "Input",
   CellTags->"2. expressions"],
  Cell[25802, 1012, 466, 9, 52, "Message",
   CellTags->"2. expressions"],
  Cell[26271, 1023, 234, 7, 36, "Output",
   CellTags->"2. expressions"],
  Cell[26520, 1033, 384, 10, 85, "Text",
   CellTags->"2. expressions"],
  Cell[26929, 1047, 184, 6, 36, "Input",
   CellTags->"2. expressions"],
  Cell[27116, 1055, 136, 4, 36, "Output",
   CellTags->"2. expressions"],
  Cell[27267, 1062, 186, 5, 39, "TextFirst",
   CellTags->"2. expressions"],
  Cell[27478, 1071, 161, 5, 36, "Input",
   CellTags->"2. expressions"],
  Cell[27642, 1078, 331, 12, 54, "Output",
   CellTags->"2. expressions"],
  Cell[28010, 1095, 171, 5, 36, "Input",
   CellTags->"2. expressions"],
  Cell[28184, 1102, 341, 12, 54, "Output",
   CellTags->"2. expressions"],
  Cell[28540, 1117, 303, 11, 40, "TextFirst",
   CellTags->"2. expressions"],
  Cell[28868, 1132, 189, 6, 36, "Input",
   CellTags->"2. expressions"],
  Cell[29060, 1140, 141, 4, 36, "Output",
   CellTags->"2. expressions"],
  Cell[29216, 1147, 760, 22, 112, "Text",
   CellTags->"2. expressions"],
  Cell[30001, 1173, 221, 7, 45, "Input",
   CellTags->"2. expressions"],
  Cell[30225, 1182, 1442, 45, 121, "Output",
   CellTags->"2. expressions"],
  Cell[31682, 1230, 57, 1, 30, "SubsectionSpacer",
   CellTags->"2. expressions"],
  Cell[31776, 1236, 68, 1, 107, "ExerciseSubsection",
   CellTags->"2. expressions"],
  Cell[31847, 1239, 149, 5, 30, "ExerciseItem",
   CellTags->"2. expressions"],
  Cell[31999, 1246, 170, 6, 22, "ExerciseItem",
   CellTags->"2. expressions"],
  Cell[32172, 1254, 226, 5, 45, "ExerciseItem",
   CellTags->"2. expressions"],
  Cell[32401, 1261, 111, 2, 22, "ExerciseSubItem",
   CellTags->"2. expressions"],
  Cell[32515, 1265, 95, 1, 22, "ExerciseSubItem",
   CellTags->"2. expressions"],
  Cell[32635, 1270, 194, 7, 22, "ExerciseItem",
   CellTags->"2. expressions"],
  Cell[32832, 1279, 132, 4, 36, "NonPrintInput",
   CellTags->"2. expressions"],
  Cell[32967, 1285, 57, 1, 30, "SubsectionSpacer",
   CellTags->"2. expressions"]},
 "c:8"->{
  Cell[33085, 1293, 141, 3, 35, "Section",
   CellTags->{
    "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
     "IPM3.2.2.6", "c:8"}]},
 "b:3.0"->{
  Cell[33251, 1300, 97, 1, 60, "Subsection",
   CellTags->{"b:3.0", "IPM3.2.2.1", "c:9"}],
  Cell[33351, 1303, 737, 13, 153, "TextFirst",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34091, 1318, 199, 6, 39, "Text",
   PageBreakAbove->True,
   CellTags->{"i:13", "b:3.0", "IPM3.2.2.1"}],
  Cell[34315, 1328, 159, 5, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34477, 1335, 104, 2, 168, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34596, 1340, 343, 12, 55, "TextFirst",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[34964, 1356, 115, 3, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[35082, 1361, 89, 2, 168, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[35186, 1366, 188, 7, 32, "TextFirst",
   CellTags->{"i:14", "b:3.0", "IPM3.2.2.1"}],
  Cell[35399, 1377, 103, 3, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[35505, 1382, 87, 1, 140, "Print",
   CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}],
  Cell[35595, 1385, 731, 20, 140, "Print",
   CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}],
  Cell[36341, 1408, 319, 9, 55, "Text",
   CellTags->{"i:15", "b:3.0", "IPM3.2.2.1"}],
  Cell[36685, 1421, 182, 6, 64, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[36870, 1429, 130, 4, 245, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[37015, 1436, 627, 20, 101, "TextFirst",
   CellTags->{"i:16", "b:3.0", "IPM3.2.2.1"}],
  Cell[37645, 1458, 255, 8, 62, "Text",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[37925, 1470, 114, 3, 36, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38042, 1475, 105, 2, 168, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38184, 1482, 113, 3, 29, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38300, 1487, 107, 3, 245, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38444, 1495, 144, 4, 38, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38591, 1501, 162, 5, 245, "Output",
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38768, 1509, 127, 2, 32, "TextFirst",
   PageBreakAbove->True,
   CellTags->{"b:3.0", "IPM3.2.2.1"}],
  Cell[38898, 1513, 197, 5, 47, "Input",
   CellTags->{"b:3.0", "IPM3.2.2.1"}]},
 "c:9"->{
  Cell[33251, 1300, 97, 1, 60, "Subsection",
   CellTags->{"b:3.0", "IPM3.2.2.1", "c:9"}]},
 "i:13"->{
  Cell[34091, 1318, 199, 6, 39, "Text",
   PageBreakAbove->True,
   CellTags->{"i:13", "b:3.0", "IPM3.2.2.1"}]},
 "i:14"->{
  Cell[35186, 1366, 188, 7, 32, "TextFirst",
   CellTags->{"i:14", "b:3.0", "IPM3.2.2.1"}]},
 "Info3302591258-2071244"->{
  Cell[35505, 1382, 87, 1, 140, "Print",
   CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}],
  Cell[35595, 1385, 731, 20, 140, "Print",
   CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}]},
 "i:15"->{
  Cell[36341, 1408, 319, 9, 55, "Text",
   CellTags->{"i:15", "b:3.0", "IPM3.2.2.1"}]},
 "i:16"->{
  Cell[37015, 1436, 627, 20, 101, "TextFirst",
   CellTags->{"i:16", "b:3.0", "IPM3.2.2.1"}]},
 "b:3.1"->{
  Cell[39163, 1525, 99, 1, 36, "Subsection",
   CellTags->{"b:3.1", "IPM3.2.2.2", "c:10"}],
  Cell[39265, 1528, 598, 9, 487, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[39866, 1539, 385, 15, 168, "Text",
   CellTags->{"i:17", "b:3.1", "IPM3.2.2.2"}],
  Cell[40254, 1556, 121, 5, 233, "Program",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[40378, 1563, 338, 10, 168, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[40719, 1575, 241, 7, 272, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41202, 1594, 144, 4, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41349, 1600, 105, 2, 151, "Output",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41469, 1605, 334, 10, 272, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[41806, 1617, 471, 17, 272, "Text",
   CellTags->{"i:18", "b:3.1", "IPM3.2.2.2"}],
  Cell[42280, 1636, 122, 5, 233, "Program",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[42405, 1643, 213, 7, 168, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[42621, 1652, 146, 4, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[42770, 1658, 272, 7, 272, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43045, 1667, 158, 6, 168, "Text",
   PageBreakAbove->True,
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43228, 1677, 169, 5, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43400, 1684, 264, 7, 158, "Output",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[43679, 1694, 319, 9, 257, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[44023, 1707, 108, 3, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[44134, 1712, 91, 1, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}],
  Cell[44228, 1715, 740, 20, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}],
  Cell[44983, 1738, 189, 5, 150, "TextFirst",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[45197, 1747, 169, 5, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[45369, 1754, 265, 7, 168, "Output",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[45649, 1764, 479, 15, 363, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[46153, 1783, 108, 3, 158, "Input",
   CellTags->{"b:3.1", "IPM3.2.2.2"}],
  Cell[46264, 1788, 91, 1, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}],
  Cell[46358, 1791, 758, 21, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}],
  Cell[47131, 1815, 581, 13, 472, "Text",
   CellTags->{"b:3.1", "IPM3.2.2.2"}]},
 "c:10"->{
  Cell[39163, 1525, 99, 1, 36, "Subsection",
   CellTags->{"b:3.1", "IPM3.2.2.2", "c:10"}]},
 "i:17"->{
  Cell[39866, 1539, 385, 15, 168, "Text",
   CellTags->{"i:17", "b:3.1", "IPM3.2.2.2"}]},
 "i:18"->{
  Cell[41806, 1617, 471, 17, 272, "Text",
   CellTags->{"i:18", "b:3.1", "IPM3.2.2.2"}]},
 "Info3302591258-1510696"->{
  Cell[44134, 1712, 91, 1, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}],
  Cell[44228, 1715, 740, 20, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}]},
 "Info3302591258-7709797"->{
  Cell[46264, 1788, 91, 1, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}],
  Cell[46358, 1791, 758, 21, 112, "Print",
   CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}]},
 "b:3.2"->{
  Cell[47780, 1835, 86, 1, 36, "Subsection",
   CellTags->{"b:3.2", "IPM3.2.2.3", "c:11"}],
  Cell[47869, 1838, 342, 8, 272, "TextFirst",
   CellTags->{"i:19", "b:3.2", "IPM3.2.2.3"}],
  Cell[48214, 1848, 390, 9, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[48629, 1861, 108, 3, 158, "Input",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[48740, 1866, 382, 9, 340, "Print",
   CellTags->{"b:3.2", "Info3302591258-3722316", "IPM3.2.2.3"}],
  Cell[49137, 1878, 480, 14, 363, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[49642, 1896, 108, 3, 158, "Input",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[49753, 1901, 91, 1, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}],
  Cell[49847, 1904, 740, 20, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}],
  Cell[50602, 1927, 394, 8, 363, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[51021, 1939, 108, 3, 158, "Input",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[51132, 1944, 91, 1, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}],
  Cell[51226, 1947, 758, 21, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}],
  Cell[51999, 1971, 533, 15, 363, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[52535, 1988, 277, 8, 272, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[52815, 1998, 475, 10, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[53293, 2010, 466, 10, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}],
  Cell[53762, 2022, 572, 16, 382, "Text",
   CellTags->{"b:3.2", "IPM3.2.2.3"}]},
 "c:11"->{
  Cell[47780, 1835, 86, 1, 36, "Subsection",
   CellTags->{"b:3.2", "IPM3.2.2.3", "c:11"}]},
 "i:19"->{
  Cell[47869, 1838, 342, 8, 272, "TextFirst",
   CellTags->{"i:19", "b:3.2", "IPM3.2.2.3"}]},
 "Info3302591258-3722316"->{
  Cell[48740, 1866, 382, 9, 340, "Print",
   CellTags->{"b:3.2", "Info3302591258-3722316", "IPM3.2.2.3"}]},
 "Info3302591258-4390566"->{
  Cell[49753, 1901, 91, 1, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}],
  Cell[49847, 1904, 740, 20, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}]},
 "Info3302591258-2230077"->{
  Cell[51132, 1944, 91, 1, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}],
  Cell[51226, 1947, 758, 21, 112, "Print",
   CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}]},
 "b:3.3"->{
  Cell[54402, 2045, 93, 1, 36, "Subsection",
   CellTags->{"b:3.3", "IPM3.2.2.4", "c:12"}],
  Cell[54498, 2048, 630, 19, 382, "TextFirst",
   CellTags->{"i:20", "b:3.3", "IPM3.2.2.4"}],
  Cell[55131, 2069, 223, 7, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[55357, 2078, 208, 6, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[55568, 2086, 218, 7, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[55811, 2097, 249, 8, 158, "Input",
   CellTags->{"b:3.3", "IPM3.2.2.4"}],
  Cell[56063, 2107, 16774, 729, 1102, 14695, 691, "GraphicsData", 
  "PostScript", "Graphics",
   CellTags->{"b:3.3", "IPM3.2.2.4"}]},
 "c:12"->{
  Cell[54402, 2045, 93, 1, 36, "Subsection",
   CellTags->{"b:3.3", "IPM3.2.2.4", "c:12"}]},
 "i:20"->{
  Cell[54498, 2048, 630, 19, 382, "TextFirst",
   CellTags->{"i:20", "b:3.3", "IPM3.2.2.4"}]},
 "i:56"->{
  Cell[72852, 2839, 211, 6, 168, "Text",
   CellTags->{"i:56", "IPM3.2.2.4"}]},
 "b:3.4"->{
  Cell[74548, 2901, 101, 1, 36, "Subsection",
   CellTags->{"b:3.4", "IPM3.2.2.5", "c:13"}],
  Cell[74652, 2904, 793, 23, 487, "TextFirst",
   CellTags->{"i:21", "b:3.4", "IPM3.2.2.5"}],
  Cell[75448, 2929, 198, 5, 168, "Text",
   CellTags->{"i:22", "b:3.4", "IPM3.2.2.5"}],
  Cell[75671, 2938, 132, 4, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[75806, 2944, 365, 8, 102, "Message",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76174, 2954, 88, 2, 168, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76277, 2959, 370, 11, 257, "Text",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76650, 2972, 197, 6, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[76850, 2980, 218, 6, 168, "Text",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77071, 2988, 187, 6, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77261, 2996, 230, 7, 257, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77494, 3005, 175, 7, 168, "TextFirst",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77694, 3016, 104, 3, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[77801, 3021, 87, 1, 112, "Print",
   CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}],
  Cell[77891, 3024, 1185, 36, 425, "Print",
   CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}],
  Cell[79091, 3063, 425, 7, 363, "TextFirst",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[79519, 3072, 99, 1, 168, "Text",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[79621, 3075, 141, 4, 158, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.5"}],
  Cell[79765, 3081, 123, 4, 158, "NonPrintInput",
   CellTags->"b:3.4"],
  Cell[79956, 3092, 83, 1, 54, "ExerciseSubsection",
   CellTags->{"b:3.4", "IPM3.2.2.6", "c:14"}],
  Cell[80042, 3095, 204, 4, 53, "ExerciseItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80249, 3101, 126, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80378, 3105, 133, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80514, 3109, 134, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80651, 3113, 126, 2, 22, "ExerciseSubItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[80802, 3119, 283, 8, 45, "ExerciseItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[81110, 3131, 331, 11, 46, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[81444, 3144, 331, 12, 246, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[81790, 3159, 332, 11, 39, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82125, 3172, 214, 6, 30, "ExercisesNoLabel",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82364, 3182, 113, 3, 36, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82480, 3187, 331, 12, 262, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82848, 3204, 113, 3, 29, "Input",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[82964, 3209, 192, 6, 168, "Output",
   CellTags->{"b:3.4", "IPM3.2.2.6"}],
  Cell[83205, 3221, 331, 11, 53, "ExerciseItem",
   CellTags->{"b:3.4", "IPM3.2.2.6"}]},
 "c:13"->{
  Cell[74548, 2901, 101, 1, 36, "Subsection",
   CellTags->{"b:3.4", "IPM3.2.2.5", "c:13"}]},
 "i:21"->{
  Cell[74652, 2904, 793, 23, 487, "TextFirst",
   CellTags->{"i:21", "b:3.4", "IPM3.2.2.5"}]},
 "i:22"->{
  Cell[75448, 2929, 198, 5, 168, "Text",
   CellTags->{"i:22", "b:3.4", "IPM3.2.2.5"}]},
 "Info3302591259-6344574"->{
  Cell[77801, 3021, 87, 1, 112, "Print",
   CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}],
  Cell[77891, 3024, 1185, 36, 425, "Print",
   CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}]},
 "c:14"->{
  Cell[79956, 3092, 83, 1, 54, "ExerciseSubsection",
   CellTags->{"b:3.4", "IPM3.2.2.6", "c:14"}]},
 "c:15"->{
  Cell[84657, 3280, 115, 1, 35, "Section",
   CellTags->{"IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", "c:15"}]},
 "b:4.0"->{
  Cell[84797, 3285, 76, 1, 245, "Subsection",
   CellTags->{"b:4.0", "IPM3.2.3.1", "c:16"}],
  Cell[84876, 3288, 766, 13, 596, "TextFirst",
   CellTags->{"i:23", "b:4.0", "IPM3.2.3.1"}],
  Cell[85667, 3305, 128, 3, 158, "Input",
   CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}],
  Cell[85798, 3310, 99, 2, 151, "Output",
   CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}],
  Cell[85912, 3315, 168, 4, 168, "Text",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[86105, 3323, 92, 2, 158, "Input",
   CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}],
  Cell[86200, 3327, 98, 2, 151, "Output",
   CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}],
  Cell[86335, 3334, 93, 2, 158, "Input",
   CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}],
  Cell[86431, 3338, 99, 2, 151, "Output",
   CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}],
  Cell[86567, 3345, 97, 2, 158, "Input",
   CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}],
  Cell[86667, 3349, 99, 2, 151, "Output",
   CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}],
  Cell[86781, 3354, 476, 18, 272, "Text",
   CellTags->{"i:28", "b:4.0", "IPM3.2.3.1"}],
  Cell[87282, 3376, 124, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87409, 3381, 90, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87536, 3388, 130, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87669, 3393, 91, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[87775, 3398, 415, 15, 272, "TextFirst",
   CellTags->{"i:29", "b:4.0", "IPM3.2.3.1"}],
  Cell[88215, 3417, 121, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88339, 3422, 90, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88466, 3429, 123, 3, 158, "Input",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88592, 3434, 91, 2, 151, "Output",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88698, 3439, 185, 4, 168, "Text",
   CellTags->{"b:4.0", "IPM3.2.3.1"}],
  Cell[88908, 3447, 138, 3, 158, "Input",
   CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}],
  Cell[89049, 3452, 98, 2, 151, "Output",
   CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}],
  Cell[89184, 3459, 183, 5, 158, "Input",
   CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}],
  Cell[89370, 3466, 99, 2, 151, "Output",
   CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}],
  Cell[89506, 3473, 389, 11, 321, "Input",
   CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}],
  Cell[89898, 3486, 99, 2, 151, "Output",
   CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}],
  Cell[90034, 3493, 312, 10, 246, "Input",
   CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}],
  Cell[90349, 3505, 100, 2, 151, "Output",
   CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}],
  Cell[90486, 3512, 250, 7, 158, "Input",
   CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}],
  Cell[90739, 3521, 99, 2, 151, "Output",
   CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}]},
 "c:16"->{
  Cell[84797, 3285, 76, 1, 245, "Subsection",
   CellTags->{"b:4.0", "IPM3.2.3.1", "c:16"}]},
 "i:23"->{
  Cell[84876, 3288, 766, 13, 596, "TextFirst",
   CellTags->{"i:23", "b:4.0", "IPM3.2.3.1"}]},
 "i:24"->{
  Cell[85667, 3305, 128, 3, 158, "Input",
   CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}],
  Cell[85798, 3310, 99, 2, 151, "Output",
   CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}]},
 "i:25"->{
  Cell[86105, 3323, 92, 2, 158, "Input",
   CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}],
  Cell[86200, 3327, 98, 2, 151, "Output",
   CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}]},
 "i:26"->{
  Cell[86335, 3334, 93, 2, 158, "Input",
   CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}],
  Cell[86431, 3338, 99, 2, 151, "Output",
   CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}]},
 "i:27"->{
  Cell[86567, 3345, 97, 2, 158, "Input",
   CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}],
  Cell[86667, 3349, 99, 2, 151, "Output",
   CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}]},
 "i:28"->{
  Cell[86781, 3354, 476, 18, 272, "Text",
   CellTags->{"i:28", "b:4.0", "IPM3.2.3.1"}]},
 "i:29"->{
  Cell[87775, 3398, 415, 15, 272, "TextFirst",
   CellTags->{"i:29", "b:4.0", "IPM3.2.3.1"}]},
 "i:30"->{
  Cell[88908, 3447, 138, 3, 158, "Input",
   CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}],
  Cell[89049, 3452, 98, 2, 151, "Output",
   CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}]},
 "i:31"->{
  Cell[89184, 3459, 183, 5, 158, "Input",
   CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}],
  Cell[89370, 3466, 99, 2, 151, "Output",
   CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}]},
 "i:32"->{
  Cell[89506, 3473, 389, 11, 321, "Input",
   CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}],
  Cell[89898, 3486, 99, 2, 151, "Output",
   CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}]},
 "i:33"->{
  Cell[90034, 3493, 312, 10, 246, "Input",
   CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}],
  Cell[90349, 3505, 100, 2, 151, "Output",
   CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}]},
 "i:34"->{
  Cell[90486, 3512, 250, 7, 158, "Input",
   CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}],
  Cell[90739, 3521, 99, 2, 151, "Output",
   CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}]},
 "b:4.1"->{
  Cell[90918, 3531, 98, 1, 245, "Subsection",
   CellTags->{"b:4.1", "IPM3.2.3.2", "c:17"}],
  Cell[91019, 3534, 897, 36, 382, "TextFirst",
   CellTags->{"i:35", "b:4.1", "IPM3.2.3.2"}],
  Cell[91941, 3574, 117, 3, 158, "Input",
   CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}],
  Cell[92061, 3579, 100, 2, 151, "Output",
   CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}],
  Cell[92198, 3586, 205, 6, 245, "Input",
   CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}],
  Cell[92406, 3594, 99, 2, 151, "Output",
   CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}],
  Cell[92542, 3601, 317, 11, 266, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[92862, 3614, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[92968, 3619, 361, 8, 272, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[93332, 3629, 2374, 83, 835, "DisplayTable",
   CellTags->{"i:38", "b:4.1", "IPM3.2.3.2"}],
  Cell[95709, 3714, 81, 1, 112, "NumberedTable",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[95793, 3717, 266, 5, 272, "Text",
   CellTags->{"i:39", "b:4.1", "IPM3.2.3.2"}],
  Cell[96084, 3726, 156, 5, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[96243, 3733, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[96349, 3738, 499, 15, 272, "Text",
   CellTags->{"i:40", "b:4.1", "IPM3.2.3.2"}],
  Cell[96873, 3757, 229, 7, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[97105, 3766, 571, 19, 627, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[97691, 3788, 348, 11, 168, "Text",
   PageBreakAbove->True,
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98064, 3803, 180, 6, 245, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98247, 3811, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98375, 3818, 193, 6, 245, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98571, 3826, 92, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[98678, 3831, 771, 21, 382, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[99474, 3856, 116, 3, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[99593, 3861, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[99699, 3866, 203, 7, 168, "Text",
   CellTags->{"i:41", "b:4.1", "IPM3.2.3.2"}],
  Cell[99927, 3877, 145, 4, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100075, 3883, 92, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100204, 3890, 146, 4, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100353, 3896, 91, 2, 151, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100459, 3901, 112, 1, 168, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[100574, 3904, 2656, 97, 737, "DisplayTable",
   CellTags->{"i:42", "b:4.1", "IPM3.2.3.2"}],
  Cell[103233, 4003, 78, 1, 112, "NumberedTable",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[103314, 4006, 746, 23, 382, "Text",
   CellTags->{"i:43", "b:4.1", "IPM3.2.3.2"}],
  Cell[104085, 4033, 218, 7, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[104306, 4042, 220, 8, 235, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[104541, 4053, 445, 17, 168, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[105011, 4074, 219, 7, 158, "Input",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[105233, 4083, 217, 8, 235, "Output",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[105465, 4094, 1883, 63, 652, "DisplayTable",
   CellTags->{"i:44", "b:4.1", "IPM3.2.3.2"}],
  Cell[107351, 4159, 78, 1, 112, "NumberedTable",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[107432, 4162, 211, 4, 272, "Text",
   CellTags->{"b:4.1", "IPM3.2.3.2"}],
  Cell[107711, 4173, 83, 1, 415, "ExerciseSubsection",
   CellTags->{"b:4.1", "IPM3.2.3.3", "c:18"}],
  Cell[107797, 4176, 274, 9, 127, "ExerciseItem",
   CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],
  Cell[108074, 4187, 586, 23, 213, "ExerciseItem",
   CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],
  Cell[108685, 4214, 751, 29, 213, "ExerciseItem",
   CellTags->{"i:47", "b:4.1", "IPM3.2.3.3"}]},
 "c:17"->{
  Cell[90918, 3531, 98, 1, 245, "Subsection",
   CellTags->{"b:4.1", "IPM3.2.3.2", "c:17"}]},
 "i:35"->{
  Cell[91019, 3534, 897, 36, 382, "TextFirst",
   CellTags->{"i:35", "b:4.1", "IPM3.2.3.2"}]},
 "i:36"->{
  Cell[91941, 3574, 117, 3, 158, "Input",
   CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}],
  Cell[92061, 3579, 100, 2, 151, "Output",
   CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}]},
 "i:37"->{
  Cell[92198, 3586, 205, 6, 245, "Input",
   CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}],
  Cell[92406, 3594, 99, 2, 151, "Output",
   CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}]},
 "i:38"->{
  Cell[93332, 3629, 2374, 83, 835, "DisplayTable",
   CellTags->{"i:38", "b:4.1", "IPM3.2.3.2"}]},
 "i:39"->{
  Cell[95793, 3717, 266, 5, 272, "Text",
   CellTags->{"i:39", "b:4.1", "IPM3.2.3.2"}]},
 "i:40"->{
  Cell[96349, 3738, 499, 15, 272, "Text",
   CellTags->{"i:40", "b:4.1", "IPM3.2.3.2"}]},
 "i:41"->{
  Cell[99699, 3866, 203, 7, 168, "Text",
   CellTags->{"i:41", "b:4.1", "IPM3.2.3.2"}]},
 "i:42"->{
  Cell[100574, 3904, 2656, 97, 737, "DisplayTable",
   CellTags->{"i:42", "b:4.1", "IPM3.2.3.2"}]},
 "i:43"->{
  Cell[103314, 4006, 746, 23, 382, "Text",
   CellTags->{"i:43", "b:4.1", "IPM3.2.3.2"}]},
 "i:44"->{
  Cell[105465, 4094, 1883, 63, 652, "DisplayTable",
   CellTags->{"i:44", "b:4.1", "IPM3.2.3.2"}]},
 "c:18"->{
  Cell[107711, 4173, 83, 1, 415, "ExerciseSubsection",
   CellTags->{"b:4.1", "IPM3.2.3.3", "c:18"}]},
 "i:54"->{
  Cell[107797, 4176, 274, 9, 127, "ExerciseItem",
   CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],
  Cell[108074, 4187, 586, 23, 213, "ExerciseItem",
   CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}]},
 "i:47"->{
  Cell[108685, 4214, 751, 29, 213, "ExerciseItem",
   CellTags->{"i:47", "b:4.1", "IPM3.2.3.3"}]},
 "b:5"->{
  Cell[109757, 4261, 69, 1, 35, "Section",
   CellTags->{"b:5", "IPM3.2.4", "c:19"}],
  Cell[109829, 4264, 469, 12, 382, "TextFirst",
   CellTags->{"i:48", "b:5", "IPM3.2.4"}],
  Cell[110323, 4280, 121, 3, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[110447, 4285, 225, 6, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[110687, 4294, 1074, 34, 487, "Text",
   CellTags->{"i:49", "b:5", "IPM3.2.4"}],
  Cell[111786, 4332, 192, 6, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[111981, 4340, 115, 3, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[112111, 4346, 624, 18, 382, "Text",
   CellTags->{"i:50", "b:5", "IPM3.2.4"}],
  Cell[112760, 4368, 124, 3, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[112887, 4373, 125, 3, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113027, 4379, 96, 1, 168, "Text",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113148, 4384, 240, 7, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113391, 4393, 241, 7, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113647, 4403, 88, 1, 168, "TextFirst",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[113760, 4408, 411, 14, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[114174, 4424, 412, 14, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[114601, 4441, 260, 6, 272, "Text",
   CellTags->{"i:51", "b:5", "IPM3.2.4"}],
  Cell[114864, 4449, 405, 10, 272, "Text",
   CellTags->{"i:52", "b:5", "IPM3.2.4"}],
  Cell[115294, 4463, 204, 6, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[115501, 4471, 271, 10, 235, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[115787, 4484, 375, 12, 272, "Text",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116165, 4498, 437, 9, 382, "Text",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116627, 4511, 142, 4, 158, "Input",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116772, 4517, 143, 4, 151, "Output",
   CellTags->{"b:5", "IPM3.2.4"}],
  Cell[116930, 4524, 332, 10, 272, "TextFirst",
   CellTags->{"i:53", "b:5", "IPM3.2.4"}],
  Cell[117649, 4554, 160, 5, 168, "Text",
   CellTags->{"b:5", "IPM3.2.4"}]},
 "c:19"->{
  Cell[109757, 4261, 69, 1, 35, "Section",
   CellTags->{"b:5", "IPM3.2.4", "c:19"}]},
 "i:48"->{
  Cell[109829, 4264, 469, 12, 382, "TextFirst",
   CellTags->{"i:48", "b:5", "IPM3.2.4"}]},
 "i:49"->{
  Cell[110687, 4294, 1074, 34, 487, "Text",
   CellTags->{"i:49", "b:5", "IPM3.2.4"}]},
 "i:50"->{
  Cell[112111, 4346, 624, 18, 382, "Text",
   CellTags->{"i:50", "b:5", "IPM3.2.4"}]},
 "i:51"->{
  Cell[114601, 4441, 260, 6, 272, "Text",
   CellTags->{"i:51", "b:5", "IPM3.2.4"}]},
 "i:52"->{
  Cell[114864, 4449, 405, 10, 272, "Text",
   CellTags->{"i:52", "b:5", "IPM3.2.4"}]},
 "i:53"->{
  Cell[116930, 4524, 332, 10, 272, "TextFirst",
   CellTags->{"i:53", "b:5", "IPM3.2.4"}]},
 "2. inits"->{
  Cell[117889, 4567, 94, 2, 41, "NonPrintSection",
   InitializationGroup->True,
   CellTags->"2. inits"],
  Cell[117986, 4571, 130, 3, 36, "NonPrintInput",
   CellTags->"2. inits"],
  Cell[118119, 4576, 2916, 82, 314, "NonPrintInput",
   CellTags->"2. inits"],
  Cell[121038, 4660, 125, 4, 36, "NonPrintInput",
   CellTags->"2. inits"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"IPM3.2.0", 182848, 5973},
 {"IPM3.2.1.1", 183241, 5982},
 {"IPM3.2.1.2", 183558, 5989},
 {"IPM3.2.1.3", 183875, 5996},
 {"IPM3.2.1.4", 184192, 6003},
 {"IPM3.2.1.5", 184509, 6010},
 {"IPM3.2.2.1", 184826, 6017},
 {"IPM3.2.2.2", 187484, 6080},
 {"IPM3.2.2.3", 190487, 6150},
 {"IPM3.2.2.4", 192573, 6197},
 {"IPM3.2.2.5", 194064, 6233},
 {"IPM3.2.2.6", 196092, 6280},
 {"IPM3.2.3.1", 198177, 6329},
 {"IPM3.2.3.2", 201383, 6402},
 {"IPM3.2.3.3", 205413, 6496},
 {"IPM3.2.4", 206232, 6513},
 {"2. expressions", 208656, 6572},
 {"c:8", 218708, 6846},
 {"b:3.0", 218882, 6851},
 {"c:9", 221073, 6904},
 {"i:13", 221176, 6907},
 {"i:14", 221300, 6911},
 {"Info3302591258-2071244", 221422, 6914},
 {"i:15", 221648, 6919},
 {"i:16", 221747, 6922},
 {"b:3.1", 221854, 6925},
 {"c:10", 224391, 6985},
 {"i:17", 224495, 6988},
 {"i:18", 224596, 6991},
 {"Info3302591258-1510696", 224715, 6994},
 {"Info3302591258-7709797", 224959, 6999},
 {"b:3.2", 225186, 7004},
 {"c:11", 226806, 7041},
 {"i:19", 226910, 7044},
 {"Info3302591258-3722316", 227033, 7047},
 {"Info3302591258-4390566", 227170, 7050},
 {"Info3302591258-2230077", 227414, 7055},
 {"b:3.3", 227641, 7060},
 {"c:12", 228297, 7076},
 {"i:20", 228401, 7079},
 {"i:56", 228507, 7082},
 {"b:3.4", 228599, 7085},
 {"c:13", 231617, 7156},
 {"i:21", 231722, 7159},
 {"i:22", 231828, 7162},
 {"Info3302591259-6344574", 231946, 7165},
 {"c:14", 232173, 7170},
 {"c:15", 232285, 7173},
 {"b:4.0", 232407, 7176},
 {"c:16", 235199, 7241},
 {"i:23", 235304, 7244},
 {"i:24", 235410, 7247},
 {"i:25", 235600, 7252},
 {"i:26", 235789, 7257},
 {"i:27", 235978, 7262},
 {"i:28", 236167, 7267},
 {"i:29", 236268, 7270},
 {"i:30", 236374, 7273},
 {"i:31", 236564, 7278},
 {"i:32", 236754, 7283},
 {"i:33", 236945, 7288},
 {"i:34", 237137, 7293},
 {"b:4.1", 237328, 7298},
 {"c:17", 241339, 7392},
 {"i:35", 241444, 7395},
 {"i:36", 241550, 7398},
 {"i:37", 241741, 7403},
 {"i:38", 241931, 7408},
 {"i:39", 242041, 7411},
 {"i:40", 242141, 7414},
 {"i:41", 242242, 7417},
 {"i:42", 242342, 7420},
 {"i:43", 242453, 7423},
 {"i:44", 242555, 7426},
 {"c:18", 242666, 7429},
 {"i:54", 242780, 7432},
 {"i:47", 242987, 7437},
 {"b:5", 243096, 7440},
 {"c:19", 245211, 7493},
 {"i:48", 245309, 7496},
 {"i:49", 245412, 7499},
 {"i:50", 245511, 7502},
 {"i:51", 245609, 7505},
 {"i:52", 245706, 7508},
 {"i:53", 245804, 7511},
 {"2. inits", 245911, 7514}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 365, 9, 36, "TitleBar",
 CellTags->{
  "IPM3.2.0", "IPM3.2.1.1", "IPM3.2.1.2", "IPM3.2.1.3", "IPM3.2.1.4", 
   "IPM3.2.1.5", "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", 
   "IPM3.2.2.5", "IPM3.2.2.6", "IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", 
   "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[935, 33, 167, 8, 137, "Chapter",
 CounterAssignments->{{"Chapter", 1}}],
Cell[1105, 43, 656, 14, 149, "ChapterAbstract",
 CellTags->"IPM3.2.0"],
Cell[CellGroupData[{
Cell[1786, 61, 59, 1, 54, "Section",
 CellTags->"2. expressions"],
Cell[1848, 64, 132, 3, 33, "Editorial",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[2005, 71, 63, 1, 60, "Subsection",
 CellTags->"2. expressions"],
Cell[2071, 74, 650, 18, 108, "TextFirst",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2758, 97, 80, 1, 60, "Subsection",
 CellTags->"2. expressions"],
Cell[2841, 100, 579, 14, 108, "TextFirst",
 CellTags->"2. expressions"],
Cell[3423, 116, 508, 11, 108, "Text",
 CellTags->"2. expressions"],
Cell[3934, 129, 266, 7, 62, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[4225, 140, 360, 11, 64, "Input",
 CellTags->"2. expressions"],
Cell[4588, 153, 170, 5, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[4773, 161, 236, 8, 62, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[5034, 173, 132, 4, 36, "Input",
 CellTags->"2. expressions"],
Cell[5169, 179, 83, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5289, 186, 189, 6, 36, "Input",
 CellTags->"2. expressions"],
Cell[5481, 194, 83, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[5579, 199, 57, 1, 30, "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5673, 205, 56, 1, 60, "Subsection",
 CellTags->"2. expressions"],
Cell[5732, 208, 451, 12, 85, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[6208, 224, 176, 6, 36, "Input",
 CellTags->"2. expressions"],
Cell[6387, 232, 706, 12, 32, "Message",
 CellTags->"2. expressions"],
Cell[7096, 246, 233, 7, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[7344, 256, 256, 8, 62, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[7625, 268, 109, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[7737, 273, 85, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7859, 280, 117, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[7979, 285, 85, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[8079, 290, 159, 6, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[8263, 300, 257, 7, 36, "Input",
 CellTags->"2. expressions"],
Cell[8523, 309, 150, 4, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[8688, 316, 162, 4, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[8875, 324, 114, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[8992, 329, 85, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[9092, 334, 85, 1, 39, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[9202, 339, 115, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[9320, 344, 86, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[9421, 349, 166, 4, 62, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[9612, 357, 127, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[9742, 362, 85, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[9842, 367, 440, 9, 108, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[10307, 380, 303, 10, 38, "Input",
 CellTags->"2. expressions"],
Cell[10613, 392, 401, 14, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11051, 411, 118, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[11172, 416, 824, 25, 127, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12033, 446, 113, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[12149, 451, 84, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[12248, 456, 121, 3, 39, "Text",
 CellTags->"2. expressions"],
Cell[12372, 461, 57, 1, 30, "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12466, 467, 79, 1, 60, "Subsection",
 CellTags->"2. expressions"],
Cell[12548, 470, 665, 17, 108, "TextFirst",
 CellTags->"2. expressions"],
Cell[13216, 489, 263, 7, 30, "DisplayFormula",
 CellTags->"2. expressions"],
Cell[13482, 498, 299, 8, 62, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[13806, 510, 143, 4, 36, "Input",
 CellTags->"2. expressions"],
Cell[13952, 516, 84, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[14051, 521, 157, 5, 39, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[14233, 530, 147, 4, 36, "Input",
 CellTags->"2. expressions"],
Cell[14383, 536, 279, 10, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14699, 551, 171, 5, 36, "Input",
 CellTags->"2. expressions"],
Cell[14873, 558, 279, 10, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[15167, 571, 399, 10, 85, "Text",
 CellTags->"2. expressions"],
Cell[15569, 583, 526, 13, 108, "Text",
 CellTags->"2. expressions"],
Cell[16098, 598, 117, 3, 39, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[16240, 605, 145, 4, 36, "Input",
 CellTags->"2. expressions"],
Cell[16388, 611, 81, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[16484, 616, 83, 1, 39, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[16592, 621, 293, 10, 45, "Input",
 CellTags->"2. expressions"],
Cell[16888, 633, 267, 9, 45, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[17170, 645, 212, 7, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[17407, 656, 113, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[17523, 661, 85, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[17623, 666, 101, 1, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[17749, 671, 115, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[17867, 676, 81, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[17963, 681, 338, 10, 85, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[18326, 695, 117, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[18446, 700, 576, 19, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[19037, 722, 506, 13, 108, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[19568, 739, 118, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[19689, 744, 86, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19812, 751, 122, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[19937, 756, 86, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[20038, 761, 136, 3, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[20199, 768, 110, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[20312, 773, 87, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20436, 780, 113, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[20552, 785, 84, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[20651, 790, 172, 5, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[20848, 799, 114, 3, 36, "Input",
 CellTags->"2. expressions"],
Cell[20965, 804, 212, 8, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21214, 817, 135, 4, 64, "Input",
 CellTags->"2. expressions"],
Cell[21352, 823, 273, 10, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[21640, 836, 383, 11, 85, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[22048, 851, 157, 5, 36, "Input",
 CellTags->"2. expressions"],
Cell[22208, 858, 81, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[22304, 863, 112, 5, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[22441, 872, 157, 5, 36, "Input",
 CellTags->"2. expressions"],
Cell[22601, 879, 81, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[22697, 884, 146, 4, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[22868, 892, 137, 4, 36, "Input",
 CellTags->"2. expressions"],
Cell[23008, 898, 269, 10, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[23292, 911, 486, 21, 62, "TextFirst",
 CellTags->"2. expressions"],
Cell[23781, 934, 176, 6, 39, "Text",
 PageBreakAbove->True,
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[23982, 944, 157, 5, 36, "Input",
 CellTags->"2. expressions"],
Cell[24142, 951, 84, 2, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[24241, 956, 98, 1, 39, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[24364, 961, 152, 4, 36, "Input",
 CellTags->"2. expressions"],
Cell[24519, 967, 437, 9, 52, "Message",
 CellTags->"2. expressions"],
Cell[24959, 978, 169, 4, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[25143, 985, 299, 9, 62, "TextFirst",
 CellTags->"2. expressions"],
Cell[25445, 996, 115, 3, 39, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[25585, 1003, 214, 7, 36, "Input",
 CellTags->"2. expressions"],
Cell[25802, 1012, 466, 9, 52, "Message",
 CellTags->"2. expressions"],
Cell[26271, 1023, 234, 7, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[26520, 1033, 384, 10, 85, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[26929, 1047, 184, 6, 36, "Input",
 CellTags->"2. expressions"],
Cell[27116, 1055, 136, 4, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[27267, 1062, 186, 5, 39, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[27478, 1071, 161, 5, 36, "Input",
 CellTags->"2. expressions"],
Cell[27642, 1078, 331, 12, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28010, 1095, 171, 5, 36, "Input",
 CellTags->"2. expressions"],
Cell[28184, 1102, 341, 12, 54, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[28540, 1117, 303, 11, 40, "TextFirst",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[28868, 1132, 189, 6, 36, "Input",
 CellTags->"2. expressions"],
Cell[29060, 1140, 141, 4, 36, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[29216, 1147, 760, 22, 112, "Text",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[30001, 1173, 221, 7, 45, "Input",
 CellTags->"2. expressions"],
Cell[30225, 1182, 1442, 45, 121, "Output",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[31682, 1230, 57, 1, 30, "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31776, 1236, 68, 1, 107, "ExerciseSubsection",
 CellTags->"2. expressions"],
Cell[31847, 1239, 149, 5, 30, "ExerciseItem",
 CellTags->"2. expressions"],
Cell[31999, 1246, 170, 6, 22, "ExerciseItem",
 CellTags->"2. expressions"],
Cell[32172, 1254, 226, 5, 45, "ExerciseItem",
 CellTags->"2. expressions"],
Cell[32401, 1261, 111, 2, 22, "ExerciseSubItem",
 CellTags->"2. expressions"],
Cell[32515, 1265, 95, 1, 22, "ExerciseSubItem",
 CellTags->"2. expressions"],
Cell[CellGroupData[{
Cell[32635, 1270, 194, 7, 22, "ExerciseItem",
 CellTags->"2. expressions"],
Cell[32832, 1279, 132, 4, 36, "NonPrintInput",
 CellTags->"2. expressions"],
Cell[32967, 1285, 57, 1, 30, "SubsectionSpacer",
 CellTags->"2. expressions"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[33085, 1293, 141, 3, 35, "Section",
 CellTags->{
  "IPM3.2.2.1", "IPM3.2.2.2", "IPM3.2.2.3", "IPM3.2.2.4", "IPM3.2.2.5", 
   "IPM3.2.2.6", "c:8"}],
Cell[CellGroupData[{
Cell[33251, 1300, 97, 1, 60, "Subsection",
 CellTags->{"b:3.0", "IPM3.2.2.1", "c:9"}],
Cell[33351, 1303, 737, 13, 153, "TextFirst",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[34091, 1318, 199, 6, 39, "Text",
 PageBreakAbove->True,
 CellTags->{"i:13", "b:3.0", "IPM3.2.2.1"}],
Cell[CellGroupData[{
Cell[34315, 1328, 159, 5, 36, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[34477, 1335, 104, 2, 168, "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"}]
}, Closed]],
Cell[34596, 1340, 343, 12, 55, "TextFirst",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[CellGroupData[{
Cell[34964, 1356, 115, 3, 36, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[35082, 1361, 89, 2, 168, "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"}]
}, Closed]],
Cell[35186, 1366, 188, 7, 32, "TextFirst",
 CellTags->{"i:14", "b:3.0", "IPM3.2.2.1"}],
Cell[CellGroupData[{
Cell[35399, 1377, 103, 3, 36, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[35505, 1382, 87, 1, 140, "Print",
 CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}],
Cell[35595, 1385, 731, 20, 140, "Print",
 CellTags->{"b:3.0", "Info3302591258-2071244", "IPM3.2.2.1"}]
}, Closed]],
Cell[36341, 1408, 319, 9, 55, "Text",
 CellTags->{"i:15", "b:3.0", "IPM3.2.2.1"}],
Cell[CellGroupData[{
Cell[36685, 1421, 182, 6, 64, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[36870, 1429, 130, 4, 245, "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"}]
}, Closed]],
Cell[37015, 1436, 627, 20, 101, "TextFirst",
 CellTags->{"i:16", "b:3.0", "IPM3.2.2.1"}],
Cell[37645, 1458, 255, 8, 62, "Text",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[CellGroupData[{
Cell[37925, 1470, 114, 3, 36, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[38042, 1475, 105, 2, 168, "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[38184, 1482, 113, 3, 29, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[38300, 1487, 107, 3, 245, "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[38444, 1495, 144, 4, 38, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[38591, 1501, 162, 5, 245, "Output",
 CellTags->{"b:3.0", "IPM3.2.2.1"}]
}, Closed]],
Cell[38768, 1509, 127, 2, 32, "TextFirst",
 PageBreakAbove->True,
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[38898, 1513, 197, 5, 47, "Input",
 CellTags->{"b:3.0", "IPM3.2.2.1"}],
Cell[39098, 1520, 28, 0, 30, "SubsectionSpacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[39163, 1525, 99, 1, 36, "Subsection",
 CellTags->{"b:3.1", "IPM3.2.2.2", "c:10"}],
Cell[39265, 1528, 598, 9, 487, "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[39866, 1539, 385, 15, 168, "Text",
 CellTags->{"i:17", "b:3.1", "IPM3.2.2.2"}],
Cell[40254, 1556, 121, 5, 233, "Program",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[40378, 1563, 338, 10, 168, "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[40719, 1575, 241, 7, 272, "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[40963, 1584, 214, 6, 285, "NonPrintInput"],
Cell[CellGroupData[{
Cell[41202, 1594, 144, 4, 158, "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[41349, 1600, 105, 2, 151, "Output",
 CellTags->{"b:3.1", "IPM3.2.2.2"}]
}, Closed]],
Cell[41469, 1605, 334, 10, 272, "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[41806, 1617, 471, 17, 272, "Text",
 CellTags->{"i:18", "b:3.1", "IPM3.2.2.2"}],
Cell[42280, 1636, 122, 5, 233, "Program",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[42405, 1643, 213, 7, 168, "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[42621, 1652, 146, 4, 158, "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[42770, 1658, 272, 7, 272, "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[43045, 1667, 158, 6, 168, "Text",
 PageBreakAbove->True,
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[CellGroupData[{
Cell[43228, 1677, 169, 5, 158, "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[43400, 1684, 264, 7, 158, "Output",
 CellTags->{"b:3.1", "IPM3.2.2.2"}]
}, Closed]],
Cell[43679, 1694, 319, 9, 257, "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[CellGroupData[{
Cell[44023, 1707, 108, 3, 158, "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[44134, 1712, 91, 1, 112, "Print",
 CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}],
Cell[44228, 1715, 740, 20, 112, "Print",
 CellTags->{"b:3.1", "Info3302591258-1510696", "IPM3.2.2.2"}]
}, Closed]],
Cell[44983, 1738, 189, 5, 150, "TextFirst",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[CellGroupData[{
Cell[45197, 1747, 169, 5, 158, "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[45369, 1754, 265, 7, 168, "Output",
 CellTags->{"b:3.1", "IPM3.2.2.2"}]
}, Closed]],
Cell[45649, 1764, 479, 15, 363, "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[CellGroupData[{
Cell[46153, 1783, 108, 3, 158, "Input",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[46264, 1788, 91, 1, 112, "Print",
 CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}],
Cell[46358, 1791, 758, 21, 112, "Print",
 CellTags->{"b:3.1", "Info3302591258-7709797", "IPM3.2.2.2"}]
}, Closed]],
Cell[47131, 1815, 581, 13, 472, "Text",
 CellTags->{"b:3.1", "IPM3.2.2.2"}],
Cell[47715, 1830, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[47780, 1835, 86, 1, 36, "Subsection",
 CellTags->{"b:3.2", "IPM3.2.2.3", "c:11"}],
Cell[47869, 1838, 342, 8, 272, "TextFirst",
 CellTags->{"i:19", "b:3.2", "IPM3.2.2.3"}],
Cell[48214, 1848, 390, 9, 382, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[CellGroupData[{
Cell[48629, 1861, 108, 3, 158, "Input",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[48740, 1866, 382, 9, 340, "Print",
 CellTags->{"b:3.2", "Info3302591258-3722316", "IPM3.2.2.3"}]
}, Closed]],
Cell[49137, 1878, 480, 14, 363, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[CellGroupData[{
Cell[49642, 1896, 108, 3, 158, "Input",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[49753, 1901, 91, 1, 112, "Print",
 CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}],
Cell[49847, 1904, 740, 20, 112, "Print",
 CellTags->{"b:3.2", "Info3302591258-4390566", "IPM3.2.2.3"}]
}, Closed]],
Cell[50602, 1927, 394, 8, 363, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[CellGroupData[{
Cell[51021, 1939, 108, 3, 158, "Input",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[51132, 1944, 91, 1, 112, "Print",
 CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}],
Cell[51226, 1947, 758, 21, 112, "Print",
 CellTags->{"b:3.2", "Info3302591258-2230077", "IPM3.2.2.3"}]
}, Closed]],
Cell[51999, 1971, 533, 15, 363, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[52535, 1988, 277, 8, 272, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[52815, 1998, 475, 10, 382, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[53293, 2010, 466, 10, 382, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[53762, 2022, 572, 16, 382, "Text",
 CellTags->{"b:3.2", "IPM3.2.2.3"}],
Cell[54337, 2040, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[54402, 2045, 93, 1, 36, "Subsection",
 CellTags->{"b:3.3", "IPM3.2.2.4", "c:12"}],
Cell[54498, 2048, 630, 19, 382, "TextFirst",
 CellTags->{"i:20", "b:3.3", "IPM3.2.2.4"}],
Cell[55131, 2069, 223, 7, 158, "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"}],
Cell[55357, 2078, 208, 6, 158, "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"}],
Cell[55568, 2086, 218, 7, 158, "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"}],
Cell[CellGroupData[{
Cell[55811, 2097, 249, 8, 158, "Input",
 CellTags->{"b:3.3", "IPM3.2.2.4"}],
Cell[56063, 2107, 16774, 729, 1102, 14695, 691, "GraphicsData", "PostScript", \
"Graphics",
 CellTags->{"b:3.3", "IPM3.2.2.4"}]
}, Closed]],
Cell[72852, 2839, 211, 6, 168, "Text",
 CellTags->{"i:56", "IPM3.2.2.4"}],
Cell[CellGroupData[{
Cell[73088, 2849, 496, 16, 171, "Input",
 CellTags->"IPM3.2.2.4"],
Cell[73587, 2867, 460, 15, 343, "Output",
 CellTags->"IPM3.2.2.4"]
}, Closed]],
Cell[74062, 2885, 393, 8, 363, "Text",
 CellTags->"IPM3.2.2.4"],
Cell[74458, 2895, 53, 1, 0, "SubsectionSpacer",
 CellTags->"IPM3.2.2.4"]
}, Closed]],
Cell[CellGroupData[{
Cell[74548, 2901, 101, 1, 36, "Subsection",
 CellTags->{"b:3.4", "IPM3.2.2.5", "c:13"}],
Cell[74652, 2904, 793, 23, 487, "TextFirst",
 CellTags->{"i:21", "b:3.4", "IPM3.2.2.5"}],
Cell[75448, 2929, 198, 5, 168, "Text",
 CellTags->{"i:22", "b:3.4", "IPM3.2.2.5"}],
Cell[CellGroupData[{
Cell[75671, 2938, 132, 4, 158, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[75806, 2944, 365, 8, 102, "Message",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[76174, 2954, 88, 2, 168, "Output",
 CellTags->{"b:3.4", "IPM3.2.2.5"}]
}, Closed]],
Cell[76277, 2959, 370, 11, 257, "Text",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[76650, 2972, 197, 6, 158, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[76850, 2980, 218, 6, 168, "Text",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[77071, 2988, 187, 6, 158, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[77261, 2996, 230, 7, 257, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[77494, 3005, 175, 7, 168, "TextFirst",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[CellGroupData[{
Cell[77694, 3016, 104, 3, 158, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[77801, 3021, 87, 1, 112, "Print",
 CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}],
Cell[77891, 3024, 1185, 36, 425, "Print",
 CellTags->{"b:3.4", "Info3302591259-6344574", "IPM3.2.2.5"}]
}, Closed]],
Cell[79091, 3063, 425, 7, 363, "TextFirst",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[79519, 3072, 99, 1, 168, "Text",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[79621, 3075, 141, 4, 158, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.5"}],
Cell[79765, 3081, 123, 4, 158, "NonPrintInput",
 CellTags->"b:3.4"],
Cell[79891, 3087, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[79956, 3092, 83, 1, 54, "ExerciseSubsection",
 CellTags->{"b:3.4", "IPM3.2.2.6", "c:14"}],
Cell[80042, 3095, 204, 4, 53, "ExerciseItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[80249, 3101, 126, 2, 22, "ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[80378, 3105, 133, 2, 22, "ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[80514, 3109, 134, 2, 22, "ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[80651, 3113, 126, 2, 22, "ExerciseSubItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[CellGroupData[{
Cell[80802, 3119, 283, 8, 45, "ExerciseItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[CellGroupData[{
Cell[81110, 3131, 331, 11, 46, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[81444, 3144, 331, 12, 246, "Output",
 CellTags->{"b:3.4", "IPM3.2.2.6"}]
}, Closed]],
Cell[81790, 3159, 332, 11, 39, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[82125, 3172, 214, 6, 30, "ExercisesNoLabel",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[CellGroupData[{
Cell[82364, 3182, 113, 3, 36, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[82480, 3187, 331, 12, 262, "Output",
 CellTags->{"b:3.4", "IPM3.2.2.6"}]
}, Closed]],
Cell[CellGroupData[{
Cell[82848, 3204, 113, 3, 29, "Input",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[82964, 3209, 192, 6, 168, "Output",
 CellTags->{"b:3.4", "IPM3.2.2.6"}]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[83205, 3221, 331, 11, 53, "ExerciseItem",
 CellTags->{"b:3.4", "IPM3.2.2.6"}],
Cell[83539, 3234, 746, 25, 92, "Input",
 CellTags->"IPM3.2.2.6"],
Cell[84288, 3261, 178, 6, 36, "NonPrintInput",
 CellTags->"IPM3.2.2.6"],
Cell[84469, 3269, 127, 4, 36, "NonPrintInput",
 CellTags->"IPM3.2.2.6"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[84657, 3280, 115, 1, 35, "Section",
 CellTags->{"IPM3.2.3.1", "IPM3.2.3.2", "IPM3.2.3.3", "c:15"}],
Cell[CellGroupData[{
Cell[84797, 3285, 76, 1, 245, "Subsection",
 CellTags->{"b:4.0", "IPM3.2.3.1", "c:16"}],
Cell[84876, 3288, 766, 13, 596, "TextFirst",
 CellTags->{"i:23", "b:4.0", "IPM3.2.3.1"}],
Cell[CellGroupData[{
Cell[85667, 3305, 128, 3, 158, "Input",
 CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}],
Cell[85798, 3310, 99, 2, 151, "Output",
 CellTags->{"i:24", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[85912, 3315, 168, 4, 168, "Text",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],
Cell[CellGroupData[{
Cell[86105, 3323, 92, 2, 158, "Input",
 CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}],
Cell[86200, 3327, 98, 2, 151, "Output",
 CellTags->{"i:25", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[86335, 3334, 93, 2, 158, "Input",
 CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}],
Cell[86431, 3338, 99, 2, 151, "Output",
 CellTags->{"i:26", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[86567, 3345, 97, 2, 158, "Input",
 CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}],
Cell[86667, 3349, 99, 2, 151, "Output",
 CellTags->{"i:27", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[86781, 3354, 476, 18, 272, "Text",
 CellTags->{"i:28", "b:4.0", "IPM3.2.3.1"}],
Cell[CellGroupData[{
Cell[87282, 3376, 124, 3, 158, "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],
Cell[87409, 3381, 90, 2, 151, "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[87536, 3388, 130, 3, 158, "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],
Cell[87669, 3393, 91, 2, 151, "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[87775, 3398, 415, 15, 272, "TextFirst",
 CellTags->{"i:29", "b:4.0", "IPM3.2.3.1"}],
Cell[CellGroupData[{
Cell[88215, 3417, 121, 3, 158, "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],
Cell[88339, 3422, 90, 2, 151, "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[88466, 3429, 123, 3, 158, "Input",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],
Cell[88592, 3434, 91, 2, 151, "Output",
 CellTags->{"b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[88698, 3439, 185, 4, 168, "Text",
 CellTags->{"b:4.0", "IPM3.2.3.1"}],
Cell[CellGroupData[{
Cell[88908, 3447, 138, 3, 158, "Input",
 CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}],
Cell[89049, 3452, 98, 2, 151, "Output",
 CellTags->{"i:30", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[89184, 3459, 183, 5, 158, "Input",
 CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}],
Cell[89370, 3466, 99, 2, 151, "Output",
 CellTags->{"i:31", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[89506, 3473, 389, 11, 321, "Input",
 CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}],
Cell[89898, 3486, 99, 2, 151, "Output",
 CellTags->{"i:32", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[90034, 3493, 312, 10, 246, "Input",
 CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}],
Cell[90349, 3505, 100, 2, 151, "Output",
 CellTags->{"i:33", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[CellGroupData[{
Cell[90486, 3512, 250, 7, 158, "Input",
 CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}],
Cell[90739, 3521, 99, 2, 151, "Output",
 CellTags->{"i:34", "b:4.0", "IPM3.2.3.1"}]
}, Closed]],
Cell[90853, 3526, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[90918, 3531, 98, 1, 245, "Subsection",
 CellTags->{"b:4.1", "IPM3.2.3.2", "c:17"}],
Cell[91019, 3534, 897, 36, 382, "TextFirst",
 CellTags->{"i:35", "b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[91941, 3574, 117, 3, 158, "Input",
 CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}],
Cell[92061, 3579, 100, 2, 151, "Output",
 CellTags->{"i:36", "b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[CellGroupData[{
Cell[92198, 3586, 205, 6, 245, "Input",
 CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}],
Cell[92406, 3594, 99, 2, 151, "Output",
 CellTags->{"i:37", "b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[CellGroupData[{
Cell[92542, 3601, 317, 11, 266, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[92862, 3614, 91, 2, 151, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[92968, 3619, 361, 8, 272, "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[93332, 3629, 2374, 83, 835, "DisplayTable",
 CellTags->{"i:38", "b:4.1", "IPM3.2.3.2"}],
Cell[95709, 3714, 81, 1, 112, "NumberedTable",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[95793, 3717, 266, 5, 272, "Text",
 CellTags->{"i:39", "b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[96084, 3726, 156, 5, 158, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[96243, 3733, 91, 2, 151, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[96349, 3738, 499, 15, 272, "Text",
 CellTags->{"i:40", "b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[96873, 3757, 229, 7, 158, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[97105, 3766, 571, 19, 627, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[97691, 3788, 348, 11, 168, "Text",
 PageBreakAbove->True,
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[98064, 3803, 180, 6, 245, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[98247, 3811, 91, 2, 151, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[CellGroupData[{
Cell[98375, 3818, 193, 6, 245, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[98571, 3826, 92, 2, 151, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[98678, 3831, 771, 21, 382, "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[99474, 3856, 116, 3, 158, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[99593, 3861, 91, 2, 151, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[99699, 3866, 203, 7, 168, "Text",
 CellTags->{"i:41", "b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[99927, 3877, 145, 4, 158, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[100075, 3883, 92, 2, 151, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[CellGroupData[{
Cell[100204, 3890, 146, 4, 158, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[100353, 3896, 91, 2, 151, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[100459, 3901, 112, 1, 168, "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[100574, 3904, 2656, 97, 737, "DisplayTable",
 CellTags->{"i:42", "b:4.1", "IPM3.2.3.2"}],
Cell[103233, 4003, 78, 1, 112, "NumberedTable",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[103314, 4006, 746, 23, 382, "Text",
 CellTags->{"i:43", "b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[104085, 4033, 218, 7, 158, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[104306, 4042, 220, 8, 235, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[104541, 4053, 445, 17, 168, "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[CellGroupData[{
Cell[105011, 4074, 219, 7, 158, "Input",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[105233, 4083, 217, 8, 235, "Output",
 CellTags->{"b:4.1", "IPM3.2.3.2"}]
}, Closed]],
Cell[105465, 4094, 1883, 63, 652, "DisplayTable",
 CellTags->{"i:44", "b:4.1", "IPM3.2.3.2"}],
Cell[107351, 4159, 78, 1, 112, "NumberedTable",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[107432, 4162, 211, 4, 272, "Text",
 CellTags->{"b:4.1", "IPM3.2.3.2"}],
Cell[107646, 4168, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],
Cell[CellGroupData[{
Cell[107711, 4173, 83, 1, 415, "ExerciseSubsection",
 CellTags->{"b:4.1", "IPM3.2.3.3", "c:18"}],
Cell[107797, 4176, 274, 9, 127, "ExerciseItem",
 CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],
Cell[108074, 4187, 586, 23, 213, "ExerciseItem",
 CellTags->{"b:4.1", "IPM3.2.3.3", "i:54"}],
Cell[CellGroupData[{
Cell[108685, 4214, 751, 29, 213, "ExerciseItem",
 CellTags->{"i:47", "b:4.1", "IPM3.2.3.3"}],
Cell[109439, 4245, 229, 7, 285, "NonPrintInput"],
Cell[109671, 4254, 25, 0, 0, "SectionSpacer"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[109757, 4261, 69, 1, 35, "Section",
 CellTags->{"b:5", "IPM3.2.4", "c:19"}],
Cell[109829, 4264, 469, 12, 382, "TextFirst",
 CellTags->{"i:48", "b:5", "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[110323, 4280, 121, 3, 158, "Input",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[110447, 4285, 225, 6, 151, "Output",
 CellTags->{"b:5", "IPM3.2.4"}]
}, Closed]],
Cell[110687, 4294, 1074, 34, 487, "Text",
 CellTags->{"i:49", "b:5", "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[111786, 4332, 192, 6, 158, "Input",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[111981, 4340, 115, 3, 151, "Output",
 CellTags->{"b:5", "IPM3.2.4"}]
}, Closed]],
Cell[112111, 4346, 624, 18, 382, "Text",
 CellTags->{"i:50", "b:5", "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[112760, 4368, 124, 3, 158, "Input",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[112887, 4373, 125, 3, 151, "Output",
 CellTags->{"b:5", "IPM3.2.4"}]
}, Closed]],
Cell[113027, 4379, 96, 1, 168, "Text",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[113148, 4384, 240, 7, 158, "Input",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[113391, 4393, 241, 7, 151, "Output",
 CellTags->{"b:5", "IPM3.2.4"}]
}, Closed]],
Cell[113647, 4403, 88, 1, 168, "TextFirst",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[113760, 4408, 411, 14, 158, "Input",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[114174, 4424, 412, 14, 151, "Output",
 CellTags->{"b:5", "IPM3.2.4"}]
}, Closed]],
Cell[114601, 4441, 260, 6, 272, "Text",
 CellTags->{"i:51", "b:5", "IPM3.2.4"}],
Cell[114864, 4449, 405, 10, 272, "Text",
 CellTags->{"i:52", "b:5", "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[115294, 4463, 204, 6, 158, "Input",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[115501, 4471, 271, 10, 235, "Output",
 CellTags->{"b:5", "IPM3.2.4"}]
}, Closed]],
Cell[115787, 4484, 375, 12, 272, "Text",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[116165, 4498, 437, 9, 382, "Text",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[CellGroupData[{
Cell[116627, 4511, 142, 4, 158, "Input",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[116772, 4517, 143, 4, 151, "Output",
 CellTags->{"b:5", "IPM3.2.4"}]
}, Closed]],
Cell[116930, 4524, 332, 10, 272, "TextFirst",
 CellTags->{"i:53", "b:5", "IPM3.2.4"}],
Cell[117265, 4536, 120, 3, 158, "Input"],
Cell[CellGroupData[{
Cell[117410, 4543, 110, 3, 158, "Input"],
Cell[117523, 4548, 111, 3, 151, "Output"]
}, Closed]],
Cell[117649, 4554, 160, 5, 168, "Text",
 CellTags->{"b:5", "IPM3.2.4"}],
Cell[117812, 4561, 40, 1, 168, "Text",
 PageBreakAbove->True]
}, Closed]],
Cell[CellGroupData[{
Cell[117889, 4567, 94, 2, 41, "NonPrintSection",
 InitializationGroup->True,
 CellTags->"2. inits"],
Cell[117986, 4571, 130, 3, 36, "NonPrintInput",
 CellTags->"2. inits"],
Cell[118119, 4576, 2916, 82, 314, "NonPrintInput",
 CellTags->"2. inits"],
Cell[121038, 4660, 125, 4, 36, "NonPrintInput",
 CellTags->"2. inits"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
