(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      6814,        268]
NotebookOptionsPosition[      4913,        193]
NotebookOutlinePosition[      5392,        212]
CellTagsIndexPosition[      5349,        209]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Create a path to the notebooks.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$CourseDirectory", "=", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
    "$BaseDirectory", ",", "\"\<Applications\>\"", ",", "\"\<IPM4\>\""}], 
    "}"}], "]"}]}]], "Input"],

Cell[BoxData["\<\"/Library/Mathematica/Applications/IPM4\"\>"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["For notebook nb, count the number of cells of style.", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CountStyles", "[", 
   RowBox[{"nb_String", ",", "style_String"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"nbExp", ",", "nbb"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nbb", "=", 
      RowBox[{"NotebookOpen", "[", 
       RowBox[{"FileNameJoin", "[", 
        RowBox[{"{", 
         RowBox[{"$CourseDirectory", ",", "nb"}], "}"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"nbExp", "=", 
      RowBox[{"NotebookGet", "[", "nbb", "]"}]}], ";", 
     RowBox[{"Length", "[", 
      RowBox[{"Cases", "[", 
       RowBox[{"nbExp", ",", 
        RowBox[{"Cell", "[", 
         RowBox[{"__", ",", "style", ",", "___"}], "]"}], ",", "Infinity"}], 
       "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example of use.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "$CourseDirectory", "]"}]], "Input"],

Cell[BoxData["\<\"/Library/Mathematica/Applications/IPM4\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"01Introduction.nb\"\>", ",", "\<\".#01Introduction.nb.1.4\"\>",
    ",", "\<\"02Language.nb\"\>", ",", "\<\"04Functions.nb\"\>", 
   ",", "\<\"06RuleBased.nb\"\>", ",", "\<\"07Recursion.nb\"\>", 
   ",", "\<\"08Numerics.nb\"\>", ",", "\<\"09Graphics.nb\"\>", 
   ",", "\<\"CVS\"\>", ",", "\<\"Dynamic.nb\"\>", ",", "\<\"FrontEnd\"\>", 
   ",", "\<\"Graphics\"\>", ",", "\<\".project\"\>", ",", "\<\"Publisher\"\>",
    ",", "\<\"Sandbox\"\>", ",", "\<\"Solutions.nb\"\>", 
   ",", "\<\"Tools\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CountStyles", "[", 
  RowBox[{"\"\<04Functions.nb\>\"", ",", "\"\<ExerciseItem\>\""}], 
  "]"}]], "Input"],

Cell[BoxData["42"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Change the working directory.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "$CourseDirectory", "]"}]], "Input"],

Cell[BoxData["\<\"/Library/Mathematica/Applications/IPM4\"\>"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Create a list of only those notebooks you want to count.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"filelist", "=", 
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"FileNames", "[", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "8"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"02Language.nb\"\>", ",", "\<\"04Functions.nb\"\>", 
   ",", "\<\"06RuleBased.nb\"\>", ",", "\<\"07Recursion.nb\"\>", 
   ",", "\<\"08Numerics.nb\"\>", ",", "\<\"09Graphics.nb\"\>"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
From filelist, count all those instances of ExerciseItem style.\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"CountStyles", "[", 
     RowBox[{"#", ",", "\"\<ExerciseItem\>\""}], "]"}], "&"}], ",", 
   "filelist"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"10", ",", "42", ",", "26", ",", "34", ",", "29", ",", "34"}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Add them up.", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Total", "[", "%", "]"}]], "Input"],

Cell[BoxData["175"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Close the notebooks.", "Subsection"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FrontEndTokenExecute", "[", 
     RowBox[{"#", ",", "\"\<Close\>\""}], "]"}], "&"}], ",", "filelist"}], 
  "]"}]], "Input"]
}, Open  ]]
},
WindowSize->{908, 713},
WindowMargins->{{82, Automatic}, {171, Automatic}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 12, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 53, 0, 52, "Subsection"],
Cell[CellGroupData[{
Cell[657, 26, 215, 6, 65, "Input"],
Cell[875, 34, 73, 0, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[997, 40, 74, 0, 52, "Subsection"],
Cell[1074, 42, 859, 23, 136, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[1970, 70, 37, 0, 52, "Subsection"],
Cell[CellGroupData[{
Cell[2032, 74, 80, 1, 41, "Input"],
Cell[2115, 77, 73, 0, 41, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2225, 82, 57, 1, 41, "Input"],
Cell[2285, 85, 561, 9, 111, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2883, 99, 130, 3, 41, "Input"],
Cell[3016, 104, 29, 0, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3094, 110, 51, 0, 52, "Subsection"],
Cell[CellGroupData[{
Cell[3170, 114, 80, 1, 41, "Input"],
Cell[3253, 117, 73, 0, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3375, 123, 78, 0, 52, "Subsection"],
Cell[CellGroupData[{
Cell[3478, 127, 195, 6, 41, "Input"],
Cell[3676, 135, 247, 5, 65, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3972, 146, 93, 2, 52, "Subsection"],
Cell[CellGroupData[{
Cell[4090, 152, 194, 6, 41, "Input"],
Cell[4287, 160, 122, 3, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4458, 169, 34, 0, 52, "Subsection"],
Cell[CellGroupData[{
Cell[4517, 173, 58, 1, 41, "Input"],
Cell[4578, 176, 30, 0, 41, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4657, 182, 42, 0, 52, "Subsection"],
Cell[4702, 184, 195, 6, 41, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
