(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      9589,        299]
NotebookOptionsPosition[      8180,        247]
NotebookOutlinePosition[      8636,        265]
CellTagsIndexPosition[      8593,        262]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example: palette to open notebooks from directory", "Subsection"],

Cell["\<\
Get names of all notebooks that meet some criteria, in this case, all \
notebooks in one of the installed palettes directory.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lis", "=", 
  RowBox[{"FileNames", "[", 
   RowBox[{"\"\<*.nb\>\"", ",", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "$InstallationDirectory", ",", "\"\<SystemFiles\>\"", ",", 
       "\"\<FrontEnd\>\"", ",", "\"\<Palettes\>\""}], "}"}], "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/BasicMathAssistant.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ChartElementSchemes.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ClassroomAssistant.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ColorSchemes.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/NetworkGraphTools.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/SlideShow.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/SpecialCharacters.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/StylesheetChooser.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/WritingAssistant.nb\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["Pick only those we want in the palette.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{"lis", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6", ",", "8"}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/BasicMathAssistant.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ChartElementSchemes.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ClassroomAssistant.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ColorSchemes.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/SlideShow.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/StylesheetChooser.nb\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Better: use patterns to delete those we don\[CloseCurlyQuote]t want.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"files", "=", 
  RowBox[{"Select", "[", 
   RowBox[{"lis", ",", 
    RowBox[{
     RowBox[{"StringFreeQ", "[", 
      RowBox[{"#", ",", 
       RowBox[{"\"\<SlideShow\>\"", "|", "\"\<StylesheetChooser\>\""}]}], 
      "]"}], "&"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/BasicMathAssistant.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ChartElementSchemes.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ClassroomAssistant.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/ColorSchemes.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/NetworkGraphTools.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/SpecialCharacters.nb\"\>", 
   ",", "\<\"/Applications/Mathematica \
8.app/SystemFiles/FrontEnd/Palettes/WritingAssistant.nb\"\>"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell["Make labels for buttons.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"labels", "=", 
  RowBox[{"Map", "[", 
   RowBox[{"FileBaseName", ",", "files"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"BasicMathAssistant\"\>", ",", "\<\"ChartElementSchemes\"\>", 
   ",", "\<\"ClassroomAssistant\"\>", ",", "\<\"ColorSchemes\"\>", 
   ",", "\<\"NetworkGraphTools\"\>", ",", "\<\"SpecialCharacters\"\>", 
   ",", "\<\"WritingAssistant\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell["Create formatted palette.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CreateOpenNotebooksPalette", "[", 
  RowBox[{"labels", ",", "files", ",", "\"\<Open Palettes\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"NotebookObject", "[", 
   PanelBox[GridBox[{
      {
       TooltipBox[
        ButtonBox[
         StyleBox[
          
          DynamicBox[FEPrivate`FrontEndResource[
           "FEBitmaps", "ManipulatePasteIcon"],
           ImageSizeCache->{20., {4., 16.}}],
          DynamicUpdating->True],
         Appearance->{Automatic, None},
         BaseStyle->{},
         ButtonFunction:>FrontEndExecute[{
            FrontEnd`SetSelectedNotebook[
             NotebookObject[
              FrontEndObject[
               LinkObject["kqs_shm", 1, 1]], 69]]}],
         Evaluator->None,
         Method->"Queued"],
        DynamicBox[
         FEPrivate`FrontEndResource[
         "FEStrings", "NotebookObjectToTheFront"]]], 
       StyleBox["\<\"Open Palettes\"\>",
        StripOnInput->False,
        FontColor->GrayLevel[0.5]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}}],
    FrameMargins->{{4, 5}, {4, 4}}], "]"}],
  NotebookObject[
   FrontEndObject[
    LinkObject["kqs_shm", 1, 1]], 69],
  Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CreateOpenNotebooksPalette", "[", 
   RowBox[{"labels_List", ",", "files_List", ",", "title_String"}], "]"}], ":=", 
  RowBox[{"CreatePalette", "[", 
   RowBox[{
    RowBox[{"Grid", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"MapThread", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Button", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#1", ",", 
              RowBox[{"FontSize", "\[Rule]", "11"}], ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"GrayLevel", "[", ".9", "]"}]}]}], "]"}], ",", 
            RowBox[{"NotebookOpen", "[", 
             RowBox[{"FileNameJoin", "[", "#2", "]"}], "]"}], ",", 
            RowBox[{"Appearance", "\[Rule]", "\"\<Palette\>\""}], ",", 
            RowBox[{"Alignment", "\[Rule]", "Center"}], ",", 
            RowBox[{"Background", "\[Rule]", " ", 
             RowBox[{"RGBColor", "[", 
              RowBox[{".2", ",", ".2", ",", ".2"}], "]"}]}], ",", 
            RowBox[{"ImageMargins", "\[Rule]", "1"}]}], "]"}], "}"}], "&"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"labels", ",", "files"}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Spacings", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", ".15"}], "}"}]}], ",", 
      RowBox[{"Background", "\[Rule]", 
       RowBox[{"RGBColor", "[", 
        RowBox[{".4", ",", ".4", ",", ".6"}], "]"}]}]}], "]"}], ",", 
    RowBox[{"Magnification", "\[Rule]", "1.5"}], ",", 
    RowBox[{"WindowTitle", "\[Rule]", "title"}], ",", 
    RowBox[{"WindowElements", "\[Rule]", 
     RowBox[{"{", "\"\<MagnificationPopUp\>\"", "}"}]}]}], "]"}]}]], "Input",
 InitializationGroup->True],

Cell["", "Spacer"]
}, Closed]]
},
WindowSize->{1212, 754},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 12, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 71, 0, 52, "Subsection"],
Cell[653, 24, 149, 3, 39, "Text"],
Cell[CellGroupData[{
Cell[827, 31, 351, 10, 88, "Input",
 InitializationCell->True],
Cell[1181, 43, 987, 20, 226, "Output"]
}, Open  ]],
Cell[2183, 66, 62, 0, 62, "MathCaption"],
Cell[CellGroupData[{
Cell[2270, 70, 174, 5, 41, "Input"],
Cell[2447, 77, 673, 14, 157, "Output"]
}, Open  ]],
Cell[3135, 94, 99, 2, 63, "MathCaption"],
Cell[CellGroupData[{
Cell[3259, 100, 302, 9, 44, "Input",
 InitializationCell->True],
Cell[3564, 111, 785, 16, 180, "Output"]
}, Open  ]],
Cell[4364, 130, 47, 0, 62, "MathCaption"],
Cell[CellGroupData[{
Cell[4436, 134, 150, 4, 41, "Input",
 InitializationCell->True],
Cell[4589, 140, 301, 5, 65, "Output"]
}, Open  ]],
Cell[4905, 148, 48, 0, 62, "MathCaption"],
Cell[CellGroupData[{
Cell[4978, 152, 144, 3, 41, "Input"],
Cell[5125, 157, 1166, 36, 61, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6340, 199, 33, 0, 104, "Section"],
Cell[6376, 201, 1767, 41, 181, "Input",
 InitializationGroup->True],
Cell[8146, 244, 18, 0, 30, "Spacer"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
