(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8412,        278]
NotebookOptionsPosition[      7134,        232]
NotebookOutlinePosition[      7616,        251]
CellTagsIndexPosition[      7573,        248]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Set Notebook Options", "Section",
 CellChangeTimes->{{3.38581476509787*^9, 3.38581477168361*^9}}],

Cell["Rule for processing single notebooks.", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NotebookQ", "[", "str_", "]"}], ":=", 
  RowBox[{"StringMatchQ", "[", 
   RowBox[{"str", ",", 
    RowBox[{"__", "~~", "\"\<.nb\>\""}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SetNotebookOptions", "[", 
    RowBox[{
     RowBox[{"str_", "?", "NotebookQ"}], ",", "nbOpts_List"}], "]"}], ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "nb", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"nb", "=", 
       RowBox[{"NotebookOpen", "[", "str", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"SetOptions", "[", 
       RowBox[{"nb", ",", 
        RowBox[{"Sequence", "@@", "nbOpts"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"NotebookSave", "[", "nb", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"NotebookClose", "[", "nb", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell["\<\
Rule for processing a directory of notebooks.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SetNotebookOptions", "[", 
    RowBox[{"mydir_String", ",", "nbOpts_List"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"fileNms", ",", "nb"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fileNms", "=", 
       RowBox[{"FileNames", "[", 
        RowBox[{
         RowBox[{"{", "\"\<*.nb\>\"", "}"}], ",", "mydir"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"nb", "=", 
          RowBox[{"NotebookOpen", "[", 
           RowBox[{"fileNms", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"SetOptions", "[", 
          RowBox[{"nb", ",", 
           RowBox[{"Sequence", "@@", "nbOpts"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"NotebookSave", "[", "nb", "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"NotebookClose", "[", "nb", "]"}], ";"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "fileNms", "]"}]}], "}"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Main course notebooks", "Subsection"],

Cell["\<\
Now, give the function a path to the directory and a list of options you want \
to use with the notebooks.\
\>", "MathCaption",
 CellChangeTimes->{{3.385815425468671*^9, 3.385815454090061*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$CourseDirectory", "=", "\"\<M205BDynamic\>\""}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetNotebookOptions", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
     "$BaseDirectory", ",", "\"\<Applications\>\"", ",", "$CourseDirectory"}],
      "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"WindowSize", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"1000", ",", "700"}], "}"}]}], ",", 
     RowBox[{"Saveable", "\[Rule]", " ", "False"}], ",", 
     RowBox[{"ScreenStyleEnvironment", "\[Rule]", "\"\<SlideShow\>\""}], ",", 
     
     RowBox[{"WindowMargins", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "Automatic"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "10"}], "}"}]}], "}"}]}]}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Null", ",", "Null", ",", "Null", ",", "Null", ",", "Null", ",", "Null", 
   ",", "Null", ",", "Null"}], "}"}]], "Output"]
}, Open  ]],

Cell["Set an individual notebook to be in Working environment.", "Text"],

Cell[BoxData[
 RowBox[{"SetNotebookOptions", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
     "$BaseDirectory", ",", "\"\<Applications\>\"", ",", "$CourseDirectory", 
      ",", "\"\<01Animate.nb\>\""}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"WindowSize", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"1000", ",", "700"}], "}"}]}], ",", 
     RowBox[{"Saveable", "\[Rule]", " ", "False"}], ",", 
     RowBox[{"ScreenStyleEnvironment", "\[Rule]", "\"\<SlideShow\>\""}], ",", 
     
     RowBox[{"WindowMargins", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "Automatic"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "10"}], "}"}]}], "}"}]}]}], "}"}]}], 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Guide pages", "Subsection"],

Cell[BoxData[
 RowBox[{"SetNotebookOptions", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
     "$BaseDirectory", ",", "\"\<Applications\>\"", ",", "$CourseDirectory", 
      ",", "\"\<Documentation\>\"", ",", "\"\<English\>\"", ",", 
      "\"\<Guides\>\""}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"WindowSize", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"1000", ",", "700"}], "}"}]}], ",", 
     RowBox[{"Saveable", "\[Rule]", " ", "False"}], ",", 
     RowBox[{"WindowMargins", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "Automatic"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "10"}], "}"}]}], "}"}]}]}], "}"}]}], 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbols pages", "Subsection"],

Cell[BoxData[
 RowBox[{"SetNotebookOptions", "[", 
  RowBox[{
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
     "$BaseDirectory", ",", "\"\<Applications\>\"", ",", "$CourseDirectory", 
      ",", "\"\<Documentation\>\"", ",", "\"\<English\>\"", ",", 
      "\"\<ReferencePages\>\"", ",", "\"\<Symbols\>\""}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"WindowSize", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{"1000", ",", "700"}], "}"}]}], ",", 
     RowBox[{"Saveable", "\[Rule]", " ", "False"}], ",", 
     RowBox[{"WindowMargins", "\[Rule]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "Automatic"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "10"}], "}"}]}], "}"}]}]}], "}"}]}], 
  "]"}]], "Input"]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{1132, 842},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 12, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 103, 1, 125, "Section"],
Cell[673, 25, 60, 0, 75, "MathCaption"],
Cell[736, 27, 218, 6, 52, "Input",
 InitializationCell->True],
Cell[957, 35, 768, 21, 192, "Input",
 InitializationCell->True],
Cell[1728, 58, 76, 2, 75, "MathCaption"],
Cell[1807, 62, 1249, 33, 220, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3081, 99, 43, 0, 63, "Subsection"],
Cell[3127, 101, 203, 4, 75, "MathCaption"],
Cell[3333, 107, 101, 2, 50, "Input"],
Cell[CellGroupData[{
Cell[3459, 113, 795, 23, 163, "Input"],
Cell[4257, 138, 164, 4, 50, "Output"]
}, Open  ]],
Cell[4436, 145, 72, 0, 48, "Text"],
Cell[4511, 147, 825, 23, 163, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5373, 175, 33, 0, 63, "Subsection"],
Cell[5409, 177, 795, 22, 163, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6241, 204, 35, 0, 63, "Subsection"],
Cell[6279, 206, 827, 22, 163, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
